/*******************************************************************************
* File Name: ADC.c
*
* Version: 0.1
*
* Date: 06 November 2011
*
* Description:
*  This file provides source code for the 4 channel MUX ADC to LCD for the phototransistors.  The  
*  firmware takes a voltage output from the emitter output of the phototransistor and use the raw results to determine the presence of a colour.  
*
*  Code Tested With:
*  1. PSoC Creator 1.0 Beta 4.1 Build 6031
*  2. PSoC Programmer 3.11 Build 724
*  3. ARM CM3-GCC 4.2.1
*  4. MiniProg3 Rev *A  FW version 2.05 [2.92/1.12]
*
********************************************************************************
* Copyright (2011), Shandong University of Science and Technology, Shandong Province, PRC.
********************************************************************************
* Author: Malvin Maduna Ma Rui Nkomo
*******************************************************************************/

#include <device.h>

/* LCD specific */
#define ROW_0       0  /* LCD row 0     */
#define ROW_1       1  /* LCD row 0     */

#define COLUMN_0    0  /* LCD column 0  */
#define COLUMN_4    4  /* LCD column 0  */
#define COLUMN_5    5  /* LCD column 0  */
#define COLUMN_6    6  /* LCD column 0  */
#define COLUMN_9    9  /* LCD column 9  */
#define COLUMN_12  12  /* LCD column 10 */
#define COLUMN_13  13  /* LCD column 11 */
#define COLUMN_14  14  /* LCD column 11 */

/* For clearing Tens and Hundreds place */
#define CLEAR_TENS_HUNDREDS "   "
/* For clearing Hundreds place */
#define CLEAR_HUNDREDS      "   "

//void delay_ms(unsigned int n);

void UpdateDisplayChannel_0(uint32 voltageRawCount0);
void UpdateDisplayChannel_1(uint32 voltageRawCount1);
void UpdateDisplayChannel_2(uint32 voltageRawCount2);
void UpdateDisplayChannel_3(uint32 voltageRawCount3);
void delay_ms(unsigned int n);

/*ADC specific variables */ 

uint32 voltageRawCount0;
uint32 voltageRawCount1;
uint32 voltageRawCount2;
uint32 voltageRawCount3;


/*******************************************************************************
* Function Name: main
********************************************************************************
*
* Summary:
*   The main function initializes both the ADC and LCD, starts and waits for an 
*   ADC conversion, then it displays the raw counts to the LCD.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void ADC()
{
  
	LCD_Char_1_ClearDisplay();
    LCD_Char_1_Position(ROW_0,COLUMN_0);	 /* Move the cursor to Row 0 Column 0 */
    LCD_Char_1_PrintString("C0= ");			 /* Print Label for the Channel 0  raw count */	
	
	LCD_Char_1_Position(ROW_0,COLUMN_9);	 /* Move the cursor to Row 0 Column 9 */
 	LCD_Char_1_PrintString("C1= "); 		 /* Print Label for the Channel 1  raw count */
	
	LCD_Char_1_Position(ROW_1,COLUMN_0);	 /* Move the cursor to Row 1 Column 0 */
  	LCD_Char_1_PrintString("C2= ");  		 /* Print Label for the Channel 2 raw count */
	
	LCD_Char_1_Position(ROW_1,COLUMN_9);	 /* Move the cursor to Row 1 Column 9 */
    LCD_Char_1_PrintString("C3= ");			 /* Print Label for the Channel 3 raw count */
	
	ADC_DelSig_1_Start();  					/* Configure and power up ADC */
   
	
	/* Read Channel 0*/
		AMux_Init();
		AMux_FastSelect(0);												 /*Select MUX channel 0*/
		ADC_DelSig_1_StartConvert();									 /* Force ADC to initiate a conversion */
        ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_WAIT_FOR_RESULT);		 /* Wait for end of conversion */
		voltageRawCount0 = ADC_DelSig_1_GetResult32(); 						/* Get converted result for channel 0*/
		UpdateDisplayChannel_0(voltageRawCount0);							 /* Print result on LCD for channel 0*/
//		voltageRawCount0 = 0; 

		delay_ms(500);
	/* Read Channel 1*/	
			
		AMux_FastSelect(1);													 /*Select MUX channel 1*/
		ADC_DelSig_1_StartConvert();										 /* Force ADC to initiate a conversion */
        ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_WAIT_FOR_RESULT);			 /* Wait for end of conversion */
		voltageRawCount1 = ADC_DelSig_1_GetResult32(); 						 /* Get converted result for channel 1*/
		UpdateDisplayChannel_1(voltageRawCount1);							/* Print result on LCD for channel 1*/
//		voltageRawCount1 = 0;

		delay_ms(500);
	/* Read Channel 2*/	
		
		AMux_FastSelect(2);													 /*Select MUX channel 2*/
		ADC_DelSig_1_StartConvert();										 /* Force ADC to initiate a conversion */
        ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_WAIT_FOR_RESULT);			 /* Wait for end of conversion */
		voltageRawCount2 = ADC_DelSig_1_GetResult32(); 						 /* Get converted result for channel 2*/
		UpdateDisplayChannel_2(voltageRawCount2);							 /* Print result on LCD for channel 2*/
//		voltageRawCount2 = 0;
		
		delay_ms(500);
	/* Read Channel 3*/	
		
		AMux_FastSelect(3);													 /*Select MUX channel 3*/
		ADC_DelSig_1_StartConvert();										 /* Force ADC to initiate a conversion */
        ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_WAIT_FOR_RESULT);			 /* Wait for end of conversion */
		voltageRawCount3 = ADC_DelSig_1_GetResult32(); 						 /* Get converted result for channel 3*/
 		UpdateDisplayChannel_3(voltageRawCount3);							 /* Print result on LCD for channel 3*/
//		voltageRawCount3 = 0;
		delay_ms(500);
    
}

/*******************************************************************************
* Function Name: UpdateDisplayChannel_0 
********************************************************************************
*
* Summary:
*   Print voltage raw count result to the LCD.  Clears some characters if
*   necessary.
*
* Parameters:
*   voltageRawCount0: The voltage raw counts being received from the ADC 
*
* Return:
*   void
*
*******************************************************************************/
void UpdateDisplayChannel_0(uint32 voltageRawCount0)
{
    /* Move the cursor to Row 0, Column 4 */
    LCD_Char_1_Position(ROW_0,COLUMN_4); 
    LCD_Char_1_PrintNumber(voltageRawCount0); /* Print the result */
    
    if (voltageRawCount0 < 10)
    {
        /* Move the cursor to Row 0, Column 5 */
        LCD_Char_1_Position(ROW_0,COLUMN_5); 
        LCD_Char_1_PrintString(CLEAR_TENS_HUNDREDS); /* Clear last characters */
    }
    else if (voltageRawCount0 < 100)
    {
        /* Move the cursor to Row 0, Column 6 */
        LCD_Char_1_Position(ROW_0,COLUMN_6); 
        LCD_Char_1_PrintString(CLEAR_HUNDREDS); /* Clear last characters */
    }
    else
    {
        /* Continue on */
    }
}



/*******************************************************************************
* Function Name: UpdateDisplayChanel_1
********************************************************************************
*
* Summary:
*   Print voltage raw count result to the LCD.  Clears some characters if
*   necessary.
*
* Parameters:
*   voltageRawCount: The voltage raw counts being received from the ADC 
*
* Return:
*   void
*
*******************************************************************************/
void UpdateDisplayChannel_1(uint32 voltageRawCount1)
{
    /* Move the cursor to Row 0, Column 12 */
    LCD_Char_1_Position(ROW_0,COLUMN_12); 
    LCD_Char_1_PrintNumber(voltageRawCount1); /* Print the result */
    
    if (voltageRawCount1 < 10)
    {
        /* Move the cursor to Row 0, Column 13 */
        LCD_Char_1_Position(ROW_0,COLUMN_13); 
        LCD_Char_1_PrintString(CLEAR_TENS_HUNDREDS); /* Clear last characters */
    }
    else if (voltageRawCount1 < 100)
    {
        /* Move the cursor to Row 0, Column 14 */
        LCD_Char_1_Position(ROW_0,COLUMN_14); 
        LCD_Char_1_PrintString(CLEAR_HUNDREDS); /* Clear last characters */
    }
    else
    {
        /* Continue on */
    }
}



/*******************************************************************************
* Function Name: UpdateDisplayChannel_2
********************************************************************************
*
* Summary:
*   Print voltage raw count result to the LCD.  Clears some characters if
*   necessary.
*
* Parameters:
*   voltageRawCount: The voltage raw counts being received from the ADC 
*
* Return:
*   void
*
*******************************************************************************/
void UpdateDisplayChannel_2(uint32 voltageRawCount2)
{
    /* Move the cursor to Row 0, Column 4 */
    LCD_Char_1_Position(ROW_1,COLUMN_4); 
    LCD_Char_1_PrintNumber(voltageRawCount2); /* Print the result */
    
    if (voltageRawCount2 < 10)
    {
        /* Move the cursor to Row 0, Column 5 */
        LCD_Char_1_Position(ROW_1,COLUMN_5); 
        LCD_Char_1_PrintString(CLEAR_TENS_HUNDREDS); /* Clear last characters */
    }
    else if (voltageRawCount2 < 100)
    {
        /* Move the cursor to Row 0, Column 6 */
        LCD_Char_1_Position(ROW_1,COLUMN_6); 
        LCD_Char_1_PrintString(CLEAR_HUNDREDS); /* Clear last characters */
    }
    else
    {
        /* Continue on */
    }
}


/*******************************************************************************
* Function Name: UpdateDisplayChannel_3
********************************************************************************
*
* Summary:
*   Print voltage raw count result to the LCD.  Clears some characters if
*   necessary.
*
* Parameters:
*   voltageRawCount: The voltage raw counts being received from the ADC 
*
* Return:
*   void
*
*******************************************************************************/
void UpdateDisplayChannel_3(uint32 voltageRawCount3)
{
    /* Move the cursor to Row 1, Column 12 */
    LCD_Char_1_Position(ROW_1,COLUMN_12); 
    LCD_Char_1_PrintNumber(voltageRawCount3); /* Print the result */
    
    if (voltageRawCount3 < 10)
    {
        /* Move the cursor to Row 1, Column 13 */
        LCD_Char_1_Position(ROW_1,COLUMN_13); 
        LCD_Char_1_PrintString(CLEAR_TENS_HUNDREDS); /* Clear last characters */
    }
    else if (voltageRawCount3 < 100)
    {
        /* Move the cursor to Row 1, Column 14 */
        LCD_Char_1_Position(ROW_1,COLUMN_14); 
        LCD_Char_1_PrintString(CLEAR_HUNDREDS); /* Clear last characters */
    }
    else
    {
        /* Continue on */
    }
}

/*  END OF FILE */
