/*******************************************************************************
* File Name: Base_Rotation_Hitec.h  
* Version 2.10
*
* Description:
*  Contains the prototypes and constants for the functions available to the 
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

#if !defined(CY_PWM_Base_Rotation_Hitec_H)
#define CY_PWM_Base_Rotation_Hitec_H


/***************************************
* Conditional Compilation Parameters
***************************************/
#define Base_Rotation_Hitec_Resolution 16u
#define Base_Rotation_Hitec_UsingFixedFunction 0u
#define Base_Rotation_Hitec_DeadBandMode 0u
#define Base_Rotation_Hitec_KillModeMinTime 0u
#define Base_Rotation_Hitec_KillMode 0u
#define Base_Rotation_Hitec_PWMMode 0u
#define Base_Rotation_Hitec_PWMModeIsCenterAligned 0u
#define Base_Rotation_Hitec_DeadBandUsed 0u
#define Base_Rotation_Hitec_DeadBand2_4 0u
#if !defined(Base_Rotation_Hitec_PWMUDB_sSTSReg_stsreg__REMOVED)
    #define Base_Rotation_Hitec_UseStatus 1u
#else
    #define Base_Rotation_Hitec_UseStatus 0u
#endif
#if !defined(Base_Rotation_Hitec_PWMUDB_sCTRLReg_ctrlreg__REMOVED)
    #define Base_Rotation_Hitec_UseControl 1u
#else
    #define Base_Rotation_Hitec_UseControl 0u
#endif
#define Base_Rotation_Hitec_UseOneCompareMode 1u
#define Base_Rotation_Hitec_MinimumKillTime 1u
#define Base_Rotation_Hitec_EnableMode 0u

#define Base_Rotation_Hitec_CompareMode1SW 0u
#define Base_Rotation_Hitec_CompareMode2SW 0u

/* PSoC3 ES2 or early */
#define Base_Rotation_Hitec_PSOC3_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)   && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))

/* PSoC5 ES1 or early */
#define Base_Rotation_Hitec_PSOC5_ES1   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)   && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))

/* PSoC3 ES3 or later */
#define Base_Rotation_Hitec_PSOC3_ES3   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                     (CYDEV_CHIP_REVISION_USED >= CYDEV_CHIP_REVISION_3A_ES3))

/* PSoC5 ES2 or later */
#define Base_Rotation_Hitec_PSOC5_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)   && \
                                     (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))

/* Use Kill Mode Enumerated Types */
#define Base_Rotation_Hitec__B_PWM__DISABLED 0
#define Base_Rotation_Hitec__B_PWM__ASYNCHRONOUS 1
#define Base_Rotation_Hitec__B_PWM__SINGLECYCLE 2
#define Base_Rotation_Hitec__B_PWM__LATCHED 3
#define Base_Rotation_Hitec__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define Base_Rotation_Hitec__B_PWM__DBMDISABLED 0
#define Base_Rotation_Hitec__B_PWM__DBM_2_4_CLOCKS 1
#define Base_Rotation_Hitec__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define Base_Rotation_Hitec__B_PWM__ONE_OUTPUT 0
#define Base_Rotation_Hitec__B_PWM__TWO_OUTPUTS 1
#define Base_Rotation_Hitec__B_PWM__DUAL_EDGE 2
#define Base_Rotation_Hitec__B_PWM__CENTER_ALIGN 3
#define Base_Rotation_Hitec__B_PWM__DITHER 5
#define Base_Rotation_Hitec__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define Base_Rotation_Hitec__B_PWM__LESS_THAN 1
#define Base_Rotation_Hitec__B_PWM__LESS_THAN_OR_EQUAL 2
#define Base_Rotation_Hitec__B_PWM__GREATER_THAN 3
#define Base_Rotation_Hitec__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define Base_Rotation_Hitec__B_PWM__EQUAL 0
#define Base_Rotation_Hitec__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/

/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct Base_Rotation_Hitec_backupStruct
{
    
    uint8 PWMEnableState;
       
    #if(!Base_Rotation_Hitec_UsingFixedFunction)
        #if (Base_Rotation_Hitec_PSOC3_ES2 || Base_Rotation_Hitec_PSOC5_ES1)
            uint16 PWMUdb;               /* PWM Current Counter value  */
            uint16 PWMPeriod;            /* PWM Current Period value   */
            #if (Base_Rotation_Hitec_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif
            #if(Base_Rotation_Hitec_UseOneCompareMode)
                uint16 PWMCompareValue;     /* PWM Current Compare value */
            #else
                uint16 PWMCompareValue1;     /* PWM Current Compare value1 */
                uint16 PWMCompareValue2;     /* PWM Current Compare value2 */
            #endif
            
            /* Backup for Deadband parameters */
            #if(Base_Rotation_Hitec_DeadBandMode == Base_Rotation_Hitec__B_PWM__DBM_256_CLOCKS || Base_Rotation_Hitec_DeadBandMode == Base_Rotation_Hitec__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif
            
            /* Backup Kill Mode Counter*/
            #if(Base_Rotation_Hitec_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif
            
        #endif
        
        #if (Base_Rotation_Hitec_PSOC3_ES3 || Base_Rotation_Hitec_PSOC5_ES2)
            uint16 PWMUdb;               /* PWM Current Counter value  */
            #if(!Base_Rotation_Hitec_PWMModeIsCenterAligned)
                uint16 PWMPeriod;
            #endif
            #if (Base_Rotation_Hitec_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif
            
            /* Backup for Deadband parameters */
            #if(Base_Rotation_Hitec_DeadBandMode == Base_Rotation_Hitec__B_PWM__DBM_256_CLOCKS || Base_Rotation_Hitec_DeadBandMode == Base_Rotation_Hitec__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif
            
            /* Backup Kill Mode Counter*/
            #if(Base_Rotation_Hitec_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif
        #endif
        
        
        /* Backup control register */
        #if(Base_Rotation_Hitec_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif
        
    #endif 
   
}Base_Rotation_Hitec_backupStruct;

/***************************************
*        Function Prototypes
 **************************************/
 
void    Base_Rotation_Hitec_Start(void);
void    Base_Rotation_Hitec_Stop(void) ;
#if (Base_Rotation_Hitec_UseStatus || Base_Rotation_Hitec_UsingFixedFunction)
    #define Base_Rotation_Hitec_SetInterruptMode(interruptMode) CY_SET_REG8(Base_Rotation_Hitec_STATUS_MASK_PTR, interruptMode)
    #define Base_Rotation_Hitec_ReadStatusRegister() CY_GET_REG8(Base_Rotation_Hitec_STATUS_PTR)
#endif
#define Base_Rotation_Hitec_GetInterruptSource() Base_Rotation_Hitec_ReadStatusRegister()
#if (Base_Rotation_Hitec_UseControl)
    #define Base_Rotation_Hitec_ReadControlRegister() CY_GET_REG8(Base_Rotation_Hitec_CONTROL_PTR) 
    #define Base_Rotation_Hitec_WriteControlRegister(control) CY_SET_REG8(Base_Rotation_Hitec_CONTROL_PTR, control)
#endif
#if (Base_Rotation_Hitec_UseOneCompareMode)
   #if (Base_Rotation_Hitec_CompareMode1SW)
       void    Base_Rotation_Hitec_SetCompareMode(uint8 comparemode) ;
   #endif
#else
    #if (Base_Rotation_Hitec_CompareMode1SW)
        void    Base_Rotation_Hitec_SetCompareMode1(uint8 comparemode) ;
    #endif
    #if (Base_Rotation_Hitec_CompareMode2SW)
        void    Base_Rotation_Hitec_SetCompareMode2(uint8 comparemode) ;
    #endif
#endif

#if (!Base_Rotation_Hitec_UsingFixedFunction)
    uint16   Base_Rotation_Hitec_ReadCounter(void) ;
    #define Base_Rotation_Hitec_ReadCapture() CY_GET_REG16(Base_Rotation_Hitec_CAPTURE_LSB_PTR)
    #if (Base_Rotation_Hitec_UseStatus)
        void Base_Rotation_Hitec_ClearFIFO(void) ;
    #endif
#endif

void    Base_Rotation_Hitec_WriteCounter(uint16 counter) ;
void    Base_Rotation_Hitec_WritePeriod(uint16 period) ;
#define Base_Rotation_Hitec_ReadPeriod() CY_GET_REG16(Base_Rotation_Hitec_PERIOD_LSB_PTR) 
#if (Base_Rotation_Hitec_UseOneCompareMode)
    void    Base_Rotation_Hitec_WriteCompare(uint16 compare) ;
    #define Base_Rotation_Hitec_ReadCompare() CY_GET_REG16(Base_Rotation_Hitec_COMPARE1_LSB_PTR) 
#else
    void    Base_Rotation_Hitec_WriteCompare1(uint16 compare) ;
    #define Base_Rotation_Hitec_ReadCompare1() CY_GET_REG16(Base_Rotation_Hitec_COMPARE1_LSB_PTR) 
    void    Base_Rotation_Hitec_WriteCompare2(uint16 compare) ;
    #define Base_Rotation_Hitec_ReadCompare2() CY_GET_REG16(Base_Rotation_Hitec_COMPARE2_LSB_PTR) 
#endif


#if (Base_Rotation_Hitec_DeadBandUsed)
    void    Base_Rotation_Hitec_WriteDeadTime(uint8 deadtime) ;
    uint8   Base_Rotation_Hitec_ReadDeadTime(void) ;
#endif

#if ( Base_Rotation_Hitec_KillModeMinTime)
    #define Base_Rotation_Hitec_WriteKillTime(killtime) CY_SET_REG8(Base_Rotation_Hitec_KILLMODEMINTIME_PTR, killtime) 
    #define Base_Rotation_Hitec_ReadKillTime() CY_GET_REG8(Base_Rotation_Hitec_KILLMODEMINTIME_PTR) 
#endif

void Base_Rotation_Hitec_Init(void) ;
void Base_Rotation_Hitec_Enable(void) ;
void Base_Rotation_Hitec_Sleep(void);
void Base_Rotation_Hitec_Wakeup(void) ;
void Base_Rotation_Hitec_SaveConfig(void);
void Base_Rotation_Hitec_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define Base_Rotation_Hitec_INIT_PERIOD_VALUE        465u
#define Base_Rotation_Hitec_INIT_COMPARE_VALUE1      415u
#define Base_Rotation_Hitec_INIT_COMPARE_VALUE2      401u
#define Base_Rotation_Hitec_INIT_INTERRUPTS_MODE     ((0u << Base_Rotation_Hitec_STATUS_TC_INT_EN_MASK_SHIFT) | (0 << Base_Rotation_Hitec_STATUS_CMP2_INT_EN_MASK_SHIFT) | (0 << Base_Rotation_Hitec_STATUS_CMP1_INT_EN_MASK_SHIFT ) | (0 << Base_Rotation_Hitec_STATUS_KILL_INT_EN_MASK_SHIFT ))
#define Base_Rotation_Hitec_DEFAULT_COMPARE2_MODE    (1u << Base_Rotation_Hitec_CTRL_CMPMODE2_SHIFT)
#define Base_Rotation_Hitec_DEFAULT_COMPARE1_MODE    (4u << Base_Rotation_Hitec_CTRL_CMPMODE1_SHIFT)
#define Base_Rotation_Hitec_INIT_DEAD_TIME           1u


/********************************
*         Registers
******************************** */

#if (Base_Rotation_Hitec_UsingFixedFunction)
   #define Base_Rotation_Hitec_PERIOD_LSB          (*(reg16 *) Base_Rotation_Hitec_PWMHW__PER0)
   #define Base_Rotation_Hitec_PERIOD_LSB_PTR      ( (reg16 *) Base_Rotation_Hitec_PWMHW__PER0)
   #define Base_Rotation_Hitec_COMPARE1_LSB        (*(reg16 *) Base_Rotation_Hitec_PWMHW__CNT_CMP0)
   #define Base_Rotation_Hitec_COMPARE1_LSB_PTR    ( (reg16 *) Base_Rotation_Hitec_PWMHW__CNT_CMP0)
   #define Base_Rotation_Hitec_COMPARE2_LSB        0x00u
   #define Base_Rotation_Hitec_COMPARE2_LSB_PTR    0x00u
   #define Base_Rotation_Hitec_COUNTER_LSB         (*(reg16 *) Base_Rotation_Hitec_PWMHW__CNT_CMP0)
   #define Base_Rotation_Hitec_COUNTER_LSB_PTR     ( (reg16 *) Base_Rotation_Hitec_PWMHW__CNT_CMP0)
   #define Base_Rotation_Hitec_CAPTURE_LSB         (*(reg16 *) Base_Rotation_Hitec_PWMHW__CAP0)
   #define Base_Rotation_Hitec_CAPTURE_LSB_PTR     ( (reg16 *) Base_Rotation_Hitec_PWMHW__CAP0)
   #define Base_Rotation_Hitec_RT1                 (*(reg8 *)  Base_Rotation_Hitec_PWMHW__RT1)
   #define Base_Rotation_Hitec_RT1_PTR             ( (reg8 *)  Base_Rotation_Hitec_PWMHW__RT1)
      
#else
   #if(Base_Rotation_Hitec_PWMModeIsCenterAligned)
       #define Base_Rotation_Hitec_PERIOD_LSB      (*(reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__D1_REG)
       #define Base_Rotation_Hitec_PERIOD_LSB_PTR   ((reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__D1_REG)
   #else
       #define Base_Rotation_Hitec_PERIOD_LSB      (*(reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__F0_REG)
       #define Base_Rotation_Hitec_PERIOD_LSB_PTR   ((reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__F0_REG)
   #endif
   #define Base_Rotation_Hitec_COMPARE1_LSB    (*(reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__D0_REG)
   #define Base_Rotation_Hitec_COMPARE1_LSB_PTR ((reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__D0_REG)
   #define Base_Rotation_Hitec_COMPARE2_LSB    (*(reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__D1_REG)
   #define Base_Rotation_Hitec_COMPARE2_LSB_PTR ((reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__D1_REG)
   #define Base_Rotation_Hitec_COUNTERCAP_LSB   *(reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__A1_REG)
   #define Base_Rotation_Hitec_COUNTERCAP_LSB_PTR ((reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__A1_REG)
   #define Base_Rotation_Hitec_COUNTER_LSB     (*(reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__A0_REG)
   #define Base_Rotation_Hitec_COUNTER_LSB_PTR  ((reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__A0_REG)
   #define Base_Rotation_Hitec_CAPTURE_LSB     (*(reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__F1_REG)
   #define Base_Rotation_Hitec_CAPTURE_LSB_PTR  ((reg16 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__F1_REG)
   #define Base_Rotation_Hitec_AUX_CONTROLDP0      (*(reg8 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__DP_AUX_CTL_REG)
   #define Base_Rotation_Hitec_AUX_CONTROLDP0_PTR  ((reg8 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u0__DP_AUX_CTL_REG)
   #if (Base_Rotation_Hitec_Resolution == 16)
       #define Base_Rotation_Hitec_AUX_CONTROLDP1    (*(reg8 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u1__DP_AUX_CTL_REG)
       #define Base_Rotation_Hitec_AUX_CONTROLDP1_PTR  ((reg8 *) Base_Rotation_Hitec_PWMUDB_sP16_pwmdp_u1__DP_AUX_CTL_REG)
   #endif
#endif
   
#if(Base_Rotation_Hitec_KillModeMinTime )
    #define Base_Rotation_Hitec_KILLMODEMINTIME      (*(reg8 *) Base_Rotation_Hitec_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define Base_Rotation_Hitec_KILLMODEMINTIME_PTR   ((reg8 *) Base_Rotation_Hitec_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif

#if(Base_Rotation_Hitec_DeadBandMode == Base_Rotation_Hitec__B_PWM__DBM_256_CLOCKS)
    #define Base_Rotation_Hitec_DEADBAND_COUNT        (*(reg8 *) Base_Rotation_Hitec_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define Base_Rotation_Hitec_DEADBAND_COUNT_PTR     ((reg8 *) Base_Rotation_Hitec_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define Base_Rotation_Hitec_DEADBAND_LSB_PTR       ((reg8 *) Base_Rotation_Hitec_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define Base_Rotation_Hitec_DEADBAND_LSB          (*(reg8 *) Base_Rotation_Hitec_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(Base_Rotation_Hitec_DeadBandMode == Base_Rotation_Hitec__B_PWM__DBM_2_4_CLOCKS)
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (Base_Rotation_Hitec_UsingFixedFunction)
        #define Base_Rotation_Hitec_DEADBAND_COUNT        (*(reg8 *) Base_Rotation_Hitec_PWMHW__CFG0) 
        #define Base_Rotation_Hitec_DEADBAND_COUNT_PTR     ((reg8 *) Base_Rotation_Hitec_PWMHW__CFG0)
        #define Base_Rotation_Hitec_DEADBAND_COUNT_MASK    (0x03u << Base_Rotation_Hitec_DEADBAND_COUNT_SHIFT) 
        #define Base_Rotation_Hitec_DEADBAND_COUNT_SHIFT   0x06u /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */ 
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define Base_Rotation_Hitec_DEADBAND_COUNT        (*(reg8 *) Base_Rotation_Hitec_PWMUDB_sDB3_AsyncCtl_dbctrlreg__CONTROL_REG)
        #define Base_Rotation_Hitec_DEADBAND_COUNT_PTR     ((reg8 *) Base_Rotation_Hitec_PWMUDB_sDB3_AsyncCtl_dbctrlreg__CONTROL_REG)
        #define Base_Rotation_Hitec_DEADBAND_COUNT_MASK    (0x03u << Base_Rotation_Hitec_DEADBAND_COUNT_SHIFT) 
        #define Base_Rotation_Hitec_DEADBAND_COUNT_SHIFT   0x00u /* As defined by the verilog implementation of the Control Register */
    #endif
#endif



#if (Base_Rotation_Hitec_UsingFixedFunction)
    #define Base_Rotation_Hitec_STATUS                (*(reg8 *) Base_Rotation_Hitec_PWMHW__SR0)
    #define Base_Rotation_Hitec_STATUS_PTR            ((reg8 *) Base_Rotation_Hitec_PWMHW__SR0)
    #define Base_Rotation_Hitec_STATUS_MASK           (*(reg8 *) Base_Rotation_Hitec_PWMHW__SR0)
    #define Base_Rotation_Hitec_STATUS_MASK_PTR       ((reg8 *) Base_Rotation_Hitec_PWMHW__SR0)
    #define Base_Rotation_Hitec_CONTROL               (*(reg8 *) Base_Rotation_Hitec_PWMHW__CFG0)
    #define Base_Rotation_Hitec_CONTROL_PTR           ((reg8 *) Base_Rotation_Hitec_PWMHW__CFG0)    
    #define Base_Rotation_Hitec_CONTROL2              (*(reg8 *) Base_Rotation_Hitec_PWMHW__CFG1)    
    #if(Base_Rotation_Hitec_PSOC3_ES3 || Base_Rotation_Hitec_PSOC5_ES2)
        #define Base_Rotation_Hitec_CONTROL3              (*(reg8 *) Base_Rotation_Hitec_PWMHW__CFG2)
    #endif
    #define Base_Rotation_Hitec_GLOBAL_ENABLE         (*(reg8 *) Base_Rotation_Hitec_PWMHW__PM_ACT_CFG)
    #define Base_Rotation_Hitec_GLOBAL_ENABLE_PTR       ( (reg8 *) Base_Rotation_Hitec_PWMHW__PM_ACT_CFG)
    #define Base_Rotation_Hitec_GLOBAL_STBY_ENABLE      (*(reg8 *) Base_Rotation_Hitec_PWMHW__PM_STBY_CFG)
    #define Base_Rotation_Hitec_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) Base_Rotation_Hitec_PWMHW__PM_STBY_CFG)
  
  
    /***********************************
    *          Constants
    ***********************************/
    /* Fixed Function Block Chosen */
    #define Base_Rotation_Hitec_BLOCK_EN_MASK          Base_Rotation_Hitec_PWMHW__PM_ACT_MSK
    #define Base_Rotation_Hitec_BLOCK_STBY_EN_MASK     Base_Rotation_Hitec_PWMHW__PM_STBY_MSK 
    /* Control Register definitions */
    #define Base_Rotation_Hitec_CTRL_ENABLE_SHIFT      0x00u
    
    #if(Base_Rotation_Hitec_PSOC3_ES2 || Base_Rotation_Hitec_PSOC5_ES1)
        #define Base_Rotation_Hitec_CTRL_CMPMODE1_SHIFT    0x01u   /* As defined by Register map as MODE_CFG bits in CFG1*/
    #endif
    #if(Base_Rotation_Hitec_PSOC3_ES3 || Base_Rotation_Hitec_PSOC5_ES2)
        #define Base_Rotation_Hitec_CTRL_CMPMODE1_SHIFT    0x04u  /* As defined by Register map as MODE_CFG bits in CFG2*/
    #endif
    
    #define Base_Rotation_Hitec_CTRL_DEAD_TIME_SHIFT   0x06u   /* As defined by Register map */
    /* Fixed Function Block Only CFG register bit definitions */
    #define Base_Rotation_Hitec_CFG0_MODE              0x02u   /*  Set to compare mode */
    //#define Base_Rotation_Hitec_CFG0_ENABLE            0x01u   /* Enable the block to run */
    #define Base_Rotation_Hitec_CFG0_DB                0x20u   /* As defined by Register map as DB bit in CFG0 */

    /* Control Register Bit Masks */
    #define Base_Rotation_Hitec_CTRL_ENABLE            (0x01u << Base_Rotation_Hitec_CTRL_ENABLE_SHIFT)
    #define Base_Rotation_Hitec_CTRL_RESET             (0x01u << Base_Rotation_Hitec_CTRL_RESET_SHIFT)
    #define Base_Rotation_Hitec_CTRL_CMPMODE2_MASK     (0x07u << Base_Rotation_Hitec_CTRL_CMPMODE2_SHIFT)
    #if(Base_Rotation_Hitec_PSOC3_ES2 || Base_Rotation_Hitec_PSOC5_ES1)
        #define Base_Rotation_Hitec_CTRL_CMPMODE1_MASK     (0x07u << Base_Rotation_Hitec_CTRL_CMPMODE1_SHIFT)
    #endif
    #if(Base_Rotation_Hitec_PSOC3_ES3 || Base_Rotation_Hitec_PSOC5_ES2)
        #define Base_Rotation_Hitec_CTRL_CMPMODE1_MASK     (0x07u << Base_Rotation_Hitec_CTRL_CMPMODE1_SHIFT)
    #endif
    
    /* Control2 Register Bit Masks */
    #define Base_Rotation_Hitec_CTRL2_IRQ_SEL_SHIFT    0x00u       /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define Base_Rotation_Hitec_CTRL2_IRQ_SEL          (0x01u << Base_Rotation_Hitec_CTRL2_IRQ_SEL_SHIFT)  
    
    /* Status Register Bit Locations */
    #define Base_Rotation_Hitec_STATUS_TC_SHIFT            0x07u   /* As defined by Register map as TC in SR0 */
    #define Base_Rotation_Hitec_STATUS_CMP1_SHIFT          0x06u   /* As defined by the Register map as CAP_CMP in SR0 */
    
    /* Status Register Interrupt Enable Bit Locations */
    #define Base_Rotation_Hitec_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)    
    #define Base_Rotation_Hitec_STATUS_TC_INT_EN_MASK_SHIFT            (Base_Rotation_Hitec_STATUS_TC_SHIFT - 4)
    #define Base_Rotation_Hitec_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)  
    #define Base_Rotation_Hitec_STATUS_CMP1_INT_EN_MASK_SHIFT          (Base_Rotation_Hitec_STATUS_CMP1_SHIFT - 4)
    
    /* Status Register Bit Masks */
    #define Base_Rotation_Hitec_STATUS_TC              (0x01u << Base_Rotation_Hitec_STATUS_TC_SHIFT)
    #define Base_Rotation_Hitec_STATUS_CMP1            (0x01u << Base_Rotation_Hitec_STATUS_CMP1_SHIFT)
    
    /* Status Register Interrupt Bit Masks*/
    #define Base_Rotation_Hitec_STATUS_TC_INT_EN_MASK              (Base_Rotation_Hitec_STATUS_TC >> 4)
    #define Base_Rotation_Hitec_STATUS_CMP1_INT_EN_MASK            (Base_Rotation_Hitec_STATUS_CMP1 >> 4)
    
    /*RT1 Synch Constants: Applicable for PSoC3 ES2/PSoC3 ES3 PSoC5 ES2*/
    #define Base_Rotation_Hitec_RT1_SHIFT              0x04u
    #define Base_Rotation_Hitec_RT1_MASK               (0x03u << Base_Rotation_Hitec_RT1_SHIFT)  /* Sync TC and CMP bit masks */
    #define Base_Rotation_Hitec_SYNC                   (0x03u << Base_Rotation_Hitec_RT1_SHIFT)
    #define Base_Rotation_Hitec_SYNCDSI_SHIFT          0x00u
    #define Base_Rotation_Hitec_SYNCDSI_MASK           (0x0Fu << Base_Rotation_Hitec_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define Base_Rotation_Hitec_SYNCDSI_EN             (0x0Fu << Base_Rotation_Hitec_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    

#else
    #define Base_Rotation_Hitec_STATUS                (*(reg8 *) Base_Rotation_Hitec_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define Base_Rotation_Hitec_STATUS_PTR            ((reg8 *) Base_Rotation_Hitec_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define Base_Rotation_Hitec_STATUS_MASK           (*(reg8 *) Base_Rotation_Hitec_PWMUDB_sSTSReg_nrstSts_stsreg__MASK_REG)
    #define Base_Rotation_Hitec_STATUS_MASK_PTR       ((reg8 *) Base_Rotation_Hitec_PWMUDB_sSTSReg_nrstSts_stsreg__MASK_REG)
    #define Base_Rotation_Hitec_STATUS_AUX_CTRL       (*(reg8 *) Base_Rotation_Hitec_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define Base_Rotation_Hitec_CONTROL               (*(reg8 *) Base_Rotation_Hitec_PWMUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG)
    #define Base_Rotation_Hitec_CONTROL_PTR           ((reg8 *) Base_Rotation_Hitec_PWMUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG)
    
    
    /***********************************
    *          Constants
    ***********************************/
    /* Control Register definitions */
    #define Base_Rotation_Hitec_CTRL_ENABLE_SHIFT      0x07u
    #define Base_Rotation_Hitec_CTRL_RESET_SHIFT       0x06u
    #define Base_Rotation_Hitec_CTRL_CMPMODE2_SHIFT    0x03u
    #define Base_Rotation_Hitec_CTRL_CMPMODE1_SHIFT    0x00u
    #define Base_Rotation_Hitec_CTRL_DEAD_TIME_SHIFT   0x00u   /* No Shift Needed for UDB block */
    /* Control Register Bit Masks */
    #define Base_Rotation_Hitec_CTRL_ENABLE            (0x01u << Base_Rotation_Hitec_CTRL_ENABLE_SHIFT)
    #define Base_Rotation_Hitec_CTRL_RESET             (0x01u << Base_Rotation_Hitec_CTRL_RESET_SHIFT)
    #define Base_Rotation_Hitec_CTRL_CMPMODE2_MASK     (0x07u << Base_Rotation_Hitec_CTRL_CMPMODE2_SHIFT)
    #define Base_Rotation_Hitec_CTRL_CMPMODE1_MASK     (0x07u << Base_Rotation_Hitec_CTRL_CMPMODE1_SHIFT) 
    
    /* Status Register Bit Locations */
    #define Base_Rotation_Hitec_STATUS_KILL_SHIFT          0x05u
    #define Base_Rotation_Hitec_STATUS_FIFONEMPTY_SHIFT    0x04u
    #define Base_Rotation_Hitec_STATUS_FIFOFULL_SHIFT      0x03u  
    #define Base_Rotation_Hitec_STATUS_TC_SHIFT            0x02u
    #define Base_Rotation_Hitec_STATUS_CMP2_SHIFT          0x01u
    #define Base_Rotation_Hitec_STATUS_CMP1_SHIFT          0x00u
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define Base_Rotation_Hitec_STATUS_KILL_INT_EN_MASK_SHIFT          Base_Rotation_Hitec_STATUS_KILL_SHIFT          
    #define Base_Rotation_Hitec_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    Base_Rotation_Hitec_STATUS_FIFONEMPTY_SHIFT    
    #define Base_Rotation_Hitec_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      Base_Rotation_Hitec_STATUS_FIFOFULL_SHIFT        
    #define Base_Rotation_Hitec_STATUS_TC_INT_EN_MASK_SHIFT            Base_Rotation_Hitec_STATUS_TC_SHIFT            
    #define Base_Rotation_Hitec_STATUS_CMP2_INT_EN_MASK_SHIFT          Base_Rotation_Hitec_STATUS_CMP2_SHIFT          
    #define Base_Rotation_Hitec_STATUS_CMP1_INT_EN_MASK_SHIFT          Base_Rotation_Hitec_STATUS_CMP1_SHIFT   
    /* Status Register Bit Masks */
    #define Base_Rotation_Hitec_STATUS_KILL            (0x00u << Base_Rotation_Hitec_STATUS_KILL_SHIFT )
    #define Base_Rotation_Hitec_STATUS_FIFOFULL        (0x01u << Base_Rotation_Hitec_STATUS_FIFOFULL_SHIFT)
    #define Base_Rotation_Hitec_STATUS_FIFONEMPTY      (0x01u << Base_Rotation_Hitec_STATUS_FIFONEMPTY_SHIFT)
    #define Base_Rotation_Hitec_STATUS_TC              (0x01u << Base_Rotation_Hitec_STATUS_TC_SHIFT)
    #define Base_Rotation_Hitec_STATUS_CMP2            (0x01u << Base_Rotation_Hitec_STATUS_CMP2_SHIFT) 
    #define Base_Rotation_Hitec_STATUS_CMP1            (0x01u << Base_Rotation_Hitec_STATUS_CMP1_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define Base_Rotation_Hitec_STATUS_KILL_INT_EN_MASK            Base_Rotation_Hitec_STATUS_KILL
    #define Base_Rotation_Hitec_STATUS_FIFOFULL_INT_EN_MASK        Base_Rotation_Hitec_STATUS_FIFOFULL
    #define Base_Rotation_Hitec_STATUS_FIFONEMPTY_INT_EN_MASK      Base_Rotation_Hitec_STATUS_FIFONEMPTY
    #define Base_Rotation_Hitec_STATUS_TC_INT_EN_MASK              Base_Rotation_Hitec_STATUS_TC
    #define Base_Rotation_Hitec_STATUS_CMP2_INT_EN_MASK            Base_Rotation_Hitec_STATUS_CMP2
    #define Base_Rotation_Hitec_STATUS_CMP1_INT_EN_MASK            Base_Rotation_Hitec_STATUS_CMP1
                                                          
    /* Datapath Auxillary Control Register definitions */
    #define Base_Rotation_Hitec_AUX_CTRL_FIFO0_CLR     0x01u
    #define Base_Rotation_Hitec_AUX_CTRL_FIFO1_CLR     0x02u
    #define Base_Rotation_Hitec_AUX_CTRL_FIFO0_LVL     0x04u
    #define Base_Rotation_Hitec_AUX_CTRL_FIFO1_LVL     0x08u
    #define Base_Rotation_Hitec_STATUS_ACTL_INT_EN_MASK  0x10u /* As defined for the ACTL Register */
#endif /* Base_Rotation_Hitec_UsingFixedFunction */

#endif  /* CY_PWM_Base_Rotation_Hitec_H */
