/*******************************************************************************
* File Name: Base_Rotation_Hitec_PM.c
* Version 2.10
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "Base_Rotation_Hitec.h"

static Base_Rotation_Hitec_backupStruct Base_Rotation_Hitec_backup;


/*******************************************************************************
* Function Name: Base_Rotation_Hitec_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Base_Rotation_Hitec_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Base_Rotation_Hitec_SaveConfig(void)
{
    
    #if(!Base_Rotation_Hitec_UsingFixedFunction)
        #if (Base_Rotation_Hitec_PSOC3_ES2 || Base_Rotation_Hitec_PSOC5_ES1)
            Base_Rotation_Hitec_backup.PWMUdb = Base_Rotation_Hitec_ReadCounter();
            Base_Rotation_Hitec_backup.PWMPeriod = Base_Rotation_Hitec_ReadPeriod();
            #if (Base_Rotation_Hitec_UseStatus)
                Base_Rotation_Hitec_backup.InterruptMaskValue = Base_Rotation_Hitec_STATUS_MASK;
            #endif
            
            #if(Base_Rotation_Hitec_UseOneCompareMode)
                Base_Rotation_Hitec_backup.PWMCompareValue = Base_Rotation_Hitec_ReadCompare();
            #else
                Base_Rotation_Hitec_backup.PWMCompareValue1 = Base_Rotation_Hitec_ReadCompare1();
                Base_Rotation_Hitec_backup.PWMCompareValue2 = Base_Rotation_Hitec_ReadCompare2();
            #endif
            
           #if(Base_Rotation_Hitec_DeadBandUsed)
                Base_Rotation_Hitec_backup.PWMdeadBandValue = Base_Rotation_Hitec_ReadDeadTime();
            #endif
          
            #if ( Base_Rotation_Hitec_KillModeMinTime)
                Base_Rotation_Hitec_backup.PWMKillCounterPeriod = Base_Rotation_Hitec_ReadKillTime();
            #endif
        #endif
        
        #if (Base_Rotation_Hitec_PSOC3_ES3 || Base_Rotation_Hitec_PSOC5_ES2)
            #if(!Base_Rotation_Hitec_PWMModeIsCenterAligned)
                Base_Rotation_Hitec_backup.PWMPeriod = Base_Rotation_Hitec_ReadPeriod();
            #endif
            Base_Rotation_Hitec_backup.PWMUdb = Base_Rotation_Hitec_ReadCounter();
            #if (Base_Rotation_Hitec_UseStatus)
                Base_Rotation_Hitec_backup.InterruptMaskValue = Base_Rotation_Hitec_STATUS_MASK;
            #endif
            
            #if(Base_Rotation_Hitec_DeadBandMode == Base_Rotation_Hitec__B_PWM__DBM_256_CLOCKS || Base_Rotation_Hitec_DeadBandMode == Base_Rotation_Hitec__B_PWM__DBM_2_4_CLOCKS)
                Base_Rotation_Hitec_backup.PWMdeadBandValue = Base_Rotation_Hitec_ReadDeadTime();
            #endif
            
            #if(Base_Rotation_Hitec_KillModeMinTime)
                 Base_Rotation_Hitec_backup.PWMKillCounterPeriod = Base_Rotation_Hitec_ReadKillTime();
            #endif
        #endif
        
        #if(Base_Rotation_Hitec_UseControl)
            Base_Rotation_Hitec_backup.PWMControlRegister = Base_Rotation_Hitec_ReadControlRegister();
        #endif
    #endif  
}


/*******************************************************************************
* Function Name: Base_Rotation_Hitec_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Base_Rotation_Hitec_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*  Yes.
*
*******************************************************************************/
void Base_Rotation_Hitec_RestoreConfig(void) 
{
        #if(!Base_Rotation_Hitec_UsingFixedFunction)
            #if (Base_Rotation_Hitec_PSOC3_ES2 || Base_Rotation_Hitec_PSOC5_ES1)
                /* Interrupt State Backup for Critical Region*/
                uint8 Base_Rotation_Hitec_interruptState;
                /* Enter Critical Region*/
                Base_Rotation_Hitec_interruptState = CyEnterCriticalSection();
                #if (Base_Rotation_Hitec_UseStatus)
                    /* Use the interrupt output of the status register for IRQ output */
                    Base_Rotation_Hitec_STATUS_AUX_CTRL |= Base_Rotation_Hitec_STATUS_ACTL_INT_EN_MASK;
                    
                    Base_Rotation_Hitec_STATUS_MASK = Base_Rotation_Hitec_backup.InterruptMaskValue;
                #endif
                
                #if (Base_Rotation_Hitec_Resolution == 8)
                    /* Set FIFO 0 to 1 byte register for period*/
                    Base_Rotation_Hitec_AUX_CONTROLDP0 |= (Base_Rotation_Hitec_AUX_CTRL_FIFO0_CLR);
                #else /* (Base_Rotation_Hitec_Resolution == 16)*/
                    /* Set FIFO 0 to 1 byte register for period */
                    Base_Rotation_Hitec_AUX_CONTROLDP0 |= (Base_Rotation_Hitec_AUX_CTRL_FIFO0_CLR);
                    Base_Rotation_Hitec_AUX_CONTROLDP1 |= (Base_Rotation_Hitec_AUX_CTRL_FIFO0_CLR);
                #endif
                /* Exit Critical Region*/
                CyExitCriticalSection(Base_Rotation_Hitec_interruptState);
                
                Base_Rotation_Hitec_WriteCounter(Base_Rotation_Hitec_backup.PWMUdb);
                Base_Rotation_Hitec_WritePeriod(Base_Rotation_Hitec_backup.PWMPeriod);
                
                #if(Base_Rotation_Hitec_UseOneCompareMode)
                    Base_Rotation_Hitec_WriteCompare(Base_Rotation_Hitec_backup.PWMCompareValue);
                #else
                    Base_Rotation_Hitec_WriteCompare1(Base_Rotation_Hitec_backup.PWMCompareValue1);
                    Base_Rotation_Hitec_WriteCompare2(Base_Rotation_Hitec_backup.PWMCompareValue2);
                #endif
                
               #if(Base_Rotation_Hitec_DeadBandMode == Base_Rotation_Hitec__B_PWM__DBM_256_CLOCKS || Base_Rotation_Hitec_DeadBandMode == Base_Rotation_Hitec__B_PWM__DBM_2_4_CLOCKS)
                    Base_Rotation_Hitec_WriteDeadTime(Base_Rotation_Hitec_backup.PWMdeadBandValue);
                #endif
            
                #if ( Base_Rotation_Hitec_KillModeMinTime)
                    Base_Rotation_Hitec_WriteKillTime(Base_Rotation_Hitec_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if (Base_Rotation_Hitec_PSOC3_ES3 || Base_Rotation_Hitec_PSOC5_ES2)
                #if(!Base_Rotation_Hitec_PWMModeIsCenterAligned)
                    Base_Rotation_Hitec_WritePeriod(Base_Rotation_Hitec_backup.PWMPeriod);
                #endif
                Base_Rotation_Hitec_WriteCounter(Base_Rotation_Hitec_backup.PWMUdb);
                #if (Base_Rotation_Hitec_UseStatus)
                    Base_Rotation_Hitec_STATUS_MASK = Base_Rotation_Hitec_backup.InterruptMaskValue;
                #endif
                
                #if(Base_Rotation_Hitec_DeadBandMode == Base_Rotation_Hitec__B_PWM__DBM_256_CLOCKS || Base_Rotation_Hitec_DeadBandMode == Base_Rotation_Hitec__B_PWM__DBM_2_4_CLOCKS)
                    Base_Rotation_Hitec_WriteDeadTime(Base_Rotation_Hitec_backup.PWMdeadBandValue);
                #endif
                
                #if(Base_Rotation_Hitec_KillModeMinTime)
                    Base_Rotation_Hitec_WriteKillTime(Base_Rotation_Hitec_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if(Base_Rotation_Hitec_UseControl)
                Base_Rotation_Hitec_WriteControlRegister(Base_Rotation_Hitec_backup.PWMControlRegister); 
            #endif
        #endif  
    }


/*******************************************************************************
* Function Name: Base_Rotation_Hitec_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Base_Rotation_Hitec_backup.PWMEnableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Base_Rotation_Hitec_Sleep(void)
{
    #if(Base_Rotation_Hitec_UseControl)
        if(Base_Rotation_Hitec_CTRL_ENABLE == (Base_Rotation_Hitec_CONTROL & Base_Rotation_Hitec_CTRL_ENABLE))
        {
            /*Component is enabled */
            Base_Rotation_Hitec_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            Base_Rotation_Hitec_backup.PWMEnableState = 0u;
        }
    #endif
    /* Stop component */
    Base_Rotation_Hitec_Stop();
    
    /* Save registers configuration */
    Base_Rotation_Hitec_SaveConfig();
}


/*******************************************************************************
* Function Name: Base_Rotation_Hitec_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Base_Rotation_Hitec_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_Wakeup(void) 
{
     /* Restore registers values */
    Base_Rotation_Hitec_RestoreConfig();
    
    if(Base_Rotation_Hitec_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        Base_Rotation_Hitec_Enable();
    } /* Do nothing if component's block was disabled before */
    
}

/* [] END OF FILE */
