/*******************************************************************************
* File Name: Grippers_DGS05NF.c  
* Version 2.10
*
* Description:
*  The PWM User Module consist of an 8 or 16-bit counter with two 8 or 16-bit
*  comparitors. Each instance of this user module is capable of generating
*  two PWM outputs with the same period. The pulse width is selectable between
*  1 and 255/65535. The period is selectable between 2 and 255/65536 clocks. 
*  The compare value output may be configured to be active when the present 
*  counter is less than or less than/equal to the compare value.
*  A terminal count output is also provided. It generates a pulse one clock
*  width wide when the counter is equal to zero.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "Grippers_DGS05NF.h"

uint8 Grippers_DGS05NF_initVar = 0u;

/*******************************************************************************
* Function Name: Grippers_DGS05NF_Start
********************************************************************************
*
* Summary:
*  The start function initializes the pwm with the default values, the 
*  enables the counter to begin counting.  It does not enable interrupts,
*  the EnableInt command should be called if interrupt generation is required.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Global variables:
*  Grippers_DGS05NF_initVar: Is modified when this function is called for the first 
*   time. Is used to ensure that initialization happens only once.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_Start(void) 
{
    /* If not Initialized then initialize all required hardware and software */
    if(Grippers_DGS05NF_initVar == 0u)
    {
        Grippers_DGS05NF_Init();
        Grippers_DGS05NF_initVar = 1u;
    }
    Grippers_DGS05NF_Enable();

}


/*******************************************************************************
* Function Name: Grippers_DGS05NF_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  Grippers_DGS05NF_Start().
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_Init(void) 
{
    #if (Grippers_DGS05NF_UsingFixedFunction || Grippers_DGS05NF_UseControl)
        uint8 ctrl;
    #endif
    
    #if(!Grippers_DGS05NF_UsingFixedFunction) 
        #if(Grippers_DGS05NF_UseStatus)
            /* Interrupt State Backup for Critical Region*/
            uint8 Grippers_DGS05NF_interruptState;
        #endif
    #endif
    
   #if (Grippers_DGS05NF_UsingFixedFunction)
        /* You are allowed to write the compare value (FF only) */
        Grippers_DGS05NF_CONTROL |= Grippers_DGS05NF_CFG0_MODE;
        #if (Grippers_DGS05NF_DeadBand2_4)
            Grippers_DGS05NF_CONTROL |= Grippers_DGS05NF_CFG0_DB;
        #endif
                
        /* Set the default Compare Mode */
        #if(Grippers_DGS05NF_PSOC3_ES2 || Grippers_DGS05NF_PSOC5_ES1)
                ctrl = Grippers_DGS05NF_CONTROL2 & ~Grippers_DGS05NF_CTRL_CMPMODE1_MASK;
                Grippers_DGS05NF_CONTROL2 = ctrl | Grippers_DGS05NF_DEFAULT_COMPARE1_MODE;
        #endif
        #if(Grippers_DGS05NF_PSOC3_ES3 || Grippers_DGS05NF_PSOC5_ES2)
                ctrl = Grippers_DGS05NF_CONTROL3 & ~Grippers_DGS05NF_CTRL_CMPMODE1_MASK;
                Grippers_DGS05NF_CONTROL3 = ctrl | Grippers_DGS05NF_DEFAULT_COMPARE1_MODE;
        #endif
        
         /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
        Grippers_DGS05NF_RT1 &= ~Grippers_DGS05NF_RT1_MASK;
        Grippers_DGS05NF_RT1 |= Grippers_DGS05NF_SYNC;     
                
        /*Enable DSI Sync all all inputs of the PWM*/
        Grippers_DGS05NF_RT1 &= ~(Grippers_DGS05NF_SYNCDSI_MASK);
        Grippers_DGS05NF_RT1 |= Grippers_DGS05NF_SYNCDSI_EN;
       
    #elif (Grippers_DGS05NF_UseControl)
        /* Set the default compare mode defined in the parameter */
        ctrl = Grippers_DGS05NF_CONTROL & ~Grippers_DGS05NF_CTRL_CMPMODE2_MASK & ~Grippers_DGS05NF_CTRL_CMPMODE1_MASK;
        Grippers_DGS05NF_CONTROL = ctrl | Grippers_DGS05NF_DEFAULT_COMPARE2_MODE | Grippers_DGS05NF_DEFAULT_COMPARE1_MODE;
    #endif 
        
    #if (!Grippers_DGS05NF_UsingFixedFunction)
        #if (Grippers_DGS05NF_Resolution == 8)
            /* Set FIFO 0 to 1 byte register for period*/
            Grippers_DGS05NF_AUX_CONTROLDP0 |= (Grippers_DGS05NF_AUX_CTRL_FIFO0_CLR);
        #else /* (Grippers_DGS05NF_Resolution == 16)*/
            /* Set FIFO 0 to 1 byte register for period */
            Grippers_DGS05NF_AUX_CONTROLDP0 |= (Grippers_DGS05NF_AUX_CTRL_FIFO0_CLR);
            Grippers_DGS05NF_AUX_CONTROLDP1 |= (Grippers_DGS05NF_AUX_CTRL_FIFO0_CLR);
        #endif
    #endif
        
    Grippers_DGS05NF_WritePeriod(Grippers_DGS05NF_INIT_PERIOD_VALUE);
    Grippers_DGS05NF_WriteCounter(Grippers_DGS05NF_INIT_PERIOD_VALUE);
        
        #if (Grippers_DGS05NF_UseOneCompareMode)
            Grippers_DGS05NF_WriteCompare(Grippers_DGS05NF_INIT_COMPARE_VALUE1);
        #else
            Grippers_DGS05NF_WriteCompare1(Grippers_DGS05NF_INIT_COMPARE_VALUE1);
            Grippers_DGS05NF_WriteCompare2(Grippers_DGS05NF_INIT_COMPARE_VALUE2);
        #endif
        
        #if (Grippers_DGS05NF_KillModeMinTime)
            Grippers_DGS05NF_WriteKillTime(Grippers_DGS05NF_MinimumKillTime);
        #endif
        
        #if (Grippers_DGS05NF_DeadBandUsed)
            Grippers_DGS05NF_WriteDeadTime(Grippers_DGS05NF_INIT_DEAD_TIME);
        #endif

    #if (Grippers_DGS05NF_UseStatus || Grippers_DGS05NF_UsingFixedFunction)
        Grippers_DGS05NF_SetInterruptMode(Grippers_DGS05NF_INIT_INTERRUPTS_MODE);
    #endif
        
    #if (Grippers_DGS05NF_UsingFixedFunction)
        /* Globally Enable the Fixed Function Block chosen */
        Grippers_DGS05NF_GLOBAL_ENABLE |= Grippers_DGS05NF_BLOCK_EN_MASK;
        /* Set the Interrupt source to come from the status register */
        Grippers_DGS05NF_CONTROL2 |= Grippers_DGS05NF_CTRL2_IRQ_SEL;
    #else
        #if(Grippers_DGS05NF_UseStatus)
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            Grippers_DGS05NF_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            Grippers_DGS05NF_STATUS_AUX_CTRL |= Grippers_DGS05NF_STATUS_ACTL_INT_EN_MASK;
            
             /* Exit Critical Region*/
            CyExitCriticalSection(Grippers_DGS05NF_interruptState);
            
            /* Clear the FIFO to enable the Grippers_DGS05NF_STATUS_FIFOFULL
                   bit to be set on FIFO full. */
            Grippers_DGS05NF_ClearFIFO();
        #endif
    #endif
}


/*******************************************************************************
* Function Name: Grippers_DGS05NF_Enable
********************************************************************************
*
* Summary: 
*  Enables the PWM block operation
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Side Effects: 
*  This works only if software enable mode is chosen
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (Grippers_DGS05NF_UsingFixedFunction)
        Grippers_DGS05NF_GLOBAL_ENABLE |= Grippers_DGS05NF_BLOCK_EN_MASK;
        Grippers_DGS05NF_GLOBAL_STBY_ENABLE |= Grippers_DGS05NF_BLOCK_STBY_EN_MASK;
    #endif 
    
    /* Enable the PWM from the control register  */
    #if (Grippers_DGS05NF_UseControl || Grippers_DGS05NF_UsingFixedFunction)
        Grippers_DGS05NF_CONTROL |= Grippers_DGS05NF_CTRL_ENABLE;
    #endif
}


/*******************************************************************************
* Function Name: Grippers_DGS05NF_Stop
********************************************************************************
*
* Summary:
*  The stop function halts the PWM, but does not change any modes or disable
*  interrupts.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects:
*  If the Enable mode is set to Hardware only then this function
*  has no effect on the operation of the PWM
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_Stop(void) 
{
    #if (Grippers_DGS05NF_UseControl || Grippers_DGS05NF_UsingFixedFunction)
        Grippers_DGS05NF_CONTROL &= ~Grippers_DGS05NF_CTRL_ENABLE;
    #endif
    
    /* Globally disable the Fixed Function Block chosen */
    #if (Grippers_DGS05NF_UsingFixedFunction)
        Grippers_DGS05NF_GLOBAL_ENABLE &= ~Grippers_DGS05NF_BLOCK_EN_MASK;
        Grippers_DGS05NF_GLOBAL_STBY_ENABLE &= ~Grippers_DGS05NF_BLOCK_STBY_EN_MASK;
    #endif
}


#if (Grippers_DGS05NF_UseOneCompareMode)
#if (Grippers_DGS05NF_CompareMode1SW)
/*******************************************************************************
* Function Name: Grippers_DGS05NF_SetCompareMode
********************************************************************************
* 
* Summary:
*  This function writes the Compare Mode for the pwm output when in Dither mode,
*  Center Align Mode or One Output Mode.
*
* Parameters:
*  comparemode:  The new compare mode for the PWM output. Use the compare types
*                defined in the H file as input arguments.
*
* Return:
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_SetCompareMode(uint8 comparemode) 
{
    #if(Grippers_DGS05NF_UsingFixedFunction)
            #if(Grippers_DGS05NF_PSOC3_ES2 || Grippers_DGS05NF_PSOC5_ES1)
                        uint8 comparemodemasked = (comparemode << Grippers_DGS05NF_CTRL_CMPMODE1_SHIFT);
                        Grippers_DGS05NF_CONTROL2 &= ~Grippers_DGS05NF_CTRL_CMPMODE1_MASK; /*Clear Existing Data */
                        Grippers_DGS05NF_CONTROL2 |= comparemodemasked;  
                #endif
                
            #if(Grippers_DGS05NF_PSOC3_ES3 || Grippers_DGS05NF_PSOC5_ES2)
                    uint8 comparemodemasked = (comparemode << Grippers_DGS05NF_CTRL_CMPMODE1_SHIFT);
            Grippers_DGS05NF_CONTROL3 &= ~Grippers_DGS05NF_CTRL_CMPMODE1_MASK; /*Clear Existing Data */
            Grippers_DGS05NF_CONTROL3 |= comparemodemasked;     
                #endif
                
    #elif (Grippers_DGS05NF_UseControl)
        uint8 comparemode1masked = (comparemode << Grippers_DGS05NF_CTRL_CMPMODE1_SHIFT) & Grippers_DGS05NF_CTRL_CMPMODE1_MASK;
        uint8 comparemode2masked = (comparemode << Grippers_DGS05NF_CTRL_CMPMODE2_SHIFT) & Grippers_DGS05NF_CTRL_CMPMODE2_MASK;
        Grippers_DGS05NF_CONTROL &= ~(Grippers_DGS05NF_CTRL_CMPMODE1_MASK | Grippers_DGS05NF_CTRL_CMPMODE2_MASK); /*Clear existing mode */
        Grippers_DGS05NF_CONTROL |= (comparemode1masked | comparemode2masked);
        
    #else
        uint8 temp = comparemode;
    #endif
}
#endif /* Grippers_DGS05NF_CompareMode1SW */

#else /* UseOneCompareMode */


#if (Grippers_DGS05NF_CompareMode1SW)
/*******************************************************************************
* Function Name: Grippers_DGS05NF_SetCompareMode1
********************************************************************************
* 
* Summary:
*  This function writes the Compare Mode for the pwm or pwm1 output
*
* Parameters:  
*  comparemode:  The new compare mode for the PWM output. Use the compare types
*                defined in the H file as input arguments.
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_SetCompareMode1(uint8 comparemode) 
{
    uint8 comparemodemasked = (comparemode << Grippers_DGS05NF_CTRL_CMPMODE1_SHIFT) & Grippers_DGS05NF_CTRL_CMPMODE1_MASK;
    #if(Grippers_DGS05NF_UsingFixedFunction)
            #if(Grippers_DGS05NF_PSOC3_ES2 || Grippers_DGS05NF_PSOC5_ES1)
                        Grippers_DGS05NF_CONTROL2 &= Grippers_DGS05NF_CTRL_CMPMODE1_MASK; /*Clear existing mode */
                        Grippers_DGS05NF_CONTROL2 |= comparemodemasked; 
            #endif
                
                #if(Grippers_DGS05NF_PSOC3_ES3 || Grippers_DGS05NF_PSOC5_ES2)
                    Grippers_DGS05NF_CONTROL3 &= Grippers_DGS05NF_CTRL_CMPMODE1_MASK; /*Clear existing mode */
                        Grippers_DGS05NF_CONTROL3 |= comparemodemasked; 
            #endif
                
    #elif (Grippers_DGS05NF_UseControl)
        Grippers_DGS05NF_CONTROL &= Grippers_DGS05NF_CTRL_CMPMODE1_MASK; /*Clear existing mode */
        Grippers_DGS05NF_CONTROL |= comparemodemasked;
    #endif    
}
#endif /* Grippers_DGS05NF_CompareMode1SW */


#if (Grippers_DGS05NF_CompareMode2SW)
/*******************************************************************************
* Function Name: Grippers_DGS05NF_SetCompareMode2
********************************************************************************
* 
* Summary:
*  This function writes the Compare Mode for the pwm or pwm2 output
*
* Parameters:  
*  comparemode:  The new compare mode for the PWM output. Use the compare types
*                defined in the H file as input arguments.
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_SetCompareMode2(uint8 comparemode) 
{
    #if(Grippers_DGS05NF_UsingFixedFunction)
        /* Do Nothing because there is no second Compare Mode Register in FF block*/ 
    #elif (Grippers_DGS05NF_UseControl)
    uint8 comparemodemasked = (comparemode << Grippers_DGS05NF_CTRL_CMPMODE2_SHIFT) & Grippers_DGS05NF_CTRL_CMPMODE2_MASK;
    Grippers_DGS05NF_CONTROL &= Grippers_DGS05NF_CTRL_CMPMODE2_MASK; /*Clear existing mode */
    Grippers_DGS05NF_CONTROL |= comparemodemasked;
    #endif    
}
#endif /*Grippers_DGS05NF_CompareMode2SW */
#endif /* UseOneCompareMode */


/*******************************************************************************
* Function Name: Grippers_DGS05NF_WriteCounter
********************************************************************************
* 
* Summary:
*  This function is used to change the counter value.
*
* Parameters:  
*  counter:  This value may be between 1 and (2^Resolution)-1.   
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_WriteCounter(uint16 counter) 
{
    #if(Grippers_DGS05NF_UsingFixedFunction)
        CY_SET_REG16(Grippers_DGS05NF_COUNTER_LSB_PTR, (uint16)counter);
    #else
        CY_SET_REG16(Grippers_DGS05NF_COUNTER_LSB_PTR, counter);
    #endif
}


#if (!Grippers_DGS05NF_UsingFixedFunction)
/*******************************************************************************
* Function Name: Grippers_DGS05NF_ReadCounter
********************************************************************************
* 
* Summary:
*  This function returns the current value of the counter.  It doesn't matter
*  if the counter is enabled or running.
*
* Parameters:  
*  void  
*
* Return: 
*  The current value of the counter.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
uint16 Grippers_DGS05NF_ReadCounter(void) 
{
    /* Force capture by reading Accumulator */
    /* Must first do a software capture to be able to read the counter */
    /* It is up to the user code to make sure there isn't already captured data in the FIFO */
    CY_GET_REG8(Grippers_DGS05NF_COUNTERCAP_LSB_PTR);
    
    /* Read the data from the FIFO (or capture register for Fixed Function)*/
    return (CY_GET_REG16(Grippers_DGS05NF_CAPTURE_LSB_PTR));
}


#if (Grippers_DGS05NF_UseStatus)
/*******************************************************************************
* Function Name: Grippers_DGS05NF_ClearFIFO
********************************************************************************
* 
* Summary:
*  This function clears all capture data from the capture FIFO
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_ClearFIFO(void) 
{
    while(Grippers_DGS05NF_ReadStatusRegister() & Grippers_DGS05NF_STATUS_FIFONEMPTY)
        Grippers_DGS05NF_ReadCapture();
}
#endif /* Grippers_DGS05NF_UseStatus */
#endif /* !Grippers_DGS05NF_UsingFixedFunction */


/*******************************************************************************
* Function Name: Grippers_DGS05NF_WritePeriod
********************************************************************************
* 
* Summary:
*  This function is used to change the period of the counter.  The new period 
*  will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period:  Period value. May be between 1 and (2^Resolution)-1.  A value of 0 
*           will result in the counter remaining at zero.
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_WritePeriod(uint16 period) 
{
    #if(Grippers_DGS05NF_UsingFixedFunction)
        CY_SET_REG16(Grippers_DGS05NF_PERIOD_LSB_PTR, (uint16)period);
    #else
        CY_SET_REG16(Grippers_DGS05NF_PERIOD_LSB_PTR, period);
    #endif
}


#if (Grippers_DGS05NF_UseOneCompareMode)
/*******************************************************************************
* Function Name: Grippers_DGS05NF_WriteCompare
********************************************************************************
* 
* Summary:
*  This funtion is used to change the compare1 value when the PWM is in Dither
*  mode. The compare output will reflect the new value on the next UDB clock. 
*  The compare output will be driven high when the present counter value is 
*  compared to the compare value based on the compare mode defined in 
*  Dither Mode.
*
* Parameters:  
*  compare:  New compare value.  
*
* Return: 
*  void
*
* Side Effects:
*  This function is only available if the PWM mode parameter is set to
*  Dither Mode, Center Aligned Mode or One Output Mode
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_WriteCompare(uint16 compare) 
{
   CY_SET_REG16(Grippers_DGS05NF_COMPARE1_LSB_PTR, compare);
   #if (Grippers_DGS05NF_PWMMode == Grippers_DGS05NF__B_PWM__DITHER)
        CY_SET_REG16(Grippers_DGS05NF_COMPARE2_LSB_PTR, compare+1);
   #endif
}


#else


/*******************************************************************************
* Function Name: Grippers_DGS05NF_WriteCompare1
********************************************************************************
* 
* Summary:
*  This funtion is used to change the compare1 value.  The compare output will 
*  reflect the new value on the next UDB clock.  The compare output will be 
*  driven high when the present counter value is less than or less than or 
*  equal to the compare register, depending on the mode.
*
* Parameters:  
*  compare:  New compare value.  
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_WriteCompare1(uint16 compare) 
{
    #if(Grippers_DGS05NF_UsingFixedFunction)
        CY_SET_REG16(Grippers_DGS05NF_COMPARE1_LSB_PTR, (uint16)compare);
    #else
        CY_SET_REG16(Grippers_DGS05NF_COMPARE1_LSB_PTR, compare);
    #endif
}


/*******************************************************************************
* Function Name: Grippers_DGS05NF_WriteCompare2
********************************************************************************
* 
* Summary:
*  This funtion is used to change the compare value, for compare1 output.  
*  The compare output will reflect the new value on the next UDB clock.  
*  The compare output will be driven high when the present counter value is 
*  less than or less than or equal to the compare register, depending on the 
*  mode.
*
* Parameters:  
*  compare:  New compare value.  
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_WriteCompare2(uint16 compare) 
{
    #if(Grippers_DGS05NF_UsingFixedFunction)
        CY_SET_REG16(Grippers_DGS05NF_COMPARE2_LSB_PTR, compare);
    #else
        CY_SET_REG16(Grippers_DGS05NF_COMPARE2_LSB_PTR, compare);
    #endif
}
#endif /* UseOneCompareMode */


#if (Grippers_DGS05NF_DeadBandUsed)
/*******************************************************************************
* Function Name: Grippers_DGS05NF_WriteDeadTime
********************************************************************************
* 
* Summary:
*  This function writes the dead-band counts to the corresponding register
*
* Parameters:  
*  deadtime:  Number of counts for dead time 
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_WriteDeadTime(uint8 deadtime) 
{
    /* If using the Dead Band 1-255 mode then just write the register */
    #if(!Grippers_DGS05NF_DeadBand2_4)
        CY_SET_REG8(Grippers_DGS05NF_DEADBAND_COUNT_PTR, deadtime);
    #else
        /* Otherwise the data has to be masked and offset */        
        /* Clear existing data */
        Grippers_DGS05NF_DEADBAND_COUNT &= ~Grippers_DGS05NF_DEADBAND_COUNT_MASK; 
            /* Set new dead time */
        Grippers_DGS05NF_DEADBAND_COUNT |= (deadtime << Grippers_DGS05NF_DEADBAND_COUNT_SHIFT) & Grippers_DGS05NF_DEADBAND_COUNT_MASK; 
    #endif
}


/*******************************************************************************
* Function Name: Grippers_DGS05NF_ReadDeadTime
********************************************************************************
* 
* Summary:
*  This function reads the dead-band counts from the corresponding register
*
* Parameters:  
*  void
*
* Return: 
*  Dead Band Counts
*
* Reentrant:
*  Yes
*
*******************************************************************************/
uint8 Grippers_DGS05NF_ReadDeadTime(void) 
{
    /* If using the Dead Band 1-255 mode then just read the register */
    #if(!Grippers_DGS05NF_DeadBand2_4)
        return (CY_GET_REG8(Grippers_DGS05NF_DEADBAND_COUNT_PTR));
    #else
        /* Otherwise the data has to be masked and offset */
        return ((Grippers_DGS05NF_DEADBAND_COUNT & Grippers_DGS05NF_DEADBAND_COUNT_MASK) >> Grippers_DGS05NF_DEADBAND_COUNT_SHIFT);
    #endif
}
#endif /* DeadBandUsed */

