/*******************************************************************************
* File Name: Grippers_DGS05NF_PM.c
* Version 2.10
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "Grippers_DGS05NF.h"

static Grippers_DGS05NF_backupStruct Grippers_DGS05NF_backup;


/*******************************************************************************
* Function Name: Grippers_DGS05NF_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Grippers_DGS05NF_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Grippers_DGS05NF_SaveConfig(void)
{
    
    #if(!Grippers_DGS05NF_UsingFixedFunction)
        #if (Grippers_DGS05NF_PSOC3_ES2 || Grippers_DGS05NF_PSOC5_ES1)
            Grippers_DGS05NF_backup.PWMUdb = Grippers_DGS05NF_ReadCounter();
            Grippers_DGS05NF_backup.PWMPeriod = Grippers_DGS05NF_ReadPeriod();
            #if (Grippers_DGS05NF_UseStatus)
                Grippers_DGS05NF_backup.InterruptMaskValue = Grippers_DGS05NF_STATUS_MASK;
            #endif
            
            #if(Grippers_DGS05NF_UseOneCompareMode)
                Grippers_DGS05NF_backup.PWMCompareValue = Grippers_DGS05NF_ReadCompare();
            #else
                Grippers_DGS05NF_backup.PWMCompareValue1 = Grippers_DGS05NF_ReadCompare1();
                Grippers_DGS05NF_backup.PWMCompareValue2 = Grippers_DGS05NF_ReadCompare2();
            #endif
            
           #if(Grippers_DGS05NF_DeadBandUsed)
                Grippers_DGS05NF_backup.PWMdeadBandValue = Grippers_DGS05NF_ReadDeadTime();
            #endif
          
            #if ( Grippers_DGS05NF_KillModeMinTime)
                Grippers_DGS05NF_backup.PWMKillCounterPeriod = Grippers_DGS05NF_ReadKillTime();
            #endif
        #endif
        
        #if (Grippers_DGS05NF_PSOC3_ES3 || Grippers_DGS05NF_PSOC5_ES2)
            #if(!Grippers_DGS05NF_PWMModeIsCenterAligned)
                Grippers_DGS05NF_backup.PWMPeriod = Grippers_DGS05NF_ReadPeriod();
            #endif
            Grippers_DGS05NF_backup.PWMUdb = Grippers_DGS05NF_ReadCounter();
            #if (Grippers_DGS05NF_UseStatus)
                Grippers_DGS05NF_backup.InterruptMaskValue = Grippers_DGS05NF_STATUS_MASK;
            #endif
            
            #if(Grippers_DGS05NF_DeadBandMode == Grippers_DGS05NF__B_PWM__DBM_256_CLOCKS || Grippers_DGS05NF_DeadBandMode == Grippers_DGS05NF__B_PWM__DBM_2_4_CLOCKS)
                Grippers_DGS05NF_backup.PWMdeadBandValue = Grippers_DGS05NF_ReadDeadTime();
            #endif
            
            #if(Grippers_DGS05NF_KillModeMinTime)
                 Grippers_DGS05NF_backup.PWMKillCounterPeriod = Grippers_DGS05NF_ReadKillTime();
            #endif
        #endif
        
        #if(Grippers_DGS05NF_UseControl)
            Grippers_DGS05NF_backup.PWMControlRegister = Grippers_DGS05NF_ReadControlRegister();
        #endif
    #endif  
}


/*******************************************************************************
* Function Name: Grippers_DGS05NF_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Grippers_DGS05NF_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*  Yes.
*
*******************************************************************************/
void Grippers_DGS05NF_RestoreConfig(void) 
{
        #if(!Grippers_DGS05NF_UsingFixedFunction)
            #if (Grippers_DGS05NF_PSOC3_ES2 || Grippers_DGS05NF_PSOC5_ES1)
                /* Interrupt State Backup for Critical Region*/
                uint8 Grippers_DGS05NF_interruptState;
                /* Enter Critical Region*/
                Grippers_DGS05NF_interruptState = CyEnterCriticalSection();
                #if (Grippers_DGS05NF_UseStatus)
                    /* Use the interrupt output of the status register for IRQ output */
                    Grippers_DGS05NF_STATUS_AUX_CTRL |= Grippers_DGS05NF_STATUS_ACTL_INT_EN_MASK;
                    
                    Grippers_DGS05NF_STATUS_MASK = Grippers_DGS05NF_backup.InterruptMaskValue;
                #endif
                
                #if (Grippers_DGS05NF_Resolution == 8)
                    /* Set FIFO 0 to 1 byte register for period*/
                    Grippers_DGS05NF_AUX_CONTROLDP0 |= (Grippers_DGS05NF_AUX_CTRL_FIFO0_CLR);
                #else /* (Grippers_DGS05NF_Resolution == 16)*/
                    /* Set FIFO 0 to 1 byte register for period */
                    Grippers_DGS05NF_AUX_CONTROLDP0 |= (Grippers_DGS05NF_AUX_CTRL_FIFO0_CLR);
                    Grippers_DGS05NF_AUX_CONTROLDP1 |= (Grippers_DGS05NF_AUX_CTRL_FIFO0_CLR);
                #endif
                /* Exit Critical Region*/
                CyExitCriticalSection(Grippers_DGS05NF_interruptState);
                
                Grippers_DGS05NF_WriteCounter(Grippers_DGS05NF_backup.PWMUdb);
                Grippers_DGS05NF_WritePeriod(Grippers_DGS05NF_backup.PWMPeriod);
                
                #if(Grippers_DGS05NF_UseOneCompareMode)
                    Grippers_DGS05NF_WriteCompare(Grippers_DGS05NF_backup.PWMCompareValue);
                #else
                    Grippers_DGS05NF_WriteCompare1(Grippers_DGS05NF_backup.PWMCompareValue1);
                    Grippers_DGS05NF_WriteCompare2(Grippers_DGS05NF_backup.PWMCompareValue2);
                #endif
                
               #if(Grippers_DGS05NF_DeadBandMode == Grippers_DGS05NF__B_PWM__DBM_256_CLOCKS || Grippers_DGS05NF_DeadBandMode == Grippers_DGS05NF__B_PWM__DBM_2_4_CLOCKS)
                    Grippers_DGS05NF_WriteDeadTime(Grippers_DGS05NF_backup.PWMdeadBandValue);
                #endif
            
                #if ( Grippers_DGS05NF_KillModeMinTime)
                    Grippers_DGS05NF_WriteKillTime(Grippers_DGS05NF_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if (Grippers_DGS05NF_PSOC3_ES3 || Grippers_DGS05NF_PSOC5_ES2)
                #if(!Grippers_DGS05NF_PWMModeIsCenterAligned)
                    Grippers_DGS05NF_WritePeriod(Grippers_DGS05NF_backup.PWMPeriod);
                #endif
                Grippers_DGS05NF_WriteCounter(Grippers_DGS05NF_backup.PWMUdb);
                #if (Grippers_DGS05NF_UseStatus)
                    Grippers_DGS05NF_STATUS_MASK = Grippers_DGS05NF_backup.InterruptMaskValue;
                #endif
                
                #if(Grippers_DGS05NF_DeadBandMode == Grippers_DGS05NF__B_PWM__DBM_256_CLOCKS || Grippers_DGS05NF_DeadBandMode == Grippers_DGS05NF__B_PWM__DBM_2_4_CLOCKS)
                    Grippers_DGS05NF_WriteDeadTime(Grippers_DGS05NF_backup.PWMdeadBandValue);
                #endif
                
                #if(Grippers_DGS05NF_KillModeMinTime)
                    Grippers_DGS05NF_WriteKillTime(Grippers_DGS05NF_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if(Grippers_DGS05NF_UseControl)
                Grippers_DGS05NF_WriteControlRegister(Grippers_DGS05NF_backup.PWMControlRegister); 
            #endif
        #endif  
    }


/*******************************************************************************
* Function Name: Grippers_DGS05NF_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Grippers_DGS05NF_backup.PWMEnableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Grippers_DGS05NF_Sleep(void)
{
    #if(Grippers_DGS05NF_UseControl)
        if(Grippers_DGS05NF_CTRL_ENABLE == (Grippers_DGS05NF_CONTROL & Grippers_DGS05NF_CTRL_ENABLE))
        {
            /*Component is enabled */
            Grippers_DGS05NF_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            Grippers_DGS05NF_backup.PWMEnableState = 0u;
        }
    #endif
    /* Stop component */
    Grippers_DGS05NF_Stop();
    
    /* Save registers configuration */
    Grippers_DGS05NF_SaveConfig();
}


/*******************************************************************************
* Function Name: Grippers_DGS05NF_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Grippers_DGS05NF_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Grippers_DGS05NF_Wakeup(void) 
{
     /* Restore registers values */
    Grippers_DGS05NF_RestoreConfig();
    
    if(Grippers_DGS05NF_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        Grippers_DGS05NF_Enable();
    } /* Do nothing if component's block was disabled before */
    
}

/* [] END OF FILE */
