/*******************************************************************************
* File Name: Lift_Futaba_S3003.c  
* Version 2.10
*
* Description:
*  The PWM User Module consist of an 8 or 16-bit counter with two 8 or 16-bit
*  comparitors. Each instance of this user module is capable of generating
*  two PWM outputs with the same period. The pulse width is selectable between
*  1 and 255/65535. The period is selectable between 2 and 255/65536 clocks. 
*  The compare value output may be configured to be active when the present 
*  counter is less than or less than/equal to the compare value.
*  A terminal count output is also provided. It generates a pulse one clock
*  width wide when the counter is equal to zero.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "Lift_Futaba_S3003.h"

uint8 Lift_Futaba_S3003_initVar = 0u;

/*******************************************************************************
* Function Name: Lift_Futaba_S3003_Start
********************************************************************************
*
* Summary:
*  The start function initializes the pwm with the default values, the 
*  enables the counter to begin counting.  It does not enable interrupts,
*  the EnableInt command should be called if interrupt generation is required.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Global variables:
*  Lift_Futaba_S3003_initVar: Is modified when this function is called for the first 
*   time. Is used to ensure that initialization happens only once.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_Start(void) 
{
    /* If not Initialized then initialize all required hardware and software */
    if(Lift_Futaba_S3003_initVar == 0u)
    {
        Lift_Futaba_S3003_Init();
        Lift_Futaba_S3003_initVar = 1u;
    }
    Lift_Futaba_S3003_Enable();

}


/*******************************************************************************
* Function Name: Lift_Futaba_S3003_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  Lift_Futaba_S3003_Start().
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_Init(void) 
{
    #if (Lift_Futaba_S3003_UsingFixedFunction || Lift_Futaba_S3003_UseControl)
        uint8 ctrl;
    #endif
    
    #if(!Lift_Futaba_S3003_UsingFixedFunction) 
        #if(Lift_Futaba_S3003_UseStatus)
            /* Interrupt State Backup for Critical Region*/
            uint8 Lift_Futaba_S3003_interruptState;
        #endif
    #endif
    
   #if (Lift_Futaba_S3003_UsingFixedFunction)
        /* You are allowed to write the compare value (FF only) */
        Lift_Futaba_S3003_CONTROL |= Lift_Futaba_S3003_CFG0_MODE;
        #if (Lift_Futaba_S3003_DeadBand2_4)
            Lift_Futaba_S3003_CONTROL |= Lift_Futaba_S3003_CFG0_DB;
        #endif
                
        /* Set the default Compare Mode */
        #if(Lift_Futaba_S3003_PSOC3_ES2 || Lift_Futaba_S3003_PSOC5_ES1)
                ctrl = Lift_Futaba_S3003_CONTROL2 & ~Lift_Futaba_S3003_CTRL_CMPMODE1_MASK;
                Lift_Futaba_S3003_CONTROL2 = ctrl | Lift_Futaba_S3003_DEFAULT_COMPARE1_MODE;
        #endif
        #if(Lift_Futaba_S3003_PSOC3_ES3 || Lift_Futaba_S3003_PSOC5_ES2)
                ctrl = Lift_Futaba_S3003_CONTROL3 & ~Lift_Futaba_S3003_CTRL_CMPMODE1_MASK;
                Lift_Futaba_S3003_CONTROL3 = ctrl | Lift_Futaba_S3003_DEFAULT_COMPARE1_MODE;
        #endif
        
         /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
        Lift_Futaba_S3003_RT1 &= ~Lift_Futaba_S3003_RT1_MASK;
        Lift_Futaba_S3003_RT1 |= Lift_Futaba_S3003_SYNC;     
                
        /*Enable DSI Sync all all inputs of the PWM*/
        Lift_Futaba_S3003_RT1 &= ~(Lift_Futaba_S3003_SYNCDSI_MASK);
        Lift_Futaba_S3003_RT1 |= Lift_Futaba_S3003_SYNCDSI_EN;
       
    #elif (Lift_Futaba_S3003_UseControl)
        /* Set the default compare mode defined in the parameter */
        ctrl = Lift_Futaba_S3003_CONTROL & ~Lift_Futaba_S3003_CTRL_CMPMODE2_MASK & ~Lift_Futaba_S3003_CTRL_CMPMODE1_MASK;
        Lift_Futaba_S3003_CONTROL = ctrl | Lift_Futaba_S3003_DEFAULT_COMPARE2_MODE | Lift_Futaba_S3003_DEFAULT_COMPARE1_MODE;
    #endif 
        
    #if (!Lift_Futaba_S3003_UsingFixedFunction)
        #if (Lift_Futaba_S3003_Resolution == 8)
            /* Set FIFO 0 to 1 byte register for period*/
            Lift_Futaba_S3003_AUX_CONTROLDP0 |= (Lift_Futaba_S3003_AUX_CTRL_FIFO0_CLR);
        #else /* (Lift_Futaba_S3003_Resolution == 16)*/
            /* Set FIFO 0 to 1 byte register for period */
            Lift_Futaba_S3003_AUX_CONTROLDP0 |= (Lift_Futaba_S3003_AUX_CTRL_FIFO0_CLR);
            Lift_Futaba_S3003_AUX_CONTROLDP1 |= (Lift_Futaba_S3003_AUX_CTRL_FIFO0_CLR);
        #endif
    #endif
        
    Lift_Futaba_S3003_WritePeriod(Lift_Futaba_S3003_INIT_PERIOD_VALUE);
    Lift_Futaba_S3003_WriteCounter(Lift_Futaba_S3003_INIT_PERIOD_VALUE);
        
        #if (Lift_Futaba_S3003_UseOneCompareMode)
            Lift_Futaba_S3003_WriteCompare(Lift_Futaba_S3003_INIT_COMPARE_VALUE1);
        #else
            Lift_Futaba_S3003_WriteCompare1(Lift_Futaba_S3003_INIT_COMPARE_VALUE1);
            Lift_Futaba_S3003_WriteCompare2(Lift_Futaba_S3003_INIT_COMPARE_VALUE2);
        #endif
        
        #if (Lift_Futaba_S3003_KillModeMinTime)
            Lift_Futaba_S3003_WriteKillTime(Lift_Futaba_S3003_MinimumKillTime);
        #endif
        
        #if (Lift_Futaba_S3003_DeadBandUsed)
            Lift_Futaba_S3003_WriteDeadTime(Lift_Futaba_S3003_INIT_DEAD_TIME);
        #endif

    #if (Lift_Futaba_S3003_UseStatus || Lift_Futaba_S3003_UsingFixedFunction)
        Lift_Futaba_S3003_SetInterruptMode(Lift_Futaba_S3003_INIT_INTERRUPTS_MODE);
    #endif
        
    #if (Lift_Futaba_S3003_UsingFixedFunction)
        /* Globally Enable the Fixed Function Block chosen */
        Lift_Futaba_S3003_GLOBAL_ENABLE |= Lift_Futaba_S3003_BLOCK_EN_MASK;
        /* Set the Interrupt source to come from the status register */
        Lift_Futaba_S3003_CONTROL2 |= Lift_Futaba_S3003_CTRL2_IRQ_SEL;
    #else
        #if(Lift_Futaba_S3003_UseStatus)
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            Lift_Futaba_S3003_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            Lift_Futaba_S3003_STATUS_AUX_CTRL |= Lift_Futaba_S3003_STATUS_ACTL_INT_EN_MASK;
            
             /* Exit Critical Region*/
            CyExitCriticalSection(Lift_Futaba_S3003_interruptState);
            
            /* Clear the FIFO to enable the Lift_Futaba_S3003_STATUS_FIFOFULL
                   bit to be set on FIFO full. */
            Lift_Futaba_S3003_ClearFIFO();
        #endif
    #endif
}


/*******************************************************************************
* Function Name: Lift_Futaba_S3003_Enable
********************************************************************************
*
* Summary: 
*  Enables the PWM block operation
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Side Effects: 
*  This works only if software enable mode is chosen
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (Lift_Futaba_S3003_UsingFixedFunction)
        Lift_Futaba_S3003_GLOBAL_ENABLE |= Lift_Futaba_S3003_BLOCK_EN_MASK;
        Lift_Futaba_S3003_GLOBAL_STBY_ENABLE |= Lift_Futaba_S3003_BLOCK_STBY_EN_MASK;
    #endif 
    
    /* Enable the PWM from the control register  */
    #if (Lift_Futaba_S3003_UseControl || Lift_Futaba_S3003_UsingFixedFunction)
        Lift_Futaba_S3003_CONTROL |= Lift_Futaba_S3003_CTRL_ENABLE;
    #endif
}


/*******************************************************************************
* Function Name: Lift_Futaba_S3003_Stop
********************************************************************************
*
* Summary:
*  The stop function halts the PWM, but does not change any modes or disable
*  interrupts.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects:
*  If the Enable mode is set to Hardware only then this function
*  has no effect on the operation of the PWM
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_Stop(void) 
{
    #if (Lift_Futaba_S3003_UseControl || Lift_Futaba_S3003_UsingFixedFunction)
        Lift_Futaba_S3003_CONTROL &= ~Lift_Futaba_S3003_CTRL_ENABLE;
    #endif
    
    /* Globally disable the Fixed Function Block chosen */
    #if (Lift_Futaba_S3003_UsingFixedFunction)
        Lift_Futaba_S3003_GLOBAL_ENABLE &= ~Lift_Futaba_S3003_BLOCK_EN_MASK;
        Lift_Futaba_S3003_GLOBAL_STBY_ENABLE &= ~Lift_Futaba_S3003_BLOCK_STBY_EN_MASK;
    #endif
}


#if (Lift_Futaba_S3003_UseOneCompareMode)
#if (Lift_Futaba_S3003_CompareMode1SW)
/*******************************************************************************
* Function Name: Lift_Futaba_S3003_SetCompareMode
********************************************************************************
* 
* Summary:
*  This function writes the Compare Mode for the pwm output when in Dither mode,
*  Center Align Mode or One Output Mode.
*
* Parameters:
*  comparemode:  The new compare mode for the PWM output. Use the compare types
*                defined in the H file as input arguments.
*
* Return:
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_SetCompareMode(uint8 comparemode) 
{
    #if(Lift_Futaba_S3003_UsingFixedFunction)
            #if(Lift_Futaba_S3003_PSOC3_ES2 || Lift_Futaba_S3003_PSOC5_ES1)
                        uint8 comparemodemasked = (comparemode << Lift_Futaba_S3003_CTRL_CMPMODE1_SHIFT);
                        Lift_Futaba_S3003_CONTROL2 &= ~Lift_Futaba_S3003_CTRL_CMPMODE1_MASK; /*Clear Existing Data */
                        Lift_Futaba_S3003_CONTROL2 |= comparemodemasked;  
                #endif
                
            #if(Lift_Futaba_S3003_PSOC3_ES3 || Lift_Futaba_S3003_PSOC5_ES2)
                    uint8 comparemodemasked = (comparemode << Lift_Futaba_S3003_CTRL_CMPMODE1_SHIFT);
            Lift_Futaba_S3003_CONTROL3 &= ~Lift_Futaba_S3003_CTRL_CMPMODE1_MASK; /*Clear Existing Data */
            Lift_Futaba_S3003_CONTROL3 |= comparemodemasked;     
                #endif
                
    #elif (Lift_Futaba_S3003_UseControl)
        uint8 comparemode1masked = (comparemode << Lift_Futaba_S3003_CTRL_CMPMODE1_SHIFT) & Lift_Futaba_S3003_CTRL_CMPMODE1_MASK;
        uint8 comparemode2masked = (comparemode << Lift_Futaba_S3003_CTRL_CMPMODE2_SHIFT) & Lift_Futaba_S3003_CTRL_CMPMODE2_MASK;
        Lift_Futaba_S3003_CONTROL &= ~(Lift_Futaba_S3003_CTRL_CMPMODE1_MASK | Lift_Futaba_S3003_CTRL_CMPMODE2_MASK); /*Clear existing mode */
        Lift_Futaba_S3003_CONTROL |= (comparemode1masked | comparemode2masked);
        
    #else
        uint8 temp = comparemode;
    #endif
}
#endif /* Lift_Futaba_S3003_CompareMode1SW */

#else /* UseOneCompareMode */


#if (Lift_Futaba_S3003_CompareMode1SW)
/*******************************************************************************
* Function Name: Lift_Futaba_S3003_SetCompareMode1
********************************************************************************
* 
* Summary:
*  This function writes the Compare Mode for the pwm or pwm1 output
*
* Parameters:  
*  comparemode:  The new compare mode for the PWM output. Use the compare types
*                defined in the H file as input arguments.
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_SetCompareMode1(uint8 comparemode) 
{
    uint8 comparemodemasked = (comparemode << Lift_Futaba_S3003_CTRL_CMPMODE1_SHIFT) & Lift_Futaba_S3003_CTRL_CMPMODE1_MASK;
    #if(Lift_Futaba_S3003_UsingFixedFunction)
            #if(Lift_Futaba_S3003_PSOC3_ES2 || Lift_Futaba_S3003_PSOC5_ES1)
                        Lift_Futaba_S3003_CONTROL2 &= Lift_Futaba_S3003_CTRL_CMPMODE1_MASK; /*Clear existing mode */
                        Lift_Futaba_S3003_CONTROL2 |= comparemodemasked; 
            #endif
                
                #if(Lift_Futaba_S3003_PSOC3_ES3 || Lift_Futaba_S3003_PSOC5_ES2)
                    Lift_Futaba_S3003_CONTROL3 &= Lift_Futaba_S3003_CTRL_CMPMODE1_MASK; /*Clear existing mode */
                        Lift_Futaba_S3003_CONTROL3 |= comparemodemasked; 
            #endif
                
    #elif (Lift_Futaba_S3003_UseControl)
        Lift_Futaba_S3003_CONTROL &= Lift_Futaba_S3003_CTRL_CMPMODE1_MASK; /*Clear existing mode */
        Lift_Futaba_S3003_CONTROL |= comparemodemasked;
    #endif    
}
#endif /* Lift_Futaba_S3003_CompareMode1SW */


#if (Lift_Futaba_S3003_CompareMode2SW)
/*******************************************************************************
* Function Name: Lift_Futaba_S3003_SetCompareMode2
********************************************************************************
* 
* Summary:
*  This function writes the Compare Mode for the pwm or pwm2 output
*
* Parameters:  
*  comparemode:  The new compare mode for the PWM output. Use the compare types
*                defined in the H file as input arguments.
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_SetCompareMode2(uint8 comparemode) 
{
    #if(Lift_Futaba_S3003_UsingFixedFunction)
        /* Do Nothing because there is no second Compare Mode Register in FF block*/ 
    #elif (Lift_Futaba_S3003_UseControl)
    uint8 comparemodemasked = (comparemode << Lift_Futaba_S3003_CTRL_CMPMODE2_SHIFT) & Lift_Futaba_S3003_CTRL_CMPMODE2_MASK;
    Lift_Futaba_S3003_CONTROL &= Lift_Futaba_S3003_CTRL_CMPMODE2_MASK; /*Clear existing mode */
    Lift_Futaba_S3003_CONTROL |= comparemodemasked;
    #endif    
}
#endif /*Lift_Futaba_S3003_CompareMode2SW */
#endif /* UseOneCompareMode */


/*******************************************************************************
* Function Name: Lift_Futaba_S3003_WriteCounter
********************************************************************************
* 
* Summary:
*  This function is used to change the counter value.
*
* Parameters:  
*  counter:  This value may be between 1 and (2^Resolution)-1.   
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_WriteCounter(uint16 counter) 
{
    #if(Lift_Futaba_S3003_UsingFixedFunction)
        CY_SET_REG16(Lift_Futaba_S3003_COUNTER_LSB_PTR, (uint16)counter);
    #else
        CY_SET_REG16(Lift_Futaba_S3003_COUNTER_LSB_PTR, counter);
    #endif
}


#if (!Lift_Futaba_S3003_UsingFixedFunction)
/*******************************************************************************
* Function Name: Lift_Futaba_S3003_ReadCounter
********************************************************************************
* 
* Summary:
*  This function returns the current value of the counter.  It doesn't matter
*  if the counter is enabled or running.
*
* Parameters:  
*  void  
*
* Return: 
*  The current value of the counter.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
uint16 Lift_Futaba_S3003_ReadCounter(void) 
{
    /* Force capture by reading Accumulator */
    /* Must first do a software capture to be able to read the counter */
    /* It is up to the user code to make sure there isn't already captured data in the FIFO */
    CY_GET_REG8(Lift_Futaba_S3003_COUNTERCAP_LSB_PTR);
    
    /* Read the data from the FIFO (or capture register for Fixed Function)*/
    return (CY_GET_REG16(Lift_Futaba_S3003_CAPTURE_LSB_PTR));
}


#if (Lift_Futaba_S3003_UseStatus)
/*******************************************************************************
* Function Name: Lift_Futaba_S3003_ClearFIFO
********************************************************************************
* 
* Summary:
*  This function clears all capture data from the capture FIFO
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_ClearFIFO(void) 
{
    while(Lift_Futaba_S3003_ReadStatusRegister() & Lift_Futaba_S3003_STATUS_FIFONEMPTY)
        Lift_Futaba_S3003_ReadCapture();
}
#endif /* Lift_Futaba_S3003_UseStatus */
#endif /* !Lift_Futaba_S3003_UsingFixedFunction */


/*******************************************************************************
* Function Name: Lift_Futaba_S3003_WritePeriod
********************************************************************************
* 
* Summary:
*  This function is used to change the period of the counter.  The new period 
*  will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period:  Period value. May be between 1 and (2^Resolution)-1.  A value of 0 
*           will result in the counter remaining at zero.
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_WritePeriod(uint16 period) 
{
    #if(Lift_Futaba_S3003_UsingFixedFunction)
        CY_SET_REG16(Lift_Futaba_S3003_PERIOD_LSB_PTR, (uint16)period);
    #else
        CY_SET_REG16(Lift_Futaba_S3003_PERIOD_LSB_PTR, period);
    #endif
}


#if (Lift_Futaba_S3003_UseOneCompareMode)
/*******************************************************************************
* Function Name: Lift_Futaba_S3003_WriteCompare
********************************************************************************
* 
* Summary:
*  This funtion is used to change the compare1 value when the PWM is in Dither
*  mode. The compare output will reflect the new value on the next UDB clock. 
*  The compare output will be driven high when the present counter value is 
*  compared to the compare value based on the compare mode defined in 
*  Dither Mode.
*
* Parameters:  
*  compare:  New compare value.  
*
* Return: 
*  void
*
* Side Effects:
*  This function is only available if the PWM mode parameter is set to
*  Dither Mode, Center Aligned Mode or One Output Mode
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_WriteCompare(uint16 compare) 
{
   CY_SET_REG16(Lift_Futaba_S3003_COMPARE1_LSB_PTR, compare);
   #if (Lift_Futaba_S3003_PWMMode == Lift_Futaba_S3003__B_PWM__DITHER)
        CY_SET_REG16(Lift_Futaba_S3003_COMPARE2_LSB_PTR, compare+1);
   #endif
}


#else


/*******************************************************************************
* Function Name: Lift_Futaba_S3003_WriteCompare1
********************************************************************************
* 
* Summary:
*  This funtion is used to change the compare1 value.  The compare output will 
*  reflect the new value on the next UDB clock.  The compare output will be 
*  driven high when the present counter value is less than or less than or 
*  equal to the compare register, depending on the mode.
*
* Parameters:  
*  compare:  New compare value.  
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_WriteCompare1(uint16 compare) 
{
    #if(Lift_Futaba_S3003_UsingFixedFunction)
        CY_SET_REG16(Lift_Futaba_S3003_COMPARE1_LSB_PTR, (uint16)compare);
    #else
        CY_SET_REG16(Lift_Futaba_S3003_COMPARE1_LSB_PTR, compare);
    #endif
}


/*******************************************************************************
* Function Name: Lift_Futaba_S3003_WriteCompare2
********************************************************************************
* 
* Summary:
*  This funtion is used to change the compare value, for compare1 output.  
*  The compare output will reflect the new value on the next UDB clock.  
*  The compare output will be driven high when the present counter value is 
*  less than or less than or equal to the compare register, depending on the 
*  mode.
*
* Parameters:  
*  compare:  New compare value.  
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_WriteCompare2(uint16 compare) 
{
    #if(Lift_Futaba_S3003_UsingFixedFunction)
        CY_SET_REG16(Lift_Futaba_S3003_COMPARE2_LSB_PTR, compare);
    #else
        CY_SET_REG16(Lift_Futaba_S3003_COMPARE2_LSB_PTR, compare);
    #endif
}
#endif /* UseOneCompareMode */


#if (Lift_Futaba_S3003_DeadBandUsed)
/*******************************************************************************
* Function Name: Lift_Futaba_S3003_WriteDeadTime
********************************************************************************
* 
* Summary:
*  This function writes the dead-band counts to the corresponding register
*
* Parameters:  
*  deadtime:  Number of counts for dead time 
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_WriteDeadTime(uint8 deadtime) 
{
    /* If using the Dead Band 1-255 mode then just write the register */
    #if(!Lift_Futaba_S3003_DeadBand2_4)
        CY_SET_REG8(Lift_Futaba_S3003_DEADBAND_COUNT_PTR, deadtime);
    #else
        /* Otherwise the data has to be masked and offset */        
        /* Clear existing data */
        Lift_Futaba_S3003_DEADBAND_COUNT &= ~Lift_Futaba_S3003_DEADBAND_COUNT_MASK; 
            /* Set new dead time */
        Lift_Futaba_S3003_DEADBAND_COUNT |= (deadtime << Lift_Futaba_S3003_DEADBAND_COUNT_SHIFT) & Lift_Futaba_S3003_DEADBAND_COUNT_MASK; 
    #endif
}


/*******************************************************************************
* Function Name: Lift_Futaba_S3003_ReadDeadTime
********************************************************************************
* 
* Summary:
*  This function reads the dead-band counts from the corresponding register
*
* Parameters:  
*  void
*
* Return: 
*  Dead Band Counts
*
* Reentrant:
*  Yes
*
*******************************************************************************/
uint8 Lift_Futaba_S3003_ReadDeadTime(void) 
{
    /* If using the Dead Band 1-255 mode then just read the register */
    #if(!Lift_Futaba_S3003_DeadBand2_4)
        return (CY_GET_REG8(Lift_Futaba_S3003_DEADBAND_COUNT_PTR));
    #else
        /* Otherwise the data has to be masked and offset */
        return ((Lift_Futaba_S3003_DEADBAND_COUNT & Lift_Futaba_S3003_DEADBAND_COUNT_MASK) >> Lift_Futaba_S3003_DEADBAND_COUNT_SHIFT);
    #endif
}
#endif /* DeadBandUsed */

