/*******************************************************************************
* File Name: Lift_Futaba_S3003.h  
* Version 2.10
*
* Description:
*  Contains the prototypes and constants for the functions available to the 
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

#if !defined(CY_PWM_Lift_Futaba_S3003_H)
#define CY_PWM_Lift_Futaba_S3003_H


/***************************************
* Conditional Compilation Parameters
***************************************/
#define Lift_Futaba_S3003_Resolution 16u
#define Lift_Futaba_S3003_UsingFixedFunction 0u
#define Lift_Futaba_S3003_DeadBandMode 0u
#define Lift_Futaba_S3003_KillModeMinTime 0u
#define Lift_Futaba_S3003_KillMode 0u
#define Lift_Futaba_S3003_PWMMode 0u
#define Lift_Futaba_S3003_PWMModeIsCenterAligned 0u
#define Lift_Futaba_S3003_DeadBandUsed 0u
#define Lift_Futaba_S3003_DeadBand2_4 0u
#if !defined(Lift_Futaba_S3003_PWMUDB_sSTSReg_stsreg__REMOVED)
    #define Lift_Futaba_S3003_UseStatus 1u
#else
    #define Lift_Futaba_S3003_UseStatus 0u
#endif
#if !defined(Lift_Futaba_S3003_PWMUDB_sCTRLReg_ctrlreg__REMOVED)
    #define Lift_Futaba_S3003_UseControl 1u
#else
    #define Lift_Futaba_S3003_UseControl 0u
#endif
#define Lift_Futaba_S3003_UseOneCompareMode 1u
#define Lift_Futaba_S3003_MinimumKillTime 1u
#define Lift_Futaba_S3003_EnableMode 0u

#define Lift_Futaba_S3003_CompareMode1SW 0u
#define Lift_Futaba_S3003_CompareMode2SW 0u

/* PSoC3 ES2 or early */
#define Lift_Futaba_S3003_PSOC3_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)   && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))

/* PSoC5 ES1 or early */
#define Lift_Futaba_S3003_PSOC5_ES1   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)   && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))

/* PSoC3 ES3 or later */
#define Lift_Futaba_S3003_PSOC3_ES3   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                     (CYDEV_CHIP_REVISION_USED >= CYDEV_CHIP_REVISION_3A_ES3))

/* PSoC5 ES2 or later */
#define Lift_Futaba_S3003_PSOC5_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)   && \
                                     (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))

/* Use Kill Mode Enumerated Types */
#define Lift_Futaba_S3003__B_PWM__DISABLED 0
#define Lift_Futaba_S3003__B_PWM__ASYNCHRONOUS 1
#define Lift_Futaba_S3003__B_PWM__SINGLECYCLE 2
#define Lift_Futaba_S3003__B_PWM__LATCHED 3
#define Lift_Futaba_S3003__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define Lift_Futaba_S3003__B_PWM__DBMDISABLED 0
#define Lift_Futaba_S3003__B_PWM__DBM_2_4_CLOCKS 1
#define Lift_Futaba_S3003__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define Lift_Futaba_S3003__B_PWM__ONE_OUTPUT 0
#define Lift_Futaba_S3003__B_PWM__TWO_OUTPUTS 1
#define Lift_Futaba_S3003__B_PWM__DUAL_EDGE 2
#define Lift_Futaba_S3003__B_PWM__CENTER_ALIGN 3
#define Lift_Futaba_S3003__B_PWM__DITHER 5
#define Lift_Futaba_S3003__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define Lift_Futaba_S3003__B_PWM__LESS_THAN 1
#define Lift_Futaba_S3003__B_PWM__LESS_THAN_OR_EQUAL 2
#define Lift_Futaba_S3003__B_PWM__GREATER_THAN 3
#define Lift_Futaba_S3003__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define Lift_Futaba_S3003__B_PWM__EQUAL 0
#define Lift_Futaba_S3003__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/

/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct Lift_Futaba_S3003_backupStruct
{
    
    uint8 PWMEnableState;
       
    #if(!Lift_Futaba_S3003_UsingFixedFunction)
        #if (Lift_Futaba_S3003_PSOC3_ES2 || Lift_Futaba_S3003_PSOC5_ES1)
            uint16 PWMUdb;               /* PWM Current Counter value  */
            uint16 PWMPeriod;            /* PWM Current Period value   */
            #if (Lift_Futaba_S3003_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif
            #if(Lift_Futaba_S3003_UseOneCompareMode)
                uint16 PWMCompareValue;     /* PWM Current Compare value */
            #else
                uint16 PWMCompareValue1;     /* PWM Current Compare value1 */
                uint16 PWMCompareValue2;     /* PWM Current Compare value2 */
            #endif
            
            /* Backup for Deadband parameters */
            #if(Lift_Futaba_S3003_DeadBandMode == Lift_Futaba_S3003__B_PWM__DBM_256_CLOCKS || Lift_Futaba_S3003_DeadBandMode == Lift_Futaba_S3003__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif
            
            /* Backup Kill Mode Counter*/
            #if(Lift_Futaba_S3003_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif
            
        #endif
        
        #if (Lift_Futaba_S3003_PSOC3_ES3 || Lift_Futaba_S3003_PSOC5_ES2)
            uint16 PWMUdb;               /* PWM Current Counter value  */
            #if(!Lift_Futaba_S3003_PWMModeIsCenterAligned)
                uint16 PWMPeriod;
            #endif
            #if (Lift_Futaba_S3003_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif
            
            /* Backup for Deadband parameters */
            #if(Lift_Futaba_S3003_DeadBandMode == Lift_Futaba_S3003__B_PWM__DBM_256_CLOCKS || Lift_Futaba_S3003_DeadBandMode == Lift_Futaba_S3003__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif
            
            /* Backup Kill Mode Counter*/
            #if(Lift_Futaba_S3003_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif
        #endif
        
        
        /* Backup control register */
        #if(Lift_Futaba_S3003_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif
        
    #endif 
   
}Lift_Futaba_S3003_backupStruct;

/***************************************
*        Function Prototypes
 **************************************/
 
void    Lift_Futaba_S3003_Start(void);
void    Lift_Futaba_S3003_Stop(void) ;
#if (Lift_Futaba_S3003_UseStatus || Lift_Futaba_S3003_UsingFixedFunction)
    #define Lift_Futaba_S3003_SetInterruptMode(interruptMode) CY_SET_REG8(Lift_Futaba_S3003_STATUS_MASK_PTR, interruptMode)
    #define Lift_Futaba_S3003_ReadStatusRegister() CY_GET_REG8(Lift_Futaba_S3003_STATUS_PTR)
#endif
#define Lift_Futaba_S3003_GetInterruptSource() Lift_Futaba_S3003_ReadStatusRegister()
#if (Lift_Futaba_S3003_UseControl)
    #define Lift_Futaba_S3003_ReadControlRegister() CY_GET_REG8(Lift_Futaba_S3003_CONTROL_PTR) 
    #define Lift_Futaba_S3003_WriteControlRegister(control) CY_SET_REG8(Lift_Futaba_S3003_CONTROL_PTR, control)
#endif
#if (Lift_Futaba_S3003_UseOneCompareMode)
   #if (Lift_Futaba_S3003_CompareMode1SW)
       void    Lift_Futaba_S3003_SetCompareMode(uint8 comparemode) ;
   #endif
#else
    #if (Lift_Futaba_S3003_CompareMode1SW)
        void    Lift_Futaba_S3003_SetCompareMode1(uint8 comparemode) ;
    #endif
    #if (Lift_Futaba_S3003_CompareMode2SW)
        void    Lift_Futaba_S3003_SetCompareMode2(uint8 comparemode) ;
    #endif
#endif

#if (!Lift_Futaba_S3003_UsingFixedFunction)
    uint16   Lift_Futaba_S3003_ReadCounter(void) ;
    #define Lift_Futaba_S3003_ReadCapture() CY_GET_REG16(Lift_Futaba_S3003_CAPTURE_LSB_PTR)
    #if (Lift_Futaba_S3003_UseStatus)
        void Lift_Futaba_S3003_ClearFIFO(void) ;
    #endif
#endif

void    Lift_Futaba_S3003_WriteCounter(uint16 counter) ;
void    Lift_Futaba_S3003_WritePeriod(uint16 period) ;
#define Lift_Futaba_S3003_ReadPeriod() CY_GET_REG16(Lift_Futaba_S3003_PERIOD_LSB_PTR) 
#if (Lift_Futaba_S3003_UseOneCompareMode)
    void    Lift_Futaba_S3003_WriteCompare(uint16 compare) ;
    #define Lift_Futaba_S3003_ReadCompare() CY_GET_REG16(Lift_Futaba_S3003_COMPARE1_LSB_PTR) 
#else
    void    Lift_Futaba_S3003_WriteCompare1(uint16 compare) ;
    #define Lift_Futaba_S3003_ReadCompare1() CY_GET_REG16(Lift_Futaba_S3003_COMPARE1_LSB_PTR) 
    void    Lift_Futaba_S3003_WriteCompare2(uint16 compare) ;
    #define Lift_Futaba_S3003_ReadCompare2() CY_GET_REG16(Lift_Futaba_S3003_COMPARE2_LSB_PTR) 
#endif


#if (Lift_Futaba_S3003_DeadBandUsed)
    void    Lift_Futaba_S3003_WriteDeadTime(uint8 deadtime) ;
    uint8   Lift_Futaba_S3003_ReadDeadTime(void) ;
#endif

#if ( Lift_Futaba_S3003_KillModeMinTime)
    #define Lift_Futaba_S3003_WriteKillTime(killtime) CY_SET_REG8(Lift_Futaba_S3003_KILLMODEMINTIME_PTR, killtime) 
    #define Lift_Futaba_S3003_ReadKillTime() CY_GET_REG8(Lift_Futaba_S3003_KILLMODEMINTIME_PTR) 
#endif

void Lift_Futaba_S3003_Init(void) ;
void Lift_Futaba_S3003_Enable(void) ;
void Lift_Futaba_S3003_Sleep(void);
void Lift_Futaba_S3003_Wakeup(void) ;
void Lift_Futaba_S3003_SaveConfig(void);
void Lift_Futaba_S3003_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define Lift_Futaba_S3003_INIT_PERIOD_VALUE        434u
#define Lift_Futaba_S3003_INIT_COMPARE_VALUE1      410u
#define Lift_Futaba_S3003_INIT_COMPARE_VALUE2      401u
#define Lift_Futaba_S3003_INIT_INTERRUPTS_MODE     ((0u << Lift_Futaba_S3003_STATUS_TC_INT_EN_MASK_SHIFT) | (0 << Lift_Futaba_S3003_STATUS_CMP2_INT_EN_MASK_SHIFT) | (0 << Lift_Futaba_S3003_STATUS_CMP1_INT_EN_MASK_SHIFT ) | (0 << Lift_Futaba_S3003_STATUS_KILL_INT_EN_MASK_SHIFT ))
#define Lift_Futaba_S3003_DEFAULT_COMPARE2_MODE    (1u << Lift_Futaba_S3003_CTRL_CMPMODE2_SHIFT)
#define Lift_Futaba_S3003_DEFAULT_COMPARE1_MODE    (4u << Lift_Futaba_S3003_CTRL_CMPMODE1_SHIFT)
#define Lift_Futaba_S3003_INIT_DEAD_TIME           1u


/********************************
*         Registers
******************************** */

#if (Lift_Futaba_S3003_UsingFixedFunction)
   #define Lift_Futaba_S3003_PERIOD_LSB          (*(reg16 *) Lift_Futaba_S3003_PWMHW__PER0)
   #define Lift_Futaba_S3003_PERIOD_LSB_PTR      ( (reg16 *) Lift_Futaba_S3003_PWMHW__PER0)
   #define Lift_Futaba_S3003_COMPARE1_LSB        (*(reg16 *) Lift_Futaba_S3003_PWMHW__CNT_CMP0)
   #define Lift_Futaba_S3003_COMPARE1_LSB_PTR    ( (reg16 *) Lift_Futaba_S3003_PWMHW__CNT_CMP0)
   #define Lift_Futaba_S3003_COMPARE2_LSB        0x00u
   #define Lift_Futaba_S3003_COMPARE2_LSB_PTR    0x00u
   #define Lift_Futaba_S3003_COUNTER_LSB         (*(reg16 *) Lift_Futaba_S3003_PWMHW__CNT_CMP0)
   #define Lift_Futaba_S3003_COUNTER_LSB_PTR     ( (reg16 *) Lift_Futaba_S3003_PWMHW__CNT_CMP0)
   #define Lift_Futaba_S3003_CAPTURE_LSB         (*(reg16 *) Lift_Futaba_S3003_PWMHW__CAP0)
   #define Lift_Futaba_S3003_CAPTURE_LSB_PTR     ( (reg16 *) Lift_Futaba_S3003_PWMHW__CAP0)
   #define Lift_Futaba_S3003_RT1                 (*(reg8 *)  Lift_Futaba_S3003_PWMHW__RT1)
   #define Lift_Futaba_S3003_RT1_PTR             ( (reg8 *)  Lift_Futaba_S3003_PWMHW__RT1)
      
#else
   #if(Lift_Futaba_S3003_PWMModeIsCenterAligned)
       #define Lift_Futaba_S3003_PERIOD_LSB      (*(reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__D1_REG)
       #define Lift_Futaba_S3003_PERIOD_LSB_PTR   ((reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__D1_REG)
   #else
       #define Lift_Futaba_S3003_PERIOD_LSB      (*(reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__F0_REG)
       #define Lift_Futaba_S3003_PERIOD_LSB_PTR   ((reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__F0_REG)
   #endif
   #define Lift_Futaba_S3003_COMPARE1_LSB    (*(reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__D0_REG)
   #define Lift_Futaba_S3003_COMPARE1_LSB_PTR ((reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__D0_REG)
   #define Lift_Futaba_S3003_COMPARE2_LSB    (*(reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__D1_REG)
   #define Lift_Futaba_S3003_COMPARE2_LSB_PTR ((reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__D1_REG)
   #define Lift_Futaba_S3003_COUNTERCAP_LSB   *(reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__A1_REG)
   #define Lift_Futaba_S3003_COUNTERCAP_LSB_PTR ((reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__A1_REG)
   #define Lift_Futaba_S3003_COUNTER_LSB     (*(reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__A0_REG)
   #define Lift_Futaba_S3003_COUNTER_LSB_PTR  ((reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__A0_REG)
   #define Lift_Futaba_S3003_CAPTURE_LSB     (*(reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__F1_REG)
   #define Lift_Futaba_S3003_CAPTURE_LSB_PTR  ((reg16 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__F1_REG)
   #define Lift_Futaba_S3003_AUX_CONTROLDP0      (*(reg8 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__DP_AUX_CTL_REG)
   #define Lift_Futaba_S3003_AUX_CONTROLDP0_PTR  ((reg8 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u0__DP_AUX_CTL_REG)
   #if (Lift_Futaba_S3003_Resolution == 16)
       #define Lift_Futaba_S3003_AUX_CONTROLDP1    (*(reg8 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u1__DP_AUX_CTL_REG)
       #define Lift_Futaba_S3003_AUX_CONTROLDP1_PTR  ((reg8 *) Lift_Futaba_S3003_PWMUDB_sP16_pwmdp_u1__DP_AUX_CTL_REG)
   #endif
#endif
   
#if(Lift_Futaba_S3003_KillModeMinTime )
    #define Lift_Futaba_S3003_KILLMODEMINTIME      (*(reg8 *) Lift_Futaba_S3003_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define Lift_Futaba_S3003_KILLMODEMINTIME_PTR   ((reg8 *) Lift_Futaba_S3003_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif

#if(Lift_Futaba_S3003_DeadBandMode == Lift_Futaba_S3003__B_PWM__DBM_256_CLOCKS)
    #define Lift_Futaba_S3003_DEADBAND_COUNT        (*(reg8 *) Lift_Futaba_S3003_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define Lift_Futaba_S3003_DEADBAND_COUNT_PTR     ((reg8 *) Lift_Futaba_S3003_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define Lift_Futaba_S3003_DEADBAND_LSB_PTR       ((reg8 *) Lift_Futaba_S3003_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define Lift_Futaba_S3003_DEADBAND_LSB          (*(reg8 *) Lift_Futaba_S3003_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(Lift_Futaba_S3003_DeadBandMode == Lift_Futaba_S3003__B_PWM__DBM_2_4_CLOCKS)
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (Lift_Futaba_S3003_UsingFixedFunction)
        #define Lift_Futaba_S3003_DEADBAND_COUNT        (*(reg8 *) Lift_Futaba_S3003_PWMHW__CFG0) 
        #define Lift_Futaba_S3003_DEADBAND_COUNT_PTR     ((reg8 *) Lift_Futaba_S3003_PWMHW__CFG0)
        #define Lift_Futaba_S3003_DEADBAND_COUNT_MASK    (0x03u << Lift_Futaba_S3003_DEADBAND_COUNT_SHIFT) 
        #define Lift_Futaba_S3003_DEADBAND_COUNT_SHIFT   0x06u /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */ 
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define Lift_Futaba_S3003_DEADBAND_COUNT        (*(reg8 *) Lift_Futaba_S3003_PWMUDB_sDB3_AsyncCtl_dbctrlreg__CONTROL_REG)
        #define Lift_Futaba_S3003_DEADBAND_COUNT_PTR     ((reg8 *) Lift_Futaba_S3003_PWMUDB_sDB3_AsyncCtl_dbctrlreg__CONTROL_REG)
        #define Lift_Futaba_S3003_DEADBAND_COUNT_MASK    (0x03u << Lift_Futaba_S3003_DEADBAND_COUNT_SHIFT) 
        #define Lift_Futaba_S3003_DEADBAND_COUNT_SHIFT   0x00u /* As defined by the verilog implementation of the Control Register */
    #endif
#endif



#if (Lift_Futaba_S3003_UsingFixedFunction)
    #define Lift_Futaba_S3003_STATUS                (*(reg8 *) Lift_Futaba_S3003_PWMHW__SR0)
    #define Lift_Futaba_S3003_STATUS_PTR            ((reg8 *) Lift_Futaba_S3003_PWMHW__SR0)
    #define Lift_Futaba_S3003_STATUS_MASK           (*(reg8 *) Lift_Futaba_S3003_PWMHW__SR0)
    #define Lift_Futaba_S3003_STATUS_MASK_PTR       ((reg8 *) Lift_Futaba_S3003_PWMHW__SR0)
    #define Lift_Futaba_S3003_CONTROL               (*(reg8 *) Lift_Futaba_S3003_PWMHW__CFG0)
    #define Lift_Futaba_S3003_CONTROL_PTR           ((reg8 *) Lift_Futaba_S3003_PWMHW__CFG0)    
    #define Lift_Futaba_S3003_CONTROL2              (*(reg8 *) Lift_Futaba_S3003_PWMHW__CFG1)    
    #if(Lift_Futaba_S3003_PSOC3_ES3 || Lift_Futaba_S3003_PSOC5_ES2)
        #define Lift_Futaba_S3003_CONTROL3              (*(reg8 *) Lift_Futaba_S3003_PWMHW__CFG2)
    #endif
    #define Lift_Futaba_S3003_GLOBAL_ENABLE         (*(reg8 *) Lift_Futaba_S3003_PWMHW__PM_ACT_CFG)
    #define Lift_Futaba_S3003_GLOBAL_ENABLE_PTR       ( (reg8 *) Lift_Futaba_S3003_PWMHW__PM_ACT_CFG)
    #define Lift_Futaba_S3003_GLOBAL_STBY_ENABLE      (*(reg8 *) Lift_Futaba_S3003_PWMHW__PM_STBY_CFG)
    #define Lift_Futaba_S3003_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) Lift_Futaba_S3003_PWMHW__PM_STBY_CFG)
  
  
    /***********************************
    *          Constants
    ***********************************/
    /* Fixed Function Block Chosen */
    #define Lift_Futaba_S3003_BLOCK_EN_MASK          Lift_Futaba_S3003_PWMHW__PM_ACT_MSK
    #define Lift_Futaba_S3003_BLOCK_STBY_EN_MASK     Lift_Futaba_S3003_PWMHW__PM_STBY_MSK 
    /* Control Register definitions */
    #define Lift_Futaba_S3003_CTRL_ENABLE_SHIFT      0x00u
    
    #if(Lift_Futaba_S3003_PSOC3_ES2 || Lift_Futaba_S3003_PSOC5_ES1)
        #define Lift_Futaba_S3003_CTRL_CMPMODE1_SHIFT    0x01u   /* As defined by Register map as MODE_CFG bits in CFG1*/
    #endif
    #if(Lift_Futaba_S3003_PSOC3_ES3 || Lift_Futaba_S3003_PSOC5_ES2)
        #define Lift_Futaba_S3003_CTRL_CMPMODE1_SHIFT    0x04u  /* As defined by Register map as MODE_CFG bits in CFG2*/
    #endif
    
    #define Lift_Futaba_S3003_CTRL_DEAD_TIME_SHIFT   0x06u   /* As defined by Register map */
    /* Fixed Function Block Only CFG register bit definitions */
    #define Lift_Futaba_S3003_CFG0_MODE              0x02u   /*  Set to compare mode */
    //#define Lift_Futaba_S3003_CFG0_ENABLE            0x01u   /* Enable the block to run */
    #define Lift_Futaba_S3003_CFG0_DB                0x20u   /* As defined by Register map as DB bit in CFG0 */

    /* Control Register Bit Masks */
    #define Lift_Futaba_S3003_CTRL_ENABLE            (0x01u << Lift_Futaba_S3003_CTRL_ENABLE_SHIFT)
    #define Lift_Futaba_S3003_CTRL_RESET             (0x01u << Lift_Futaba_S3003_CTRL_RESET_SHIFT)
    #define Lift_Futaba_S3003_CTRL_CMPMODE2_MASK     (0x07u << Lift_Futaba_S3003_CTRL_CMPMODE2_SHIFT)
    #if(Lift_Futaba_S3003_PSOC3_ES2 || Lift_Futaba_S3003_PSOC5_ES1)
        #define Lift_Futaba_S3003_CTRL_CMPMODE1_MASK     (0x07u << Lift_Futaba_S3003_CTRL_CMPMODE1_SHIFT)
    #endif
    #if(Lift_Futaba_S3003_PSOC3_ES3 || Lift_Futaba_S3003_PSOC5_ES2)
        #define Lift_Futaba_S3003_CTRL_CMPMODE1_MASK     (0x07u << Lift_Futaba_S3003_CTRL_CMPMODE1_SHIFT)
    #endif
    
    /* Control2 Register Bit Masks */
    #define Lift_Futaba_S3003_CTRL2_IRQ_SEL_SHIFT    0x00u       /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define Lift_Futaba_S3003_CTRL2_IRQ_SEL          (0x01u << Lift_Futaba_S3003_CTRL2_IRQ_SEL_SHIFT)  
    
    /* Status Register Bit Locations */
    #define Lift_Futaba_S3003_STATUS_TC_SHIFT            0x07u   /* As defined by Register map as TC in SR0 */
    #define Lift_Futaba_S3003_STATUS_CMP1_SHIFT          0x06u   /* As defined by the Register map as CAP_CMP in SR0 */
    
    /* Status Register Interrupt Enable Bit Locations */
    #define Lift_Futaba_S3003_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)    
    #define Lift_Futaba_S3003_STATUS_TC_INT_EN_MASK_SHIFT            (Lift_Futaba_S3003_STATUS_TC_SHIFT - 4)
    #define Lift_Futaba_S3003_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)  
    #define Lift_Futaba_S3003_STATUS_CMP1_INT_EN_MASK_SHIFT          (Lift_Futaba_S3003_STATUS_CMP1_SHIFT - 4)
    
    /* Status Register Bit Masks */
    #define Lift_Futaba_S3003_STATUS_TC              (0x01u << Lift_Futaba_S3003_STATUS_TC_SHIFT)
    #define Lift_Futaba_S3003_STATUS_CMP1            (0x01u << Lift_Futaba_S3003_STATUS_CMP1_SHIFT)
    
    /* Status Register Interrupt Bit Masks*/
    #define Lift_Futaba_S3003_STATUS_TC_INT_EN_MASK              (Lift_Futaba_S3003_STATUS_TC >> 4)
    #define Lift_Futaba_S3003_STATUS_CMP1_INT_EN_MASK            (Lift_Futaba_S3003_STATUS_CMP1 >> 4)
    
    /*RT1 Synch Constants: Applicable for PSoC3 ES2/PSoC3 ES3 PSoC5 ES2*/
    #define Lift_Futaba_S3003_RT1_SHIFT              0x04u
    #define Lift_Futaba_S3003_RT1_MASK               (0x03u << Lift_Futaba_S3003_RT1_SHIFT)  /* Sync TC and CMP bit masks */
    #define Lift_Futaba_S3003_SYNC                   (0x03u << Lift_Futaba_S3003_RT1_SHIFT)
    #define Lift_Futaba_S3003_SYNCDSI_SHIFT          0x00u
    #define Lift_Futaba_S3003_SYNCDSI_MASK           (0x0Fu << Lift_Futaba_S3003_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define Lift_Futaba_S3003_SYNCDSI_EN             (0x0Fu << Lift_Futaba_S3003_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    

#else
    #define Lift_Futaba_S3003_STATUS                (*(reg8 *) Lift_Futaba_S3003_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define Lift_Futaba_S3003_STATUS_PTR            ((reg8 *) Lift_Futaba_S3003_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define Lift_Futaba_S3003_STATUS_MASK           (*(reg8 *) Lift_Futaba_S3003_PWMUDB_sSTSReg_nrstSts_stsreg__MASK_REG)
    #define Lift_Futaba_S3003_STATUS_MASK_PTR       ((reg8 *) Lift_Futaba_S3003_PWMUDB_sSTSReg_nrstSts_stsreg__MASK_REG)
    #define Lift_Futaba_S3003_STATUS_AUX_CTRL       (*(reg8 *) Lift_Futaba_S3003_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define Lift_Futaba_S3003_CONTROL               (*(reg8 *) Lift_Futaba_S3003_PWMUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG)
    #define Lift_Futaba_S3003_CONTROL_PTR           ((reg8 *) Lift_Futaba_S3003_PWMUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG)
    
    
    /***********************************
    *          Constants
    ***********************************/
    /* Control Register definitions */
    #define Lift_Futaba_S3003_CTRL_ENABLE_SHIFT      0x07u
    #define Lift_Futaba_S3003_CTRL_RESET_SHIFT       0x06u
    #define Lift_Futaba_S3003_CTRL_CMPMODE2_SHIFT    0x03u
    #define Lift_Futaba_S3003_CTRL_CMPMODE1_SHIFT    0x00u
    #define Lift_Futaba_S3003_CTRL_DEAD_TIME_SHIFT   0x00u   /* No Shift Needed for UDB block */
    /* Control Register Bit Masks */
    #define Lift_Futaba_S3003_CTRL_ENABLE            (0x01u << Lift_Futaba_S3003_CTRL_ENABLE_SHIFT)
    #define Lift_Futaba_S3003_CTRL_RESET             (0x01u << Lift_Futaba_S3003_CTRL_RESET_SHIFT)
    #define Lift_Futaba_S3003_CTRL_CMPMODE2_MASK     (0x07u << Lift_Futaba_S3003_CTRL_CMPMODE2_SHIFT)
    #define Lift_Futaba_S3003_CTRL_CMPMODE1_MASK     (0x07u << Lift_Futaba_S3003_CTRL_CMPMODE1_SHIFT) 
    
    /* Status Register Bit Locations */
    #define Lift_Futaba_S3003_STATUS_KILL_SHIFT          0x05u
    #define Lift_Futaba_S3003_STATUS_FIFONEMPTY_SHIFT    0x04u
    #define Lift_Futaba_S3003_STATUS_FIFOFULL_SHIFT      0x03u  
    #define Lift_Futaba_S3003_STATUS_TC_SHIFT            0x02u
    #define Lift_Futaba_S3003_STATUS_CMP2_SHIFT          0x01u
    #define Lift_Futaba_S3003_STATUS_CMP1_SHIFT          0x00u
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define Lift_Futaba_S3003_STATUS_KILL_INT_EN_MASK_SHIFT          Lift_Futaba_S3003_STATUS_KILL_SHIFT          
    #define Lift_Futaba_S3003_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    Lift_Futaba_S3003_STATUS_FIFONEMPTY_SHIFT    
    #define Lift_Futaba_S3003_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      Lift_Futaba_S3003_STATUS_FIFOFULL_SHIFT        
    #define Lift_Futaba_S3003_STATUS_TC_INT_EN_MASK_SHIFT            Lift_Futaba_S3003_STATUS_TC_SHIFT            
    #define Lift_Futaba_S3003_STATUS_CMP2_INT_EN_MASK_SHIFT          Lift_Futaba_S3003_STATUS_CMP2_SHIFT          
    #define Lift_Futaba_S3003_STATUS_CMP1_INT_EN_MASK_SHIFT          Lift_Futaba_S3003_STATUS_CMP1_SHIFT   
    /* Status Register Bit Masks */
    #define Lift_Futaba_S3003_STATUS_KILL            (0x00u << Lift_Futaba_S3003_STATUS_KILL_SHIFT )
    #define Lift_Futaba_S3003_STATUS_FIFOFULL        (0x01u << Lift_Futaba_S3003_STATUS_FIFOFULL_SHIFT)
    #define Lift_Futaba_S3003_STATUS_FIFONEMPTY      (0x01u << Lift_Futaba_S3003_STATUS_FIFONEMPTY_SHIFT)
    #define Lift_Futaba_S3003_STATUS_TC              (0x01u << Lift_Futaba_S3003_STATUS_TC_SHIFT)
    #define Lift_Futaba_S3003_STATUS_CMP2            (0x01u << Lift_Futaba_S3003_STATUS_CMP2_SHIFT) 
    #define Lift_Futaba_S3003_STATUS_CMP1            (0x01u << Lift_Futaba_S3003_STATUS_CMP1_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define Lift_Futaba_S3003_STATUS_KILL_INT_EN_MASK            Lift_Futaba_S3003_STATUS_KILL
    #define Lift_Futaba_S3003_STATUS_FIFOFULL_INT_EN_MASK        Lift_Futaba_S3003_STATUS_FIFOFULL
    #define Lift_Futaba_S3003_STATUS_FIFONEMPTY_INT_EN_MASK      Lift_Futaba_S3003_STATUS_FIFONEMPTY
    #define Lift_Futaba_S3003_STATUS_TC_INT_EN_MASK              Lift_Futaba_S3003_STATUS_TC
    #define Lift_Futaba_S3003_STATUS_CMP2_INT_EN_MASK            Lift_Futaba_S3003_STATUS_CMP2
    #define Lift_Futaba_S3003_STATUS_CMP1_INT_EN_MASK            Lift_Futaba_S3003_STATUS_CMP1
                                                          
    /* Datapath Auxillary Control Register definitions */
    #define Lift_Futaba_S3003_AUX_CTRL_FIFO0_CLR     0x01u
    #define Lift_Futaba_S3003_AUX_CTRL_FIFO1_CLR     0x02u
    #define Lift_Futaba_S3003_AUX_CTRL_FIFO0_LVL     0x04u
    #define Lift_Futaba_S3003_AUX_CTRL_FIFO1_LVL     0x08u
    #define Lift_Futaba_S3003_STATUS_ACTL_INT_EN_MASK  0x10u /* As defined for the ACTL Register */
#endif /* Lift_Futaba_S3003_UsingFixedFunction */

#endif  /* CY_PWM_Lift_Futaba_S3003_H */
