/*******************************************************************************
* File Name: Lift_Futaba_S3003_PM.c
* Version 2.10
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "Lift_Futaba_S3003.h"

static Lift_Futaba_S3003_backupStruct Lift_Futaba_S3003_backup;


/*******************************************************************************
* Function Name: Lift_Futaba_S3003_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Lift_Futaba_S3003_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Lift_Futaba_S3003_SaveConfig(void)
{
    
    #if(!Lift_Futaba_S3003_UsingFixedFunction)
        #if (Lift_Futaba_S3003_PSOC3_ES2 || Lift_Futaba_S3003_PSOC5_ES1)
            Lift_Futaba_S3003_backup.PWMUdb = Lift_Futaba_S3003_ReadCounter();
            Lift_Futaba_S3003_backup.PWMPeriod = Lift_Futaba_S3003_ReadPeriod();
            #if (Lift_Futaba_S3003_UseStatus)
                Lift_Futaba_S3003_backup.InterruptMaskValue = Lift_Futaba_S3003_STATUS_MASK;
            #endif
            
            #if(Lift_Futaba_S3003_UseOneCompareMode)
                Lift_Futaba_S3003_backup.PWMCompareValue = Lift_Futaba_S3003_ReadCompare();
            #else
                Lift_Futaba_S3003_backup.PWMCompareValue1 = Lift_Futaba_S3003_ReadCompare1();
                Lift_Futaba_S3003_backup.PWMCompareValue2 = Lift_Futaba_S3003_ReadCompare2();
            #endif
            
           #if(Lift_Futaba_S3003_DeadBandUsed)
                Lift_Futaba_S3003_backup.PWMdeadBandValue = Lift_Futaba_S3003_ReadDeadTime();
            #endif
          
            #if ( Lift_Futaba_S3003_KillModeMinTime)
                Lift_Futaba_S3003_backup.PWMKillCounterPeriod = Lift_Futaba_S3003_ReadKillTime();
            #endif
        #endif
        
        #if (Lift_Futaba_S3003_PSOC3_ES3 || Lift_Futaba_S3003_PSOC5_ES2)
            #if(!Lift_Futaba_S3003_PWMModeIsCenterAligned)
                Lift_Futaba_S3003_backup.PWMPeriod = Lift_Futaba_S3003_ReadPeriod();
            #endif
            Lift_Futaba_S3003_backup.PWMUdb = Lift_Futaba_S3003_ReadCounter();
            #if (Lift_Futaba_S3003_UseStatus)
                Lift_Futaba_S3003_backup.InterruptMaskValue = Lift_Futaba_S3003_STATUS_MASK;
            #endif
            
            #if(Lift_Futaba_S3003_DeadBandMode == Lift_Futaba_S3003__B_PWM__DBM_256_CLOCKS || Lift_Futaba_S3003_DeadBandMode == Lift_Futaba_S3003__B_PWM__DBM_2_4_CLOCKS)
                Lift_Futaba_S3003_backup.PWMdeadBandValue = Lift_Futaba_S3003_ReadDeadTime();
            #endif
            
            #if(Lift_Futaba_S3003_KillModeMinTime)
                 Lift_Futaba_S3003_backup.PWMKillCounterPeriod = Lift_Futaba_S3003_ReadKillTime();
            #endif
        #endif
        
        #if(Lift_Futaba_S3003_UseControl)
            Lift_Futaba_S3003_backup.PWMControlRegister = Lift_Futaba_S3003_ReadControlRegister();
        #endif
    #endif  
}


/*******************************************************************************
* Function Name: Lift_Futaba_S3003_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Lift_Futaba_S3003_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*  Yes.
*
*******************************************************************************/
void Lift_Futaba_S3003_RestoreConfig(void) 
{
        #if(!Lift_Futaba_S3003_UsingFixedFunction)
            #if (Lift_Futaba_S3003_PSOC3_ES2 || Lift_Futaba_S3003_PSOC5_ES1)
                /* Interrupt State Backup for Critical Region*/
                uint8 Lift_Futaba_S3003_interruptState;
                /* Enter Critical Region*/
                Lift_Futaba_S3003_interruptState = CyEnterCriticalSection();
                #if (Lift_Futaba_S3003_UseStatus)
                    /* Use the interrupt output of the status register for IRQ output */
                    Lift_Futaba_S3003_STATUS_AUX_CTRL |= Lift_Futaba_S3003_STATUS_ACTL_INT_EN_MASK;
                    
                    Lift_Futaba_S3003_STATUS_MASK = Lift_Futaba_S3003_backup.InterruptMaskValue;
                #endif
                
                #if (Lift_Futaba_S3003_Resolution == 8)
                    /* Set FIFO 0 to 1 byte register for period*/
                    Lift_Futaba_S3003_AUX_CONTROLDP0 |= (Lift_Futaba_S3003_AUX_CTRL_FIFO0_CLR);
                #else /* (Lift_Futaba_S3003_Resolution == 16)*/
                    /* Set FIFO 0 to 1 byte register for period */
                    Lift_Futaba_S3003_AUX_CONTROLDP0 |= (Lift_Futaba_S3003_AUX_CTRL_FIFO0_CLR);
                    Lift_Futaba_S3003_AUX_CONTROLDP1 |= (Lift_Futaba_S3003_AUX_CTRL_FIFO0_CLR);
                #endif
                /* Exit Critical Region*/
                CyExitCriticalSection(Lift_Futaba_S3003_interruptState);
                
                Lift_Futaba_S3003_WriteCounter(Lift_Futaba_S3003_backup.PWMUdb);
                Lift_Futaba_S3003_WritePeriod(Lift_Futaba_S3003_backup.PWMPeriod);
                
                #if(Lift_Futaba_S3003_UseOneCompareMode)
                    Lift_Futaba_S3003_WriteCompare(Lift_Futaba_S3003_backup.PWMCompareValue);
                #else
                    Lift_Futaba_S3003_WriteCompare1(Lift_Futaba_S3003_backup.PWMCompareValue1);
                    Lift_Futaba_S3003_WriteCompare2(Lift_Futaba_S3003_backup.PWMCompareValue2);
                #endif
                
               #if(Lift_Futaba_S3003_DeadBandMode == Lift_Futaba_S3003__B_PWM__DBM_256_CLOCKS || Lift_Futaba_S3003_DeadBandMode == Lift_Futaba_S3003__B_PWM__DBM_2_4_CLOCKS)
                    Lift_Futaba_S3003_WriteDeadTime(Lift_Futaba_S3003_backup.PWMdeadBandValue);
                #endif
            
                #if ( Lift_Futaba_S3003_KillModeMinTime)
                    Lift_Futaba_S3003_WriteKillTime(Lift_Futaba_S3003_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if (Lift_Futaba_S3003_PSOC3_ES3 || Lift_Futaba_S3003_PSOC5_ES2)
                #if(!Lift_Futaba_S3003_PWMModeIsCenterAligned)
                    Lift_Futaba_S3003_WritePeriod(Lift_Futaba_S3003_backup.PWMPeriod);
                #endif
                Lift_Futaba_S3003_WriteCounter(Lift_Futaba_S3003_backup.PWMUdb);
                #if (Lift_Futaba_S3003_UseStatus)
                    Lift_Futaba_S3003_STATUS_MASK = Lift_Futaba_S3003_backup.InterruptMaskValue;
                #endif
                
                #if(Lift_Futaba_S3003_DeadBandMode == Lift_Futaba_S3003__B_PWM__DBM_256_CLOCKS || Lift_Futaba_S3003_DeadBandMode == Lift_Futaba_S3003__B_PWM__DBM_2_4_CLOCKS)
                    Lift_Futaba_S3003_WriteDeadTime(Lift_Futaba_S3003_backup.PWMdeadBandValue);
                #endif
                
                #if(Lift_Futaba_S3003_KillModeMinTime)
                    Lift_Futaba_S3003_WriteKillTime(Lift_Futaba_S3003_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if(Lift_Futaba_S3003_UseControl)
                Lift_Futaba_S3003_WriteControlRegister(Lift_Futaba_S3003_backup.PWMControlRegister); 
            #endif
        #endif  
    }


/*******************************************************************************
* Function Name: Lift_Futaba_S3003_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Lift_Futaba_S3003_backup.PWMEnableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Lift_Futaba_S3003_Sleep(void)
{
    #if(Lift_Futaba_S3003_UseControl)
        if(Lift_Futaba_S3003_CTRL_ENABLE == (Lift_Futaba_S3003_CONTROL & Lift_Futaba_S3003_CTRL_ENABLE))
        {
            /*Component is enabled */
            Lift_Futaba_S3003_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            Lift_Futaba_S3003_backup.PWMEnableState = 0u;
        }
    #endif
    /* Stop component */
    Lift_Futaba_S3003_Stop();
    
    /* Save registers configuration */
    Lift_Futaba_S3003_SaveConfig();
}


/*******************************************************************************
* Function Name: Lift_Futaba_S3003_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Lift_Futaba_S3003_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Lift_Futaba_S3003_Wakeup(void) 
{
     /* Restore registers values */
    Lift_Futaba_S3003_RestoreConfig();
    
    if(Lift_Futaba_S3003_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        Lift_Futaba_S3003_Enable();
    } /* Do nothing if component's block was disabled before */
    
}

/* [] END OF FILE */
