/*******************************************************************************
* File Name: S2.c  
* Version 1.60
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "S2.h"

/* APIs are not generated for P15[7:6] */
#if !(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC5 &&\
     CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_5A_PRODUCTION &&\
	 S2__PORT == 15 && (S2__MASK & 0xC0))

/*******************************************************************************
* Function Name: S2_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void S2_Write(uint8 value) 
{
    uint8 staticBits = S2_DR & ~S2_MASK;
    S2_DR = staticBits | ((value << S2_SHIFT) & S2_MASK);
}


/*******************************************************************************
* Function Name: S2_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void S2_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(S2_0, mode);
}


/*******************************************************************************
* Function Name: S2_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro S2_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 S2_Read(void) 
{
    return (S2_PS & S2_MASK) >> S2_SHIFT;
}


/*******************************************************************************
* Function Name: S2_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 S2_ReadDataReg(void) 
{
    return (S2_DR & S2_MASK) >> S2_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(S2_INTSTAT) 

    /*******************************************************************************
    * Function Name: S2_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 S2_ClearInterrupt(void) 
    {
        return (S2_INTSTAT & S2_MASK) >> S2_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif
/* [] END OF FILE */ 
