/*******************************************************************************
* File Name: Second_Arm_DGS06NF.c  
* Version 2.10
*
* Description:
*  The PWM User Module consist of an 8 or 16-bit counter with two 8 or 16-bit
*  comparitors. Each instance of this user module is capable of generating
*  two PWM outputs with the same period. The pulse width is selectable between
*  1 and 255/65535. The period is selectable between 2 and 255/65536 clocks. 
*  The compare value output may be configured to be active when the present 
*  counter is less than or less than/equal to the compare value.
*  A terminal count output is also provided. It generates a pulse one clock
*  width wide when the counter is equal to zero.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "Second_Arm_DGS06NF.h"

uint8 Second_Arm_DGS06NF_initVar = 0u;

/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_Start
********************************************************************************
*
* Summary:
*  The start function initializes the pwm with the default values, the 
*  enables the counter to begin counting.  It does not enable interrupts,
*  the EnableInt command should be called if interrupt generation is required.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Global variables:
*  Second_Arm_DGS06NF_initVar: Is modified when this function is called for the first 
*   time. Is used to ensure that initialization happens only once.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_Start(void) 
{
    /* If not Initialized then initialize all required hardware and software */
    if(Second_Arm_DGS06NF_initVar == 0u)
    {
        Second_Arm_DGS06NF_Init();
        Second_Arm_DGS06NF_initVar = 1u;
    }
    Second_Arm_DGS06NF_Enable();

}


/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  Second_Arm_DGS06NF_Start().
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_Init(void) 
{
    #if (Second_Arm_DGS06NF_UsingFixedFunction || Second_Arm_DGS06NF_UseControl)
        uint8 ctrl;
    #endif
    
    #if(!Second_Arm_DGS06NF_UsingFixedFunction) 
        #if(Second_Arm_DGS06NF_UseStatus)
            /* Interrupt State Backup for Critical Region*/
            uint8 Second_Arm_DGS06NF_interruptState;
        #endif
    #endif
    
   #if (Second_Arm_DGS06NF_UsingFixedFunction)
        /* You are allowed to write the compare value (FF only) */
        Second_Arm_DGS06NF_CONTROL |= Second_Arm_DGS06NF_CFG0_MODE;
        #if (Second_Arm_DGS06NF_DeadBand2_4)
            Second_Arm_DGS06NF_CONTROL |= Second_Arm_DGS06NF_CFG0_DB;
        #endif
                
        /* Set the default Compare Mode */
        #if(Second_Arm_DGS06NF_PSOC3_ES2 || Second_Arm_DGS06NF_PSOC5_ES1)
                ctrl = Second_Arm_DGS06NF_CONTROL2 & ~Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK;
                Second_Arm_DGS06NF_CONTROL2 = ctrl | Second_Arm_DGS06NF_DEFAULT_COMPARE1_MODE;
        #endif
        #if(Second_Arm_DGS06NF_PSOC3_ES3 || Second_Arm_DGS06NF_PSOC5_ES2)
                ctrl = Second_Arm_DGS06NF_CONTROL3 & ~Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK;
                Second_Arm_DGS06NF_CONTROL3 = ctrl | Second_Arm_DGS06NF_DEFAULT_COMPARE1_MODE;
        #endif
        
         /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
        Second_Arm_DGS06NF_RT1 &= ~Second_Arm_DGS06NF_RT1_MASK;
        Second_Arm_DGS06NF_RT1 |= Second_Arm_DGS06NF_SYNC;     
                
        /*Enable DSI Sync all all inputs of the PWM*/
        Second_Arm_DGS06NF_RT1 &= ~(Second_Arm_DGS06NF_SYNCDSI_MASK);
        Second_Arm_DGS06NF_RT1 |= Second_Arm_DGS06NF_SYNCDSI_EN;
       
    #elif (Second_Arm_DGS06NF_UseControl)
        /* Set the default compare mode defined in the parameter */
        ctrl = Second_Arm_DGS06NF_CONTROL & ~Second_Arm_DGS06NF_CTRL_CMPMODE2_MASK & ~Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK;
        Second_Arm_DGS06NF_CONTROL = ctrl | Second_Arm_DGS06NF_DEFAULT_COMPARE2_MODE | Second_Arm_DGS06NF_DEFAULT_COMPARE1_MODE;
    #endif 
        
    #if (!Second_Arm_DGS06NF_UsingFixedFunction)
        #if (Second_Arm_DGS06NF_Resolution == 8)
            /* Set FIFO 0 to 1 byte register for period*/
            Second_Arm_DGS06NF_AUX_CONTROLDP0 |= (Second_Arm_DGS06NF_AUX_CTRL_FIFO0_CLR);
        #else /* (Second_Arm_DGS06NF_Resolution == 16)*/
            /* Set FIFO 0 to 1 byte register for period */
            Second_Arm_DGS06NF_AUX_CONTROLDP0 |= (Second_Arm_DGS06NF_AUX_CTRL_FIFO0_CLR);
            Second_Arm_DGS06NF_AUX_CONTROLDP1 |= (Second_Arm_DGS06NF_AUX_CTRL_FIFO0_CLR);
        #endif
    #endif
        
    Second_Arm_DGS06NF_WritePeriod(Second_Arm_DGS06NF_INIT_PERIOD_VALUE);
    Second_Arm_DGS06NF_WriteCounter(Second_Arm_DGS06NF_INIT_PERIOD_VALUE);
        
        #if (Second_Arm_DGS06NF_UseOneCompareMode)
            Second_Arm_DGS06NF_WriteCompare(Second_Arm_DGS06NF_INIT_COMPARE_VALUE1);
        #else
            Second_Arm_DGS06NF_WriteCompare1(Second_Arm_DGS06NF_INIT_COMPARE_VALUE1);
            Second_Arm_DGS06NF_WriteCompare2(Second_Arm_DGS06NF_INIT_COMPARE_VALUE2);
        #endif
        
        #if (Second_Arm_DGS06NF_KillModeMinTime)
            Second_Arm_DGS06NF_WriteKillTime(Second_Arm_DGS06NF_MinimumKillTime);
        #endif
        
        #if (Second_Arm_DGS06NF_DeadBandUsed)
            Second_Arm_DGS06NF_WriteDeadTime(Second_Arm_DGS06NF_INIT_DEAD_TIME);
        #endif

    #if (Second_Arm_DGS06NF_UseStatus || Second_Arm_DGS06NF_UsingFixedFunction)
        Second_Arm_DGS06NF_SetInterruptMode(Second_Arm_DGS06NF_INIT_INTERRUPTS_MODE);
    #endif
        
    #if (Second_Arm_DGS06NF_UsingFixedFunction)
        /* Globally Enable the Fixed Function Block chosen */
        Second_Arm_DGS06NF_GLOBAL_ENABLE |= Second_Arm_DGS06NF_BLOCK_EN_MASK;
        /* Set the Interrupt source to come from the status register */
        Second_Arm_DGS06NF_CONTROL2 |= Second_Arm_DGS06NF_CTRL2_IRQ_SEL;
    #else
        #if(Second_Arm_DGS06NF_UseStatus)
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            Second_Arm_DGS06NF_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            Second_Arm_DGS06NF_STATUS_AUX_CTRL |= Second_Arm_DGS06NF_STATUS_ACTL_INT_EN_MASK;
            
             /* Exit Critical Region*/
            CyExitCriticalSection(Second_Arm_DGS06NF_interruptState);
            
            /* Clear the FIFO to enable the Second_Arm_DGS06NF_STATUS_FIFOFULL
                   bit to be set on FIFO full. */
            Second_Arm_DGS06NF_ClearFIFO();
        #endif
    #endif
}


/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_Enable
********************************************************************************
*
* Summary: 
*  Enables the PWM block operation
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Side Effects: 
*  This works only if software enable mode is chosen
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (Second_Arm_DGS06NF_UsingFixedFunction)
        Second_Arm_DGS06NF_GLOBAL_ENABLE |= Second_Arm_DGS06NF_BLOCK_EN_MASK;
        Second_Arm_DGS06NF_GLOBAL_STBY_ENABLE |= Second_Arm_DGS06NF_BLOCK_STBY_EN_MASK;
    #endif 
    
    /* Enable the PWM from the control register  */
    #if (Second_Arm_DGS06NF_UseControl || Second_Arm_DGS06NF_UsingFixedFunction)
        Second_Arm_DGS06NF_CONTROL |= Second_Arm_DGS06NF_CTRL_ENABLE;
    #endif
}


/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_Stop
********************************************************************************
*
* Summary:
*  The stop function halts the PWM, but does not change any modes or disable
*  interrupts.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects:
*  If the Enable mode is set to Hardware only then this function
*  has no effect on the operation of the PWM
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_Stop(void) 
{
    #if (Second_Arm_DGS06NF_UseControl || Second_Arm_DGS06NF_UsingFixedFunction)
        Second_Arm_DGS06NF_CONTROL &= ~Second_Arm_DGS06NF_CTRL_ENABLE;
    #endif
    
    /* Globally disable the Fixed Function Block chosen */
    #if (Second_Arm_DGS06NF_UsingFixedFunction)
        Second_Arm_DGS06NF_GLOBAL_ENABLE &= ~Second_Arm_DGS06NF_BLOCK_EN_MASK;
        Second_Arm_DGS06NF_GLOBAL_STBY_ENABLE &= ~Second_Arm_DGS06NF_BLOCK_STBY_EN_MASK;
    #endif
}


#if (Second_Arm_DGS06NF_UseOneCompareMode)
#if (Second_Arm_DGS06NF_CompareMode1SW)
/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_SetCompareMode
********************************************************************************
* 
* Summary:
*  This function writes the Compare Mode for the pwm output when in Dither mode,
*  Center Align Mode or One Output Mode.
*
* Parameters:
*  comparemode:  The new compare mode for the PWM output. Use the compare types
*                defined in the H file as input arguments.
*
* Return:
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_SetCompareMode(uint8 comparemode) 
{
    #if(Second_Arm_DGS06NF_UsingFixedFunction)
            #if(Second_Arm_DGS06NF_PSOC3_ES2 || Second_Arm_DGS06NF_PSOC5_ES1)
                        uint8 comparemodemasked = (comparemode << Second_Arm_DGS06NF_CTRL_CMPMODE1_SHIFT);
                        Second_Arm_DGS06NF_CONTROL2 &= ~Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK; /*Clear Existing Data */
                        Second_Arm_DGS06NF_CONTROL2 |= comparemodemasked;  
                #endif
                
            #if(Second_Arm_DGS06NF_PSOC3_ES3 || Second_Arm_DGS06NF_PSOC5_ES2)
                    uint8 comparemodemasked = (comparemode << Second_Arm_DGS06NF_CTRL_CMPMODE1_SHIFT);
            Second_Arm_DGS06NF_CONTROL3 &= ~Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK; /*Clear Existing Data */
            Second_Arm_DGS06NF_CONTROL3 |= comparemodemasked;     
                #endif
                
    #elif (Second_Arm_DGS06NF_UseControl)
        uint8 comparemode1masked = (comparemode << Second_Arm_DGS06NF_CTRL_CMPMODE1_SHIFT) & Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK;
        uint8 comparemode2masked = (comparemode << Second_Arm_DGS06NF_CTRL_CMPMODE2_SHIFT) & Second_Arm_DGS06NF_CTRL_CMPMODE2_MASK;
        Second_Arm_DGS06NF_CONTROL &= ~(Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK | Second_Arm_DGS06NF_CTRL_CMPMODE2_MASK); /*Clear existing mode */
        Second_Arm_DGS06NF_CONTROL |= (comparemode1masked | comparemode2masked);
        
    #else
        uint8 temp = comparemode;
    #endif
}
#endif /* Second_Arm_DGS06NF_CompareMode1SW */

#else /* UseOneCompareMode */


#if (Second_Arm_DGS06NF_CompareMode1SW)
/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_SetCompareMode1
********************************************************************************
* 
* Summary:
*  This function writes the Compare Mode for the pwm or pwm1 output
*
* Parameters:  
*  comparemode:  The new compare mode for the PWM output. Use the compare types
*                defined in the H file as input arguments.
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_SetCompareMode1(uint8 comparemode) 
{
    uint8 comparemodemasked = (comparemode << Second_Arm_DGS06NF_CTRL_CMPMODE1_SHIFT) & Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK;
    #if(Second_Arm_DGS06NF_UsingFixedFunction)
            #if(Second_Arm_DGS06NF_PSOC3_ES2 || Second_Arm_DGS06NF_PSOC5_ES1)
                        Second_Arm_DGS06NF_CONTROL2 &= Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK; /*Clear existing mode */
                        Second_Arm_DGS06NF_CONTROL2 |= comparemodemasked; 
            #endif
                
                #if(Second_Arm_DGS06NF_PSOC3_ES3 || Second_Arm_DGS06NF_PSOC5_ES2)
                    Second_Arm_DGS06NF_CONTROL3 &= Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK; /*Clear existing mode */
                        Second_Arm_DGS06NF_CONTROL3 |= comparemodemasked; 
            #endif
                
    #elif (Second_Arm_DGS06NF_UseControl)
        Second_Arm_DGS06NF_CONTROL &= Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK; /*Clear existing mode */
        Second_Arm_DGS06NF_CONTROL |= comparemodemasked;
    #endif    
}
#endif /* Second_Arm_DGS06NF_CompareMode1SW */


#if (Second_Arm_DGS06NF_CompareMode2SW)
/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_SetCompareMode2
********************************************************************************
* 
* Summary:
*  This function writes the Compare Mode for the pwm or pwm2 output
*
* Parameters:  
*  comparemode:  The new compare mode for the PWM output. Use the compare types
*                defined in the H file as input arguments.
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_SetCompareMode2(uint8 comparemode) 
{
    #if(Second_Arm_DGS06NF_UsingFixedFunction)
        /* Do Nothing because there is no second Compare Mode Register in FF block*/ 
    #elif (Second_Arm_DGS06NF_UseControl)
    uint8 comparemodemasked = (comparemode << Second_Arm_DGS06NF_CTRL_CMPMODE2_SHIFT) & Second_Arm_DGS06NF_CTRL_CMPMODE2_MASK;
    Second_Arm_DGS06NF_CONTROL &= Second_Arm_DGS06NF_CTRL_CMPMODE2_MASK; /*Clear existing mode */
    Second_Arm_DGS06NF_CONTROL |= comparemodemasked;
    #endif    
}
#endif /*Second_Arm_DGS06NF_CompareMode2SW */
#endif /* UseOneCompareMode */


/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_WriteCounter
********************************************************************************
* 
* Summary:
*  This function is used to change the counter value.
*
* Parameters:  
*  counter:  This value may be between 1 and (2^Resolution)-1.   
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_WriteCounter(uint16 counter) 
{
    #if(Second_Arm_DGS06NF_UsingFixedFunction)
        CY_SET_REG16(Second_Arm_DGS06NF_COUNTER_LSB_PTR, (uint16)counter);
    #else
        CY_SET_REG16(Second_Arm_DGS06NF_COUNTER_LSB_PTR, counter);
    #endif
}


#if (!Second_Arm_DGS06NF_UsingFixedFunction)
/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_ReadCounter
********************************************************************************
* 
* Summary:
*  This function returns the current value of the counter.  It doesn't matter
*  if the counter is enabled or running.
*
* Parameters:  
*  void  
*
* Return: 
*  The current value of the counter.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
uint16 Second_Arm_DGS06NF_ReadCounter(void) 
{
    /* Force capture by reading Accumulator */
    /* Must first do a software capture to be able to read the counter */
    /* It is up to the user code to make sure there isn't already captured data in the FIFO */
    CY_GET_REG8(Second_Arm_DGS06NF_COUNTERCAP_LSB_PTR);
    
    /* Read the data from the FIFO (or capture register for Fixed Function)*/
    return (CY_GET_REG16(Second_Arm_DGS06NF_CAPTURE_LSB_PTR));
}


#if (Second_Arm_DGS06NF_UseStatus)
/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_ClearFIFO
********************************************************************************
* 
* Summary:
*  This function clears all capture data from the capture FIFO
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_ClearFIFO(void) 
{
    while(Second_Arm_DGS06NF_ReadStatusRegister() & Second_Arm_DGS06NF_STATUS_FIFONEMPTY)
        Second_Arm_DGS06NF_ReadCapture();
}
#endif /* Second_Arm_DGS06NF_UseStatus */
#endif /* !Second_Arm_DGS06NF_UsingFixedFunction */


/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_WritePeriod
********************************************************************************
* 
* Summary:
*  This function is used to change the period of the counter.  The new period 
*  will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period:  Period value. May be between 1 and (2^Resolution)-1.  A value of 0 
*           will result in the counter remaining at zero.
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_WritePeriod(uint16 period) 
{
    #if(Second_Arm_DGS06NF_UsingFixedFunction)
        CY_SET_REG16(Second_Arm_DGS06NF_PERIOD_LSB_PTR, (uint16)period);
    #else
        CY_SET_REG16(Second_Arm_DGS06NF_PERIOD_LSB_PTR, period);
    #endif
}


#if (Second_Arm_DGS06NF_UseOneCompareMode)
/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_WriteCompare
********************************************************************************
* 
* Summary:
*  This funtion is used to change the compare1 value when the PWM is in Dither
*  mode. The compare output will reflect the new value on the next UDB clock. 
*  The compare output will be driven high when the present counter value is 
*  compared to the compare value based on the compare mode defined in 
*  Dither Mode.
*
* Parameters:  
*  compare:  New compare value.  
*
* Return: 
*  void
*
* Side Effects:
*  This function is only available if the PWM mode parameter is set to
*  Dither Mode, Center Aligned Mode or One Output Mode
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_WriteCompare(uint16 compare) 
{
   CY_SET_REG16(Second_Arm_DGS06NF_COMPARE1_LSB_PTR, compare);
   #if (Second_Arm_DGS06NF_PWMMode == Second_Arm_DGS06NF__B_PWM__DITHER)
        CY_SET_REG16(Second_Arm_DGS06NF_COMPARE2_LSB_PTR, compare+1);
   #endif
}


#else


/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_WriteCompare1
********************************************************************************
* 
* Summary:
*  This funtion is used to change the compare1 value.  The compare output will 
*  reflect the new value on the next UDB clock.  The compare output will be 
*  driven high when the present counter value is less than or less than or 
*  equal to the compare register, depending on the mode.
*
* Parameters:  
*  compare:  New compare value.  
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_WriteCompare1(uint16 compare) 
{
    #if(Second_Arm_DGS06NF_UsingFixedFunction)
        CY_SET_REG16(Second_Arm_DGS06NF_COMPARE1_LSB_PTR, (uint16)compare);
    #else
        CY_SET_REG16(Second_Arm_DGS06NF_COMPARE1_LSB_PTR, compare);
    #endif
}


/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_WriteCompare2
********************************************************************************
* 
* Summary:
*  This funtion is used to change the compare value, for compare1 output.  
*  The compare output will reflect the new value on the next UDB clock.  
*  The compare output will be driven high when the present counter value is 
*  less than or less than or equal to the compare register, depending on the 
*  mode.
*
* Parameters:  
*  compare:  New compare value.  
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_WriteCompare2(uint16 compare) 
{
    #if(Second_Arm_DGS06NF_UsingFixedFunction)
        CY_SET_REG16(Second_Arm_DGS06NF_COMPARE2_LSB_PTR, compare);
    #else
        CY_SET_REG16(Second_Arm_DGS06NF_COMPARE2_LSB_PTR, compare);
    #endif
}
#endif /* UseOneCompareMode */


#if (Second_Arm_DGS06NF_DeadBandUsed)
/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_WriteDeadTime
********************************************************************************
* 
* Summary:
*  This function writes the dead-band counts to the corresponding register
*
* Parameters:  
*  deadtime:  Number of counts for dead time 
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_WriteDeadTime(uint8 deadtime) 
{
    /* If using the Dead Band 1-255 mode then just write the register */
    #if(!Second_Arm_DGS06NF_DeadBand2_4)
        CY_SET_REG8(Second_Arm_DGS06NF_DEADBAND_COUNT_PTR, deadtime);
    #else
        /* Otherwise the data has to be masked and offset */        
        /* Clear existing data */
        Second_Arm_DGS06NF_DEADBAND_COUNT &= ~Second_Arm_DGS06NF_DEADBAND_COUNT_MASK; 
            /* Set new dead time */
        Second_Arm_DGS06NF_DEADBAND_COUNT |= (deadtime << Second_Arm_DGS06NF_DEADBAND_COUNT_SHIFT) & Second_Arm_DGS06NF_DEADBAND_COUNT_MASK; 
    #endif
}


/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_ReadDeadTime
********************************************************************************
* 
* Summary:
*  This function reads the dead-band counts from the corresponding register
*
* Parameters:  
*  void
*
* Return: 
*  Dead Band Counts
*
* Reentrant:
*  Yes
*
*******************************************************************************/
uint8 Second_Arm_DGS06NF_ReadDeadTime(void) 
{
    /* If using the Dead Band 1-255 mode then just read the register */
    #if(!Second_Arm_DGS06NF_DeadBand2_4)
        return (CY_GET_REG8(Second_Arm_DGS06NF_DEADBAND_COUNT_PTR));
    #else
        /* Otherwise the data has to be masked and offset */
        return ((Second_Arm_DGS06NF_DEADBAND_COUNT & Second_Arm_DGS06NF_DEADBAND_COUNT_MASK) >> Second_Arm_DGS06NF_DEADBAND_COUNT_SHIFT);
    #endif
}
#endif /* DeadBandUsed */

