/*******************************************************************************
* File Name: Second_Arm_DGS06NF.h  
* Version 2.10
*
* Description:
*  Contains the prototypes and constants for the functions available to the 
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

#if !defined(CY_PWM_Second_Arm_DGS06NF_H)
#define CY_PWM_Second_Arm_DGS06NF_H


/***************************************
* Conditional Compilation Parameters
***************************************/
#define Second_Arm_DGS06NF_Resolution 16u
#define Second_Arm_DGS06NF_UsingFixedFunction 0u
#define Second_Arm_DGS06NF_DeadBandMode 0u
#define Second_Arm_DGS06NF_KillModeMinTime 0u
#define Second_Arm_DGS06NF_KillMode 0u
#define Second_Arm_DGS06NF_PWMMode 0u
#define Second_Arm_DGS06NF_PWMModeIsCenterAligned 0u
#define Second_Arm_DGS06NF_DeadBandUsed 0u
#define Second_Arm_DGS06NF_DeadBand2_4 0u
#if !defined(Second_Arm_DGS06NF_PWMUDB_sSTSReg_stsreg__REMOVED)
    #define Second_Arm_DGS06NF_UseStatus 1u
#else
    #define Second_Arm_DGS06NF_UseStatus 0u
#endif
#if !defined(Second_Arm_DGS06NF_PWMUDB_sCTRLReg_ctrlreg__REMOVED)
    #define Second_Arm_DGS06NF_UseControl 1u
#else
    #define Second_Arm_DGS06NF_UseControl 0u
#endif
#define Second_Arm_DGS06NF_UseOneCompareMode 1u
#define Second_Arm_DGS06NF_MinimumKillTime 1u
#define Second_Arm_DGS06NF_EnableMode 0u

#define Second_Arm_DGS06NF_CompareMode1SW 0u
#define Second_Arm_DGS06NF_CompareMode2SW 0u

/* PSoC3 ES2 or early */
#define Second_Arm_DGS06NF_PSOC3_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)   && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))

/* PSoC5 ES1 or early */
#define Second_Arm_DGS06NF_PSOC5_ES1   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)   && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))

/* PSoC3 ES3 or later */
#define Second_Arm_DGS06NF_PSOC3_ES3   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                     (CYDEV_CHIP_REVISION_USED >= CYDEV_CHIP_REVISION_3A_ES3))

/* PSoC5 ES2 or later */
#define Second_Arm_DGS06NF_PSOC5_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)   && \
                                     (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))

/* Use Kill Mode Enumerated Types */
#define Second_Arm_DGS06NF__B_PWM__DISABLED 0
#define Second_Arm_DGS06NF__B_PWM__ASYNCHRONOUS 1
#define Second_Arm_DGS06NF__B_PWM__SINGLECYCLE 2
#define Second_Arm_DGS06NF__B_PWM__LATCHED 3
#define Second_Arm_DGS06NF__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define Second_Arm_DGS06NF__B_PWM__DBMDISABLED 0
#define Second_Arm_DGS06NF__B_PWM__DBM_2_4_CLOCKS 1
#define Second_Arm_DGS06NF__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define Second_Arm_DGS06NF__B_PWM__ONE_OUTPUT 0
#define Second_Arm_DGS06NF__B_PWM__TWO_OUTPUTS 1
#define Second_Arm_DGS06NF__B_PWM__DUAL_EDGE 2
#define Second_Arm_DGS06NF__B_PWM__CENTER_ALIGN 3
#define Second_Arm_DGS06NF__B_PWM__DITHER 5
#define Second_Arm_DGS06NF__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define Second_Arm_DGS06NF__B_PWM__LESS_THAN 1
#define Second_Arm_DGS06NF__B_PWM__LESS_THAN_OR_EQUAL 2
#define Second_Arm_DGS06NF__B_PWM__GREATER_THAN 3
#define Second_Arm_DGS06NF__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define Second_Arm_DGS06NF__B_PWM__EQUAL 0
#define Second_Arm_DGS06NF__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/

/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct Second_Arm_DGS06NF_backupStruct
{
    
    uint8 PWMEnableState;
       
    #if(!Second_Arm_DGS06NF_UsingFixedFunction)
        #if (Second_Arm_DGS06NF_PSOC3_ES2 || Second_Arm_DGS06NF_PSOC5_ES1)
            uint16 PWMUdb;               /* PWM Current Counter value  */
            uint16 PWMPeriod;            /* PWM Current Period value   */
            #if (Second_Arm_DGS06NF_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif
            #if(Second_Arm_DGS06NF_UseOneCompareMode)
                uint16 PWMCompareValue;     /* PWM Current Compare value */
            #else
                uint16 PWMCompareValue1;     /* PWM Current Compare value1 */
                uint16 PWMCompareValue2;     /* PWM Current Compare value2 */
            #endif
            
            /* Backup for Deadband parameters */
            #if(Second_Arm_DGS06NF_DeadBandMode == Second_Arm_DGS06NF__B_PWM__DBM_256_CLOCKS || Second_Arm_DGS06NF_DeadBandMode == Second_Arm_DGS06NF__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif
            
            /* Backup Kill Mode Counter*/
            #if(Second_Arm_DGS06NF_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif
            
        #endif
        
        #if (Second_Arm_DGS06NF_PSOC3_ES3 || Second_Arm_DGS06NF_PSOC5_ES2)
            uint16 PWMUdb;               /* PWM Current Counter value  */
            #if(!Second_Arm_DGS06NF_PWMModeIsCenterAligned)
                uint16 PWMPeriod;
            #endif
            #if (Second_Arm_DGS06NF_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif
            
            /* Backup for Deadband parameters */
            #if(Second_Arm_DGS06NF_DeadBandMode == Second_Arm_DGS06NF__B_PWM__DBM_256_CLOCKS || Second_Arm_DGS06NF_DeadBandMode == Second_Arm_DGS06NF__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif
            
            /* Backup Kill Mode Counter*/
            #if(Second_Arm_DGS06NF_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif
        #endif
        
        
        /* Backup control register */
        #if(Second_Arm_DGS06NF_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif
        
    #endif 
   
}Second_Arm_DGS06NF_backupStruct;

/***************************************
*        Function Prototypes
 **************************************/
 
void    Second_Arm_DGS06NF_Start(void);
void    Second_Arm_DGS06NF_Stop(void) ;
#if (Second_Arm_DGS06NF_UseStatus || Second_Arm_DGS06NF_UsingFixedFunction)
    #define Second_Arm_DGS06NF_SetInterruptMode(interruptMode) CY_SET_REG8(Second_Arm_DGS06NF_STATUS_MASK_PTR, interruptMode)
    #define Second_Arm_DGS06NF_ReadStatusRegister() CY_GET_REG8(Second_Arm_DGS06NF_STATUS_PTR)
#endif
#define Second_Arm_DGS06NF_GetInterruptSource() Second_Arm_DGS06NF_ReadStatusRegister()
#if (Second_Arm_DGS06NF_UseControl)
    #define Second_Arm_DGS06NF_ReadControlRegister() CY_GET_REG8(Second_Arm_DGS06NF_CONTROL_PTR) 
    #define Second_Arm_DGS06NF_WriteControlRegister(control) CY_SET_REG8(Second_Arm_DGS06NF_CONTROL_PTR, control)
#endif
#if (Second_Arm_DGS06NF_UseOneCompareMode)
   #if (Second_Arm_DGS06NF_CompareMode1SW)
       void    Second_Arm_DGS06NF_SetCompareMode(uint8 comparemode) ;
   #endif
#else
    #if (Second_Arm_DGS06NF_CompareMode1SW)
        void    Second_Arm_DGS06NF_SetCompareMode1(uint8 comparemode) ;
    #endif
    #if (Second_Arm_DGS06NF_CompareMode2SW)
        void    Second_Arm_DGS06NF_SetCompareMode2(uint8 comparemode) ;
    #endif
#endif

#if (!Second_Arm_DGS06NF_UsingFixedFunction)
    uint16   Second_Arm_DGS06NF_ReadCounter(void) ;
    #define Second_Arm_DGS06NF_ReadCapture() CY_GET_REG16(Second_Arm_DGS06NF_CAPTURE_LSB_PTR)
    #if (Second_Arm_DGS06NF_UseStatus)
        void Second_Arm_DGS06NF_ClearFIFO(void) ;
    #endif
#endif

void    Second_Arm_DGS06NF_WriteCounter(uint16 counter) ;
void    Second_Arm_DGS06NF_WritePeriod(uint16 period) ;
#define Second_Arm_DGS06NF_ReadPeriod() CY_GET_REG16(Second_Arm_DGS06NF_PERIOD_LSB_PTR) 
#if (Second_Arm_DGS06NF_UseOneCompareMode)
    void    Second_Arm_DGS06NF_WriteCompare(uint16 compare) ;
    #define Second_Arm_DGS06NF_ReadCompare() CY_GET_REG16(Second_Arm_DGS06NF_COMPARE1_LSB_PTR) 
#else
    void    Second_Arm_DGS06NF_WriteCompare1(uint16 compare) ;
    #define Second_Arm_DGS06NF_ReadCompare1() CY_GET_REG16(Second_Arm_DGS06NF_COMPARE1_LSB_PTR) 
    void    Second_Arm_DGS06NF_WriteCompare2(uint16 compare) ;
    #define Second_Arm_DGS06NF_ReadCompare2() CY_GET_REG16(Second_Arm_DGS06NF_COMPARE2_LSB_PTR) 
#endif


#if (Second_Arm_DGS06NF_DeadBandUsed)
    void    Second_Arm_DGS06NF_WriteDeadTime(uint8 deadtime) ;
    uint8   Second_Arm_DGS06NF_ReadDeadTime(void) ;
#endif

#if ( Second_Arm_DGS06NF_KillModeMinTime)
    #define Second_Arm_DGS06NF_WriteKillTime(killtime) CY_SET_REG8(Second_Arm_DGS06NF_KILLMODEMINTIME_PTR, killtime) 
    #define Second_Arm_DGS06NF_ReadKillTime() CY_GET_REG8(Second_Arm_DGS06NF_KILLMODEMINTIME_PTR) 
#endif

void Second_Arm_DGS06NF_Init(void) ;
void Second_Arm_DGS06NF_Enable(void) ;
void Second_Arm_DGS06NF_Sleep(void);
void Second_Arm_DGS06NF_Wakeup(void) ;
void Second_Arm_DGS06NF_SaveConfig(void);
void Second_Arm_DGS06NF_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define Second_Arm_DGS06NF_INIT_PERIOD_VALUE        408u
#define Second_Arm_DGS06NF_INIT_COMPARE_VALUE1      405u
#define Second_Arm_DGS06NF_INIT_COMPARE_VALUE2      401u
#define Second_Arm_DGS06NF_INIT_INTERRUPTS_MODE     ((0u << Second_Arm_DGS06NF_STATUS_TC_INT_EN_MASK_SHIFT) | (0 << Second_Arm_DGS06NF_STATUS_CMP2_INT_EN_MASK_SHIFT) | (0 << Second_Arm_DGS06NF_STATUS_CMP1_INT_EN_MASK_SHIFT ) | (0 << Second_Arm_DGS06NF_STATUS_KILL_INT_EN_MASK_SHIFT ))
#define Second_Arm_DGS06NF_DEFAULT_COMPARE2_MODE    (1u << Second_Arm_DGS06NF_CTRL_CMPMODE2_SHIFT)
#define Second_Arm_DGS06NF_DEFAULT_COMPARE1_MODE    (4u << Second_Arm_DGS06NF_CTRL_CMPMODE1_SHIFT)
#define Second_Arm_DGS06NF_INIT_DEAD_TIME           1u


/********************************
*         Registers
******************************** */

#if (Second_Arm_DGS06NF_UsingFixedFunction)
   #define Second_Arm_DGS06NF_PERIOD_LSB          (*(reg16 *) Second_Arm_DGS06NF_PWMHW__PER0)
   #define Second_Arm_DGS06NF_PERIOD_LSB_PTR      ( (reg16 *) Second_Arm_DGS06NF_PWMHW__PER0)
   #define Second_Arm_DGS06NF_COMPARE1_LSB        (*(reg16 *) Second_Arm_DGS06NF_PWMHW__CNT_CMP0)
   #define Second_Arm_DGS06NF_COMPARE1_LSB_PTR    ( (reg16 *) Second_Arm_DGS06NF_PWMHW__CNT_CMP0)
   #define Second_Arm_DGS06NF_COMPARE2_LSB        0x00u
   #define Second_Arm_DGS06NF_COMPARE2_LSB_PTR    0x00u
   #define Second_Arm_DGS06NF_COUNTER_LSB         (*(reg16 *) Second_Arm_DGS06NF_PWMHW__CNT_CMP0)
   #define Second_Arm_DGS06NF_COUNTER_LSB_PTR     ( (reg16 *) Second_Arm_DGS06NF_PWMHW__CNT_CMP0)
   #define Second_Arm_DGS06NF_CAPTURE_LSB         (*(reg16 *) Second_Arm_DGS06NF_PWMHW__CAP0)
   #define Second_Arm_DGS06NF_CAPTURE_LSB_PTR     ( (reg16 *) Second_Arm_DGS06NF_PWMHW__CAP0)
   #define Second_Arm_DGS06NF_RT1                 (*(reg8 *)  Second_Arm_DGS06NF_PWMHW__RT1)
   #define Second_Arm_DGS06NF_RT1_PTR             ( (reg8 *)  Second_Arm_DGS06NF_PWMHW__RT1)
      
#else
   #if(Second_Arm_DGS06NF_PWMModeIsCenterAligned)
       #define Second_Arm_DGS06NF_PERIOD_LSB      (*(reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__D1_REG)
       #define Second_Arm_DGS06NF_PERIOD_LSB_PTR   ((reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__D1_REG)
   #else
       #define Second_Arm_DGS06NF_PERIOD_LSB      (*(reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__F0_REG)
       #define Second_Arm_DGS06NF_PERIOD_LSB_PTR   ((reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__F0_REG)
   #endif
   #define Second_Arm_DGS06NF_COMPARE1_LSB    (*(reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__D0_REG)
   #define Second_Arm_DGS06NF_COMPARE1_LSB_PTR ((reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__D0_REG)
   #define Second_Arm_DGS06NF_COMPARE2_LSB    (*(reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__D1_REG)
   #define Second_Arm_DGS06NF_COMPARE2_LSB_PTR ((reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__D1_REG)
   #define Second_Arm_DGS06NF_COUNTERCAP_LSB   *(reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__A1_REG)
   #define Second_Arm_DGS06NF_COUNTERCAP_LSB_PTR ((reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__A1_REG)
   #define Second_Arm_DGS06NF_COUNTER_LSB     (*(reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__A0_REG)
   #define Second_Arm_DGS06NF_COUNTER_LSB_PTR  ((reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__A0_REG)
   #define Second_Arm_DGS06NF_CAPTURE_LSB     (*(reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__F1_REG)
   #define Second_Arm_DGS06NF_CAPTURE_LSB_PTR  ((reg16 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__F1_REG)
   #define Second_Arm_DGS06NF_AUX_CONTROLDP0      (*(reg8 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__DP_AUX_CTL_REG)
   #define Second_Arm_DGS06NF_AUX_CONTROLDP0_PTR  ((reg8 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u0__DP_AUX_CTL_REG)
   #if (Second_Arm_DGS06NF_Resolution == 16)
       #define Second_Arm_DGS06NF_AUX_CONTROLDP1    (*(reg8 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u1__DP_AUX_CTL_REG)
       #define Second_Arm_DGS06NF_AUX_CONTROLDP1_PTR  ((reg8 *) Second_Arm_DGS06NF_PWMUDB_sP16_pwmdp_u1__DP_AUX_CTL_REG)
   #endif
#endif
   
#if(Second_Arm_DGS06NF_KillModeMinTime )
    #define Second_Arm_DGS06NF_KILLMODEMINTIME      (*(reg8 *) Second_Arm_DGS06NF_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define Second_Arm_DGS06NF_KILLMODEMINTIME_PTR   ((reg8 *) Second_Arm_DGS06NF_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif

#if(Second_Arm_DGS06NF_DeadBandMode == Second_Arm_DGS06NF__B_PWM__DBM_256_CLOCKS)
    #define Second_Arm_DGS06NF_DEADBAND_COUNT        (*(reg8 *) Second_Arm_DGS06NF_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define Second_Arm_DGS06NF_DEADBAND_COUNT_PTR     ((reg8 *) Second_Arm_DGS06NF_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define Second_Arm_DGS06NF_DEADBAND_LSB_PTR       ((reg8 *) Second_Arm_DGS06NF_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define Second_Arm_DGS06NF_DEADBAND_LSB          (*(reg8 *) Second_Arm_DGS06NF_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(Second_Arm_DGS06NF_DeadBandMode == Second_Arm_DGS06NF__B_PWM__DBM_2_4_CLOCKS)
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (Second_Arm_DGS06NF_UsingFixedFunction)
        #define Second_Arm_DGS06NF_DEADBAND_COUNT        (*(reg8 *) Second_Arm_DGS06NF_PWMHW__CFG0) 
        #define Second_Arm_DGS06NF_DEADBAND_COUNT_PTR     ((reg8 *) Second_Arm_DGS06NF_PWMHW__CFG0)
        #define Second_Arm_DGS06NF_DEADBAND_COUNT_MASK    (0x03u << Second_Arm_DGS06NF_DEADBAND_COUNT_SHIFT) 
        #define Second_Arm_DGS06NF_DEADBAND_COUNT_SHIFT   0x06u /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */ 
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define Second_Arm_DGS06NF_DEADBAND_COUNT        (*(reg8 *) Second_Arm_DGS06NF_PWMUDB_sDB3_AsyncCtl_dbctrlreg__CONTROL_REG)
        #define Second_Arm_DGS06NF_DEADBAND_COUNT_PTR     ((reg8 *) Second_Arm_DGS06NF_PWMUDB_sDB3_AsyncCtl_dbctrlreg__CONTROL_REG)
        #define Second_Arm_DGS06NF_DEADBAND_COUNT_MASK    (0x03u << Second_Arm_DGS06NF_DEADBAND_COUNT_SHIFT) 
        #define Second_Arm_DGS06NF_DEADBAND_COUNT_SHIFT   0x00u /* As defined by the verilog implementation of the Control Register */
    #endif
#endif



#if (Second_Arm_DGS06NF_UsingFixedFunction)
    #define Second_Arm_DGS06NF_STATUS                (*(reg8 *) Second_Arm_DGS06NF_PWMHW__SR0)
    #define Second_Arm_DGS06NF_STATUS_PTR            ((reg8 *) Second_Arm_DGS06NF_PWMHW__SR0)
    #define Second_Arm_DGS06NF_STATUS_MASK           (*(reg8 *) Second_Arm_DGS06NF_PWMHW__SR0)
    #define Second_Arm_DGS06NF_STATUS_MASK_PTR       ((reg8 *) Second_Arm_DGS06NF_PWMHW__SR0)
    #define Second_Arm_DGS06NF_CONTROL               (*(reg8 *) Second_Arm_DGS06NF_PWMHW__CFG0)
    #define Second_Arm_DGS06NF_CONTROL_PTR           ((reg8 *) Second_Arm_DGS06NF_PWMHW__CFG0)    
    #define Second_Arm_DGS06NF_CONTROL2              (*(reg8 *) Second_Arm_DGS06NF_PWMHW__CFG1)    
    #if(Second_Arm_DGS06NF_PSOC3_ES3 || Second_Arm_DGS06NF_PSOC5_ES2)
        #define Second_Arm_DGS06NF_CONTROL3              (*(reg8 *) Second_Arm_DGS06NF_PWMHW__CFG2)
    #endif
    #define Second_Arm_DGS06NF_GLOBAL_ENABLE         (*(reg8 *) Second_Arm_DGS06NF_PWMHW__PM_ACT_CFG)
    #define Second_Arm_DGS06NF_GLOBAL_ENABLE_PTR       ( (reg8 *) Second_Arm_DGS06NF_PWMHW__PM_ACT_CFG)
    #define Second_Arm_DGS06NF_GLOBAL_STBY_ENABLE      (*(reg8 *) Second_Arm_DGS06NF_PWMHW__PM_STBY_CFG)
    #define Second_Arm_DGS06NF_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) Second_Arm_DGS06NF_PWMHW__PM_STBY_CFG)
  
  
    /***********************************
    *          Constants
    ***********************************/
    /* Fixed Function Block Chosen */
    #define Second_Arm_DGS06NF_BLOCK_EN_MASK          Second_Arm_DGS06NF_PWMHW__PM_ACT_MSK
    #define Second_Arm_DGS06NF_BLOCK_STBY_EN_MASK     Second_Arm_DGS06NF_PWMHW__PM_STBY_MSK 
    /* Control Register definitions */
    #define Second_Arm_DGS06NF_CTRL_ENABLE_SHIFT      0x00u
    
    #if(Second_Arm_DGS06NF_PSOC3_ES2 || Second_Arm_DGS06NF_PSOC5_ES1)
        #define Second_Arm_DGS06NF_CTRL_CMPMODE1_SHIFT    0x01u   /* As defined by Register map as MODE_CFG bits in CFG1*/
    #endif
    #if(Second_Arm_DGS06NF_PSOC3_ES3 || Second_Arm_DGS06NF_PSOC5_ES2)
        #define Second_Arm_DGS06NF_CTRL_CMPMODE1_SHIFT    0x04u  /* As defined by Register map as MODE_CFG bits in CFG2*/
    #endif
    
    #define Second_Arm_DGS06NF_CTRL_DEAD_TIME_SHIFT   0x06u   /* As defined by Register map */
    /* Fixed Function Block Only CFG register bit definitions */
    #define Second_Arm_DGS06NF_CFG0_MODE              0x02u   /*  Set to compare mode */
    //#define Second_Arm_DGS06NF_CFG0_ENABLE            0x01u   /* Enable the block to run */
    #define Second_Arm_DGS06NF_CFG0_DB                0x20u   /* As defined by Register map as DB bit in CFG0 */

    /* Control Register Bit Masks */
    #define Second_Arm_DGS06NF_CTRL_ENABLE            (0x01u << Second_Arm_DGS06NF_CTRL_ENABLE_SHIFT)
    #define Second_Arm_DGS06NF_CTRL_RESET             (0x01u << Second_Arm_DGS06NF_CTRL_RESET_SHIFT)
    #define Second_Arm_DGS06NF_CTRL_CMPMODE2_MASK     (0x07u << Second_Arm_DGS06NF_CTRL_CMPMODE2_SHIFT)
    #if(Second_Arm_DGS06NF_PSOC3_ES2 || Second_Arm_DGS06NF_PSOC5_ES1)
        #define Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK     (0x07u << Second_Arm_DGS06NF_CTRL_CMPMODE1_SHIFT)
    #endif
    #if(Second_Arm_DGS06NF_PSOC3_ES3 || Second_Arm_DGS06NF_PSOC5_ES2)
        #define Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK     (0x07u << Second_Arm_DGS06NF_CTRL_CMPMODE1_SHIFT)
    #endif
    
    /* Control2 Register Bit Masks */
    #define Second_Arm_DGS06NF_CTRL2_IRQ_SEL_SHIFT    0x00u       /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define Second_Arm_DGS06NF_CTRL2_IRQ_SEL          (0x01u << Second_Arm_DGS06NF_CTRL2_IRQ_SEL_SHIFT)  
    
    /* Status Register Bit Locations */
    #define Second_Arm_DGS06NF_STATUS_TC_SHIFT            0x07u   /* As defined by Register map as TC in SR0 */
    #define Second_Arm_DGS06NF_STATUS_CMP1_SHIFT          0x06u   /* As defined by the Register map as CAP_CMP in SR0 */
    
    /* Status Register Interrupt Enable Bit Locations */
    #define Second_Arm_DGS06NF_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)    
    #define Second_Arm_DGS06NF_STATUS_TC_INT_EN_MASK_SHIFT            (Second_Arm_DGS06NF_STATUS_TC_SHIFT - 4)
    #define Second_Arm_DGS06NF_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)  
    #define Second_Arm_DGS06NF_STATUS_CMP1_INT_EN_MASK_SHIFT          (Second_Arm_DGS06NF_STATUS_CMP1_SHIFT - 4)
    
    /* Status Register Bit Masks */
    #define Second_Arm_DGS06NF_STATUS_TC              (0x01u << Second_Arm_DGS06NF_STATUS_TC_SHIFT)
    #define Second_Arm_DGS06NF_STATUS_CMP1            (0x01u << Second_Arm_DGS06NF_STATUS_CMP1_SHIFT)
    
    /* Status Register Interrupt Bit Masks*/
    #define Second_Arm_DGS06NF_STATUS_TC_INT_EN_MASK              (Second_Arm_DGS06NF_STATUS_TC >> 4)
    #define Second_Arm_DGS06NF_STATUS_CMP1_INT_EN_MASK            (Second_Arm_DGS06NF_STATUS_CMP1 >> 4)
    
    /*RT1 Synch Constants: Applicable for PSoC3 ES2/PSoC3 ES3 PSoC5 ES2*/
    #define Second_Arm_DGS06NF_RT1_SHIFT              0x04u
    #define Second_Arm_DGS06NF_RT1_MASK               (0x03u << Second_Arm_DGS06NF_RT1_SHIFT)  /* Sync TC and CMP bit masks */
    #define Second_Arm_DGS06NF_SYNC                   (0x03u << Second_Arm_DGS06NF_RT1_SHIFT)
    #define Second_Arm_DGS06NF_SYNCDSI_SHIFT          0x00u
    #define Second_Arm_DGS06NF_SYNCDSI_MASK           (0x0Fu << Second_Arm_DGS06NF_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define Second_Arm_DGS06NF_SYNCDSI_EN             (0x0Fu << Second_Arm_DGS06NF_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    

#else
    #define Second_Arm_DGS06NF_STATUS                (*(reg8 *) Second_Arm_DGS06NF_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define Second_Arm_DGS06NF_STATUS_PTR            ((reg8 *) Second_Arm_DGS06NF_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define Second_Arm_DGS06NF_STATUS_MASK           (*(reg8 *) Second_Arm_DGS06NF_PWMUDB_sSTSReg_nrstSts_stsreg__MASK_REG)
    #define Second_Arm_DGS06NF_STATUS_MASK_PTR       ((reg8 *) Second_Arm_DGS06NF_PWMUDB_sSTSReg_nrstSts_stsreg__MASK_REG)
    #define Second_Arm_DGS06NF_STATUS_AUX_CTRL       (*(reg8 *) Second_Arm_DGS06NF_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define Second_Arm_DGS06NF_CONTROL               (*(reg8 *) Second_Arm_DGS06NF_PWMUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG)
    #define Second_Arm_DGS06NF_CONTROL_PTR           ((reg8 *) Second_Arm_DGS06NF_PWMUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG)
    
    
    /***********************************
    *          Constants
    ***********************************/
    /* Control Register definitions */
    #define Second_Arm_DGS06NF_CTRL_ENABLE_SHIFT      0x07u
    #define Second_Arm_DGS06NF_CTRL_RESET_SHIFT       0x06u
    #define Second_Arm_DGS06NF_CTRL_CMPMODE2_SHIFT    0x03u
    #define Second_Arm_DGS06NF_CTRL_CMPMODE1_SHIFT    0x00u
    #define Second_Arm_DGS06NF_CTRL_DEAD_TIME_SHIFT   0x00u   /* No Shift Needed for UDB block */
    /* Control Register Bit Masks */
    #define Second_Arm_DGS06NF_CTRL_ENABLE            (0x01u << Second_Arm_DGS06NF_CTRL_ENABLE_SHIFT)
    #define Second_Arm_DGS06NF_CTRL_RESET             (0x01u << Second_Arm_DGS06NF_CTRL_RESET_SHIFT)
    #define Second_Arm_DGS06NF_CTRL_CMPMODE2_MASK     (0x07u << Second_Arm_DGS06NF_CTRL_CMPMODE2_SHIFT)
    #define Second_Arm_DGS06NF_CTRL_CMPMODE1_MASK     (0x07u << Second_Arm_DGS06NF_CTRL_CMPMODE1_SHIFT) 
    
    /* Status Register Bit Locations */
    #define Second_Arm_DGS06NF_STATUS_KILL_SHIFT          0x05u
    #define Second_Arm_DGS06NF_STATUS_FIFONEMPTY_SHIFT    0x04u
    #define Second_Arm_DGS06NF_STATUS_FIFOFULL_SHIFT      0x03u  
    #define Second_Arm_DGS06NF_STATUS_TC_SHIFT            0x02u
    #define Second_Arm_DGS06NF_STATUS_CMP2_SHIFT          0x01u
    #define Second_Arm_DGS06NF_STATUS_CMP1_SHIFT          0x00u
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define Second_Arm_DGS06NF_STATUS_KILL_INT_EN_MASK_SHIFT          Second_Arm_DGS06NF_STATUS_KILL_SHIFT          
    #define Second_Arm_DGS06NF_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    Second_Arm_DGS06NF_STATUS_FIFONEMPTY_SHIFT    
    #define Second_Arm_DGS06NF_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      Second_Arm_DGS06NF_STATUS_FIFOFULL_SHIFT        
    #define Second_Arm_DGS06NF_STATUS_TC_INT_EN_MASK_SHIFT            Second_Arm_DGS06NF_STATUS_TC_SHIFT            
    #define Second_Arm_DGS06NF_STATUS_CMP2_INT_EN_MASK_SHIFT          Second_Arm_DGS06NF_STATUS_CMP2_SHIFT          
    #define Second_Arm_DGS06NF_STATUS_CMP1_INT_EN_MASK_SHIFT          Second_Arm_DGS06NF_STATUS_CMP1_SHIFT   
    /* Status Register Bit Masks */
    #define Second_Arm_DGS06NF_STATUS_KILL            (0x00u << Second_Arm_DGS06NF_STATUS_KILL_SHIFT )
    #define Second_Arm_DGS06NF_STATUS_FIFOFULL        (0x01u << Second_Arm_DGS06NF_STATUS_FIFOFULL_SHIFT)
    #define Second_Arm_DGS06NF_STATUS_FIFONEMPTY      (0x01u << Second_Arm_DGS06NF_STATUS_FIFONEMPTY_SHIFT)
    #define Second_Arm_DGS06NF_STATUS_TC              (0x01u << Second_Arm_DGS06NF_STATUS_TC_SHIFT)
    #define Second_Arm_DGS06NF_STATUS_CMP2            (0x01u << Second_Arm_DGS06NF_STATUS_CMP2_SHIFT) 
    #define Second_Arm_DGS06NF_STATUS_CMP1            (0x01u << Second_Arm_DGS06NF_STATUS_CMP1_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define Second_Arm_DGS06NF_STATUS_KILL_INT_EN_MASK            Second_Arm_DGS06NF_STATUS_KILL
    #define Second_Arm_DGS06NF_STATUS_FIFOFULL_INT_EN_MASK        Second_Arm_DGS06NF_STATUS_FIFOFULL
    #define Second_Arm_DGS06NF_STATUS_FIFONEMPTY_INT_EN_MASK      Second_Arm_DGS06NF_STATUS_FIFONEMPTY
    #define Second_Arm_DGS06NF_STATUS_TC_INT_EN_MASK              Second_Arm_DGS06NF_STATUS_TC
    #define Second_Arm_DGS06NF_STATUS_CMP2_INT_EN_MASK            Second_Arm_DGS06NF_STATUS_CMP2
    #define Second_Arm_DGS06NF_STATUS_CMP1_INT_EN_MASK            Second_Arm_DGS06NF_STATUS_CMP1
                                                          
    /* Datapath Auxillary Control Register definitions */
    #define Second_Arm_DGS06NF_AUX_CTRL_FIFO0_CLR     0x01u
    #define Second_Arm_DGS06NF_AUX_CTRL_FIFO1_CLR     0x02u
    #define Second_Arm_DGS06NF_AUX_CTRL_FIFO0_LVL     0x04u
    #define Second_Arm_DGS06NF_AUX_CTRL_FIFO1_LVL     0x08u
    #define Second_Arm_DGS06NF_STATUS_ACTL_INT_EN_MASK  0x10u /* As defined for the ACTL Register */
#endif /* Second_Arm_DGS06NF_UsingFixedFunction */

#endif  /* CY_PWM_Second_Arm_DGS06NF_H */
