/*******************************************************************************
* File Name: Second_Arm_DGS06NF_PM.c
* Version 2.10
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "Second_Arm_DGS06NF.h"

static Second_Arm_DGS06NF_backupStruct Second_Arm_DGS06NF_backup;


/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Second_Arm_DGS06NF_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Second_Arm_DGS06NF_SaveConfig(void)
{
    
    #if(!Second_Arm_DGS06NF_UsingFixedFunction)
        #if (Second_Arm_DGS06NF_PSOC3_ES2 || Second_Arm_DGS06NF_PSOC5_ES1)
            Second_Arm_DGS06NF_backup.PWMUdb = Second_Arm_DGS06NF_ReadCounter();
            Second_Arm_DGS06NF_backup.PWMPeriod = Second_Arm_DGS06NF_ReadPeriod();
            #if (Second_Arm_DGS06NF_UseStatus)
                Second_Arm_DGS06NF_backup.InterruptMaskValue = Second_Arm_DGS06NF_STATUS_MASK;
            #endif
            
            #if(Second_Arm_DGS06NF_UseOneCompareMode)
                Second_Arm_DGS06NF_backup.PWMCompareValue = Second_Arm_DGS06NF_ReadCompare();
            #else
                Second_Arm_DGS06NF_backup.PWMCompareValue1 = Second_Arm_DGS06NF_ReadCompare1();
                Second_Arm_DGS06NF_backup.PWMCompareValue2 = Second_Arm_DGS06NF_ReadCompare2();
            #endif
            
           #if(Second_Arm_DGS06NF_DeadBandUsed)
                Second_Arm_DGS06NF_backup.PWMdeadBandValue = Second_Arm_DGS06NF_ReadDeadTime();
            #endif
          
            #if ( Second_Arm_DGS06NF_KillModeMinTime)
                Second_Arm_DGS06NF_backup.PWMKillCounterPeriod = Second_Arm_DGS06NF_ReadKillTime();
            #endif
        #endif
        
        #if (Second_Arm_DGS06NF_PSOC3_ES3 || Second_Arm_DGS06NF_PSOC5_ES2)
            #if(!Second_Arm_DGS06NF_PWMModeIsCenterAligned)
                Second_Arm_DGS06NF_backup.PWMPeriod = Second_Arm_DGS06NF_ReadPeriod();
            #endif
            Second_Arm_DGS06NF_backup.PWMUdb = Second_Arm_DGS06NF_ReadCounter();
            #if (Second_Arm_DGS06NF_UseStatus)
                Second_Arm_DGS06NF_backup.InterruptMaskValue = Second_Arm_DGS06NF_STATUS_MASK;
            #endif
            
            #if(Second_Arm_DGS06NF_DeadBandMode == Second_Arm_DGS06NF__B_PWM__DBM_256_CLOCKS || Second_Arm_DGS06NF_DeadBandMode == Second_Arm_DGS06NF__B_PWM__DBM_2_4_CLOCKS)
                Second_Arm_DGS06NF_backup.PWMdeadBandValue = Second_Arm_DGS06NF_ReadDeadTime();
            #endif
            
            #if(Second_Arm_DGS06NF_KillModeMinTime)
                 Second_Arm_DGS06NF_backup.PWMKillCounterPeriod = Second_Arm_DGS06NF_ReadKillTime();
            #endif
        #endif
        
        #if(Second_Arm_DGS06NF_UseControl)
            Second_Arm_DGS06NF_backup.PWMControlRegister = Second_Arm_DGS06NF_ReadControlRegister();
        #endif
    #endif  
}


/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Second_Arm_DGS06NF_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*  Yes.
*
*******************************************************************************/
void Second_Arm_DGS06NF_RestoreConfig(void) 
{
        #if(!Second_Arm_DGS06NF_UsingFixedFunction)
            #if (Second_Arm_DGS06NF_PSOC3_ES2 || Second_Arm_DGS06NF_PSOC5_ES1)
                /* Interrupt State Backup for Critical Region*/
                uint8 Second_Arm_DGS06NF_interruptState;
                /* Enter Critical Region*/
                Second_Arm_DGS06NF_interruptState = CyEnterCriticalSection();
                #if (Second_Arm_DGS06NF_UseStatus)
                    /* Use the interrupt output of the status register for IRQ output */
                    Second_Arm_DGS06NF_STATUS_AUX_CTRL |= Second_Arm_DGS06NF_STATUS_ACTL_INT_EN_MASK;
                    
                    Second_Arm_DGS06NF_STATUS_MASK = Second_Arm_DGS06NF_backup.InterruptMaskValue;
                #endif
                
                #if (Second_Arm_DGS06NF_Resolution == 8)
                    /* Set FIFO 0 to 1 byte register for period*/
                    Second_Arm_DGS06NF_AUX_CONTROLDP0 |= (Second_Arm_DGS06NF_AUX_CTRL_FIFO0_CLR);
                #else /* (Second_Arm_DGS06NF_Resolution == 16)*/
                    /* Set FIFO 0 to 1 byte register for period */
                    Second_Arm_DGS06NF_AUX_CONTROLDP0 |= (Second_Arm_DGS06NF_AUX_CTRL_FIFO0_CLR);
                    Second_Arm_DGS06NF_AUX_CONTROLDP1 |= (Second_Arm_DGS06NF_AUX_CTRL_FIFO0_CLR);
                #endif
                /* Exit Critical Region*/
                CyExitCriticalSection(Second_Arm_DGS06NF_interruptState);
                
                Second_Arm_DGS06NF_WriteCounter(Second_Arm_DGS06NF_backup.PWMUdb);
                Second_Arm_DGS06NF_WritePeriod(Second_Arm_DGS06NF_backup.PWMPeriod);
                
                #if(Second_Arm_DGS06NF_UseOneCompareMode)
                    Second_Arm_DGS06NF_WriteCompare(Second_Arm_DGS06NF_backup.PWMCompareValue);
                #else
                    Second_Arm_DGS06NF_WriteCompare1(Second_Arm_DGS06NF_backup.PWMCompareValue1);
                    Second_Arm_DGS06NF_WriteCompare2(Second_Arm_DGS06NF_backup.PWMCompareValue2);
                #endif
                
               #if(Second_Arm_DGS06NF_DeadBandMode == Second_Arm_DGS06NF__B_PWM__DBM_256_CLOCKS || Second_Arm_DGS06NF_DeadBandMode == Second_Arm_DGS06NF__B_PWM__DBM_2_4_CLOCKS)
                    Second_Arm_DGS06NF_WriteDeadTime(Second_Arm_DGS06NF_backup.PWMdeadBandValue);
                #endif
            
                #if ( Second_Arm_DGS06NF_KillModeMinTime)
                    Second_Arm_DGS06NF_WriteKillTime(Second_Arm_DGS06NF_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if (Second_Arm_DGS06NF_PSOC3_ES3 || Second_Arm_DGS06NF_PSOC5_ES2)
                #if(!Second_Arm_DGS06NF_PWMModeIsCenterAligned)
                    Second_Arm_DGS06NF_WritePeriod(Second_Arm_DGS06NF_backup.PWMPeriod);
                #endif
                Second_Arm_DGS06NF_WriteCounter(Second_Arm_DGS06NF_backup.PWMUdb);
                #if (Second_Arm_DGS06NF_UseStatus)
                    Second_Arm_DGS06NF_STATUS_MASK = Second_Arm_DGS06NF_backup.InterruptMaskValue;
                #endif
                
                #if(Second_Arm_DGS06NF_DeadBandMode == Second_Arm_DGS06NF__B_PWM__DBM_256_CLOCKS || Second_Arm_DGS06NF_DeadBandMode == Second_Arm_DGS06NF__B_PWM__DBM_2_4_CLOCKS)
                    Second_Arm_DGS06NF_WriteDeadTime(Second_Arm_DGS06NF_backup.PWMdeadBandValue);
                #endif
                
                #if(Second_Arm_DGS06NF_KillModeMinTime)
                    Second_Arm_DGS06NF_WriteKillTime(Second_Arm_DGS06NF_backup.PWMKillCounterPeriod);
                #endif
            #endif
            
            #if(Second_Arm_DGS06NF_UseControl)
                Second_Arm_DGS06NF_WriteControlRegister(Second_Arm_DGS06NF_backup.PWMControlRegister); 
            #endif
        #endif  
    }


/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Second_Arm_DGS06NF_backup.PWMEnableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Second_Arm_DGS06NF_Sleep(void)
{
    #if(Second_Arm_DGS06NF_UseControl)
        if(Second_Arm_DGS06NF_CTRL_ENABLE == (Second_Arm_DGS06NF_CONTROL & Second_Arm_DGS06NF_CTRL_ENABLE))
        {
            /*Component is enabled */
            Second_Arm_DGS06NF_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            Second_Arm_DGS06NF_backup.PWMEnableState = 0u;
        }
    #endif
    /* Stop component */
    Second_Arm_DGS06NF_Stop();
    
    /* Save registers configuration */
    Second_Arm_DGS06NF_SaveConfig();
}


/*******************************************************************************
* Function Name: Second_Arm_DGS06NF_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Second_Arm_DGS06NF_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Second_Arm_DGS06NF_Wakeup(void) 
{
     /* Restore registers values */
    Second_Arm_DGS06NF_RestoreConfig();
    
    if(Second_Arm_DGS06NF_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        Second_Arm_DGS06NF_Enable();
    } /* Do nothing if component's block was disabled before */
    
}

/* [] END OF FILE */
