/* ========================================
 *
 * Copyright: Shandong University Of Science and Technology , 06 Nov 2011 September
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 * This portion of code is for controlling the whole SCARA Robot 
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF Malvin Maduna Nkomo.
 * Author : Malvin Maduna Nkomo
 * ========================================
*/
#include <device.h>

/*LED states */
#define LED_ON  0x01
#define LED_OFF 0x00


uint8 ledState1 = 0x00; /* Initially set LED1 to off */
uint8 ledState2 = 0x00; /* Initially set LED2 to off */
uint8 ledState3 = 0x00; /* Initially set LED3 to off */
uint8 ledState4 = 0x00; /* Initially set LED4 to off */

/*PWM specific variables */ 

uint16 period;

/*ADC specific variables */ 

uint32 voltageRawCount0;
uint32 voltageRawCount1;
uint32 voltageRawCount2;
uint32 voltageRawCount3;

/*******************function prototypes **********************/
int Base_Rotate_Clockwise(unsigned int period);
int Base_Rotate_CounterClockwise(unsigned int period);
int Second_Arm_Rotate_Clockwise(unsigned int period);					
int Second_Arm_Rotate_CounterClockwise(unsigned int period); 	
int Up(unsigned int period);
int Down(unsigned int period);
int Open_Grippers(unsigned int period);
int Close_Grippers(unsigned int period);
int	Second_Arm_Rotate_Clockwise_To_Centre(unsigned int period);
int	Second_Arm_Rotate_Clockwise_From_Centre_To_Rest(unsigned int period);
int	Second_Arm_Rotate_Counter_Clockwise_From_Centre_To_Rest(unsigned int period);
int Search_Foward(unsigned int period);
int Search_With_Base_Motor(unsigned int period);
void  Home(void);
void ADC(void);
void Dump_Position(void);
void delay_ms(unsigned int n);
void PickUpToHome(void);
void PickUpToCentre(void);
void CounterFrequency(void);
void RGBSensor(void);

/*************************************************************/


void main()

{  	

   /* Intialize the LCD*/
    LCD_Char_1_Start(); 
	LCD_Char_1_ClearDisplay();
     
 		
	Clock_Start();									/********** Start the PWM modules ********************************************************************/
	
	while (1) 
	
	{
	 	
			for(;;)
			{
			
           	 {
				LCD_Char_1_ClearDisplay();
				LCD_Char_1_Position(0,0);
			   	LCD_Char_1_PrintString("Robot Running"); 
				
               				
				Base_Rotation_Hitec_Start(); 					/*Start the PWM for the Hitec Servo */
				Second_Arm_DGS06NF_Start();						/*Start the PWM for the DG SErvo S06NF*/
				Lift_Futaba_S3003_Start();						/*Start the PWM for the Futaba Lifting servo */
				Grippers_DGS05NF_Start();						/*Start the PWM for the Grippers Servo */
				
				Home();
				Open_Grippers(period);
				for (;;)
				
				{
//		    	Dump_Position();				
//				Up(period);
//				delay_ms(10000);
//				delay_ms(10000);
//				Up(period);
//				Lift_Futaba_S3003_WritePeriod(420);
//				delay_ms(10000);
//				Search_Foward(period);
//				delay_ms(10000);
//				Search_With_Base_Motor(period);
//				delay_ms(10000);
//				Open_Grippers(period);
//				PickUpToHome();
//				PickUpToCentre();
				RGBSensor();
//				delay_ms(10000);
//				Close_Grippers(period);
//				delay_ms(10000);
//				Search_Foward(period);
//				delay_ms(1000);
//				Home();
//				delay_ms(100000);
				}
			
        	 }

      		}    
       
        
	}

}

/********************************* END OF THE MAIN FUNCTION***************************************************/ 



/*********************************FUNCTIONS********************************************************************
*This is the function for the clockwise rotaion of the Hitec Servo HS422 in a clockwise dierection from period 
*period 425 to period 465. The startup period set on the PWM Module is 425 and teh CPM value is 415. the output
*is 1 output 16 bit resolution and UDB.
***************************************************************************************************************/

int Base_Rotate_Clockwise(unsigned int period )

{
	for(period=408;period<=465;period++)
		{
			Base_Rotation_Hitec_WritePeriod(period);
			delay_ms(750);
			ledState1 ^= 0x01u;   										/* Toggle LED1 setting between low and high */
        	LED_1_Write(ledState1); 									/* Set LED1 */
		
		}
		
		return period;
}

/**************************************************************************************************************/


/**************************************************************************************************************
*this is the function for the counter clockwise rotaion of the Hitec Servo HS422 in a counter clockwise direction from period 
*period 465 to period 425. The startup period set on the PWM Module is 425 and the CPM value is 415. The output
*is 1 output 16 bit resolution and UDB.
***************************************************************************************************************/

int Base_Rotate_CounterClockwise(unsigned int period)		
	
{	
	for(period=465;period>=408;period--)
		
		{			
			Base_Rotation_Hitec_WritePeriod(period);
			delay_ms(750);
			ledState1 ^= 0x01u;  		 								/* Toggle LED2 setting between low and high */
        	LED_1_Write(ledState1);		 								/* Set LED2 */
		}
		
	return period;
}
/**************************************************************************************************************/


/**************************************************************************************************************
*this is the function for the clockwise rotaion of the DG Servo DGS06NF in a clockwise direction from period 
*period 465 to period 425. The startup period set on the PWM Module is 425 and the CPM value is 415. The output
*is 1 output 16 bit resolution and UDB.
***************************************************************************************************************/

int	Second_Arm_Rotate_Clockwise(unsigned int period)					/*Rotate the DGServo S06NF in the clockwise direction*/
{
		for (period=408;period<465;period++)
		{
			Second_Arm_DGS06NF_WritePeriod(period);
			delay_ms(1500);
			ledState2 ^= 0x01u;   										/* Toggle LED2 setting between low and high */
        	LED_2_Write(ledState2); 									/* Set LED2 */
			
		}
		
	return period;


}		
		
/**************************************************************************************************************
*this is the function for the counter clockwise rotaion of the DGSevo S06NF in a counter clockwise direction from period 
*period 465 to period 425. The startup period set on the PWM Module is 425 and the CPM value is 415. The output
*is 1 output 16 bit resolution and UDB.
***************************************************************************************************************/
int Second_Arm_Rotate_CounterClockwise(unsigned int period) 			/*Rotate the DGServo S06NF in the counter clocksiwe direction */
{
		for (period=465;period>408;period--)
		
		{
			Second_Arm_DGS06NF_WritePeriod(period);
			delay_ms(1500);
			ledState2 ^= 0x01u;   										/* Toggle LED2 setting between low and high */
        	LED_2_Write(ledState2); 									/* Set LED2 */
		
		}
		
		return period;

}		

		
/**********************************Up Movement********************************************************************************/

int Up(unsigned int period)
{

	for (period=434; period>422; period--)
	
	{
		Lift_Futaba_S3003_WritePeriod(period);
		delay_ms(1500);
		ledState3 ^= 0x01u;   										/* Toggle LED3 setting between low and high */
        LED_3_Write(ledState3); 
		
	}
	
	return period;
}
/**********************Down Movement******************************************************************************/
int Down(unsigned int period)
{

	for (period=422; period<434; period++)
	
	{
		Lift_Futaba_S3003_WritePeriod(period);
		delay_ms(1500);
		ledState3 ^= 0x01u;   										/* Toggle LED3 setting between low and high */
        LED_3_Write(ledState3); 
		
	}
	
	return period; 
}


/******************************Open Grippers*********************************************************************************/

int Open_Grippers(unsigned int period)

{
	for(period=434; period>422; period--)

		{
		Grippers_DGS05NF_WritePeriod(period);
		delay_ms(5000);
		ledState4 ^= 0x01u;   										/* Toggle LED4 setting between low and high */
        LED_4_Write(ledState4); 
		}
		
		return period; 
		
}

/*****************************Close Grippers************************************************************/

int Close_Grippers(unsigned int period)

{
		for (period=422; period<434; period++)
		
		{
		Grippers_DGS05NF_WritePeriod(period);
		delay_ms (1000);
		ledState4 ^= 0x01u;   										/* Toggle LED3 setting between low and high */
        LED_4_Write(ledState4); 
		}
		
		return period;
}

/************************************************************************************************************/
/**************************************************************************************************************
*this is the function for the clockwise rotaion of the DG Servo DGS06NF in a clockwise direction from period 
*period 465 to period 436. This positions the arm centrally The startup period set on the PWM Module is 425 and 
the CPM value is 415. The output is 1 output 16 bit resolution and UDB.
***************************************************************************************************************/

int	Second_Arm_Rotate_Clockwise_To_Centre(unsigned int period)					/*Rotate the DGServo S06NF in the clockwise direction till center*/
{
		for (period=465;period>434;period--)
		{
			Second_Arm_DGS06NF_WritePeriod(period);
			delay_ms(1500);
			ledState2 ^= 0x01u;   										/* Toggle LED2 setting between low and high */
        	LED_2_Write(ledState2); 									/* Set LED2 */
			
		}
		
	return period;


}		


/*This is the function for the movement of the 2nd arm from the centre position Clockwise to the rest at 180*/


int	Second_Arm_Rotate_Clockwise_From_Centre_To_Rest(unsigned int period)					/*Rotate the DGServo S06NF in the clockwise direction till center*/
{
		for (period=434;period>408;period--)
		{
			Second_Arm_DGS06NF_WritePeriod(period);
			delay_ms(1500);
			ledState2 ^= 0x01u;   										/* Toggle LED2 setting between low and high */
        	LED_2_Write(ledState2); 									/* Set LED2 */
			
		}
		
	return period;


}	

/*This is the function for the movement of the 2nd arm from the centre position Counter Cllockwise to rest at 0 */


int	Second_Arm_Rotate_Counter_Clockwise_From_Centre_To_Rest(unsigned int period)
{
		for (period=434;period<465;period++)
		{
			Second_Arm_DGS06NF_WritePeriod(period);
			delay_ms(1500);
			ledState2 ^= 0x01u;   										/* Toggle LED2 setting between low and high */
        	LED_2_Write(ledState2); 									/* Set LED2 */
			
		}
		
	return period;


}	

/*********************************Search the colour********************************************************************
*This is the function for the searching of teh product in the foward direction
***************************************************************************************************************/
int Search_Foward(unsigned int period)

{	
			voltageRawCount0=0;
			voltageRawCount1=0;
			voltageRawCount2=0;
			voltageRawCount3=0;
			Lift_Futaba_S3003_WritePeriod(420);
			Grippers_DGS05NF_WritePeriod(420);
			
			Base_Rotation_Hitec_WritePeriod(455);
			for (period=426; period>=412; period--)
			
				{
					Grippers_DGS05NF_WritePeriod(420);
					delay_ms(100);	
					ADC();
					delay_ms(100);
					
						if ((voltageRawCount1>250)&&(voltageRawCount2>250))
						
					
							{
								
//								period++;
								PickUpToHome();
								voltageRawCount1=0;
								voltageRawCount2=0;
								break; 
							}
							
							else 
							
							{
								Second_Arm_DGS06NF_WritePeriod(period);
								delay_ms(100);
								
							}
				}
//				PickUpToHome();
				delay_ms(100);
				
				Base_Rotation_Hitec_WritePeriod(455);
				delay_ms(100);
			for (period=412; period<=426; period++)
			
				{
				
					delay_ms(100);
					ADC();
					delay_ms(100);
					if ( (voltageRawCount1>250)&&(voltageRawCount2>250))
						
							{
//								period--;	
								PickUpToCentre();
								 
								break; 
							}
							
							else 
							
							{
								Second_Arm_DGS06NF_WritePeriod(period);
								delay_ms(100);
								
							}
				}	
				delay_ms(1000);
		
			
//			Search again for another angle


			Base_Rotation_Hitec_WritePeriod(460);
			
			for (period=440; period>=416; period--)
			
				{
					delay_ms(100);
					ADC();
					delay_ms(100);

					
						if ((voltageRawCount1>250)&&(voltageRawCount2>250))
						
							{
								
//								period++;
								PickUpToHome();
								voltageRawCount1=0;
								voltageRawCount2=0;
								break; 
							}
							
							else 
							
							{
								Second_Arm_DGS06NF_WritePeriod(period);
								delay_ms(100);
								
							}
							
				}

				delay_ms(300);

				Base_Rotation_Hitec_WritePeriod(458);
				delay_ms(300);
				
			for (period=416; period<=437; period++)
			
				{
					delay_ms(100);
					ADC();
					delay_ms(100);
					if ((voltageRawCount1>250)&&(voltageRawCount2>250))
						
							{
								
//								period--;
								PickUpToCentre();
								
								break; 
							}
							
							else 
							
							{
								Second_Arm_DGS06NF_WritePeriod(period);
								delay_ms(100);
								
							}
				}	
				delay_ms(100);
//			Search again for the 3rd time at another angle
			
			Base_Rotation_Hitec_WritePeriod(462);
			
			for (period=442; period>=425; period--)
			
				{
					delay_ms(100);
					ADC();
					delay_ms(100);
						if ((voltageRawCount1>250)&&(voltageRawCount2>250))
						
							{
								
//								period++;
								PickUpToHome();
								
								break; 
							}
							
							else 
							
							{
								Second_Arm_DGS06NF_WritePeriod(period);
								delay_ms(100);
								
							}
							
				}

				delay_ms(100);

				Base_Rotation_Hitec_WritePeriod(462);
				delay_ms(100);
				
			for (period=428; period<=442; period++)
			
				{
					delay_ms(100);
					ADC();
					delay_ms(100);
					if ( (voltageRawCount1>250)&&(voltageRawCount2>250))
						
							{
								
//								period--;
								PickUpToCentre();
								
								break; 
							}
							
							else 
							
							{
								Second_Arm_DGS06NF_WritePeriod(period);
								delay_ms(100);
																
							}
				}	
				delay_ms(100);

return period; 
}

//////////////////////////////////////////////////////////////////////////// 
///////////// This is the search pattern based on the base rotation motor. 

int Search_With_Base_Motor(unsigned int period)

{
		Lift_Futaba_S3003_WritePeriod(420);
		Grippers_DGS05NF_WritePeriod(422);
		
		Second_Arm_DGS06NF_WritePeriod(415);
		for (period=445; period<=458; period++)
			
				{
//					Grippers_DGS05NF_WritePeriod(420);
					voltageRawCount0=0;
					voltageRawCount1=0; 
					voltageRawCount2=0;
					voltageRawCount3=0;
					
					delay_ms(100);
					ADC();
					delay_ms(100);
					
					if ( (voltageRawCount1>250)&&(voltageRawCount2>250))
						
							{
								
//								period--;
								PickUpToCentre();
								
								break; 
							}
							
							else 
							
							{
								Base_Rotation_Hitec_WritePeriod(period);
								delay_ms(100);
								
							}
				}	
				delay_ms(100);

		Second_Arm_DGS06NF_WritePeriod(417);

		for (period=458; period>447; period--)
			
				{
					voltageRawCount0=0;
					voltageRawCount1=0; 
					voltageRawCount2=0;
					voltageRawCount3=0;
					
					delay_ms(100);
					ADC();
					delay_ms(100);
					
					if ( (voltageRawCount1>250)&&(voltageRawCount2>250))
						
							{
								
//								period++;
								PickUpToCentre();
								 
								break; 
							}
							
							else 
							
							{
								Base_Rotation_Hitec_WritePeriod(period);
								delay_ms(100);
								
							}
				}	
		
		delay_ms(100);

// second iteration using base rotate 

		Second_Arm_DGS06NF_WritePeriod(419);
		for (period=449; period<=458; period++)
			
				{
//					Grippers_DGS05NF_WritePeriod(420);
					voltageRawCount0=0;
					voltageRawCount1=0; 
					voltageRawCount2=0;
					voltageRawCount3=0;
					
					delay_ms(100);
					ADC();
					delay_ms(100);
					
					if ( (voltageRawCount1>250)&&(voltageRawCount2>250))
						
							{
								
//								period--;
								PickUpToCentre();
								
								break; 
							}
							
							else 
							
							{
								Base_Rotation_Hitec_WritePeriod(period);
								delay_ms(100);
								
							}
				}	
				delay_ms(100);

		Second_Arm_DGS06NF_WritePeriod(421);

		for (period=460; period>449; period--)
			
				{
					voltageRawCount0=0;
					voltageRawCount1=0; 
					voltageRawCount2=0;
					voltageRawCount3=0;
					
					delay_ms(100);
					ADC();
					delay_ms(100);
					
					if ( (voltageRawCount1>250)&&(voltageRawCount2>250))
						
							{
								
//								period++;
								PickUpToCentre();
								 
								break; 
							}
							
							else 
							
							{
								Base_Rotation_Hitec_WritePeriod(period);
								delay_ms(100);
								
							}
				}	

// third iterartion using base rotate


Second_Arm_DGS06NF_WritePeriod(430);
		for (period=454; period<=462; period++)
			
				{
//					Grippers_DGS05NF_WritePeriod(420);
					voltageRawCount0=0;
					voltageRawCount1=0; 
					voltageRawCount2=0;
					voltageRawCount3=0;
					
					delay_ms(100);
					ADC();
					delay_ms(100);
					
					if ( (voltageRawCount1>250)&&(voltageRawCount2>250))
						
							{
								
//								period--;
								PickUpToCentre();
								
								break; 
							}
							
							else 
							
							{
								Base_Rotation_Hitec_WritePeriod(period);
								delay_ms(100);
								
							}
				}	
				delay_ms(100);

		Second_Arm_DGS06NF_WritePeriod(424);

		for (period=460; period>450; period--)
			
				{
					voltageRawCount0=0;
					voltageRawCount1=0; 
					voltageRawCount2=0;
					voltageRawCount3=0;
					
					delay_ms(100);
					ADC();
					delay_ms(100);
					
					if ( (voltageRawCount1>250)&&(voltageRawCount2>250))
						
							{
								
//								period++;
								PickUpToCentre();
								 
								break; 
							}
							
							else 
							
							{
								Base_Rotation_Hitec_WritePeriod(period);
								delay_ms(100);
								
							}
				}	


return period; 

}




/**********************end of search function*/

//**********************************************************************
//**********************************************************************
//**********************************************************************

//   		Home function

void Home(void)

{
//				Initial position for all the arms and mechanisms

				Second_Arm_DGS06NF_WritePeriod(433);
				Base_Rotation_Hitec_WritePeriod(445);
				Lift_Futaba_S3003_WritePeriod(422);
				Grippers_DGS05NF_WritePeriod(432);
				
//				End of initial positions functions 		
		
//return period; 
}

//				End of home function 



//   		Dump function

void Dump_Position(void)

{
//				Initial position for all the arms and mechanisms

				Second_Arm_DGS06NF_WritePeriod(432);
				Base_Rotation_Hitec_WritePeriod(426);
				Lift_Futaba_S3003_WritePeriod(422);
				Grippers_DGS05NF_WritePeriod(432);
				
//				End of initial positions functions 		

//return period; 

//				End of Dump function 

}


void PickUpToHome(void)

{
//				Initialise the  Pick Up sequence
//				Up(period);
				Open_Grippers(period);
				
				voltageRawCount0=0;
				voltageRawCount1=0; 
				voltageRawCount2=0;
				voltageRawCount3=0;
				delay_ms(1000);
				ADC();
				delay_ms(1000);
				
				int a; 			
				for (a = 0; a<=1; a++)
				
				{
					if ( (voltageRawCount1>300)&&(voltageRawCount2>300))
						
							{
							
							Down(period);
							delay_ms(100);
							Close_Grippers(period);
							delay_ms(100);
							Up(period);
							delay_ms(100);
							Base_Rotation_Hitec_WritePeriod(426);
							Second_Arm_DGS06NF_WritePeriod(433);
							delay_ms(2000);
							Down(period);
							delay_ms(100);
							Open_Grippers(period);
							delay_ms(20000);
							Lift_Futaba_S3003_WritePeriod(422);
							delay_ms(2000);
							Base_Rotation_Hitec_WritePeriod(464);
							delay_ms(1000);	
							Close_Grippers(period);
							delay_ms(2000);
							Grippers_DGS05NF_WritePeriod(422);
							break; 
							}
							
							else 	if ( (voltageRawCount1<300)&&(voltageRawCount2<300))
						
							{
							continue;									
							}
					
					}
}
				
				
//				return period; 

//				End of Pick Up sequence







void PickUpToCentre(void)

{
//				Initialise the  Pick Up sequence
//				Up(period);
				Open_Grippers(period);
				delay_ms(100);
				
				voltageRawCount0=0;
				voltageRawCount1=0; 
				voltageRawCount2=0;
				voltageRawCount3=0;
				delay_ms(1000);
				ADC();
				delay_ms(1000);
				
				int b; 
				 for (b=0; b<=1; b++)
				 {
				
					if (  (voltageRawCount1>300)&&(voltageRawCount2>300))
						
							{
							Down(period);
							delay_ms(100);
							Close_Grippers(period);
							delay_ms(100);
							Up(period);
							delay_ms(100);
							Base_Rotation_Hitec_WritePeriod(445);
							Second_Arm_DGS06NF_WritePeriod(433);
							delay_ms(2000);
							Down(period);
							delay_ms(100);
							Open_Grippers(period);
							delay_ms(2000);
							Lift_Futaba_S3003_WritePeriod(422);
							delay_ms(2000);
							Base_Rotation_Hitec_WritePeriod(464);
							delay_ms(100);	
							Close_Grippers(period);
							delay_ms(2000);
							Grippers_DGS05NF_WritePeriod(422);
							
							}
							
							else 	if ( (voltageRawCount1<300)&&(voltageRawCount2<300))
							
							{
							continue;
							}
				
				}
//				return period; 

//				End of Pick Up sequence


}



/********************** Delay function*******************************************************************
*This is the delay function used to generate the time delays between the servo pulses ******/

void delay_ms(unsigned int n)
{
	unsigned int i;
	unsigned int j;
	for (i=n; i>0;i--)
		{
		
			for(j=125; j>0;j--)
			
			{
			
			}
			
				
		}
		
}


/*  END OF FILE */
